@@ -72,7 +72,6 @@ typedef void (*lyd_ctx_free_clb)(struct lyd_ctx *ctx);
  * Covers ::lyd_xml_ctx, ::lyd_json_ctx and ::lyd_lyb_ctx.
  */
 struct lyd_ctx {
-    const struct lysc_ext_instance *ext; /**< extension instance possibly changing document root context of the data being parsed */
     uint32_t parse_opts;           /**< various @ref dataparseroptions. */
     uint32_t val_opts;             /**< various @ref datavalidationoptions. */
     uint32_t int_opts;             /**< internal parser options */
@@ -102,7 +101,6 @@ struct lyd_ctx {
  * @brief Internal context for XML data parser.
  */
 struct lyd_xml_ctx {
-    const struct lysc_ext_instance *ext;
     uint32_t parse_opts;
     uint32_t val_opts;
     uint32_t int_opts;
@@ -126,7 +124,6 @@ struct lyd_xml_ctx {
  * @brief Internal context for JSON data parser.
  */
 struct lyd_json_ctx {
-    const struct lysc_ext_instance *ext;
     uint32_t parse_opts;
     uint32_t val_opts;
     uint32_t int_opts;
@@ -151,8 +148,6 @@ struct lyd_json_ctx {
  * @brief Internal context for LYB data parser/printer.
  */
 struct lyd_lyb_ctx {
-    const struct lysc_ext_instance *ext;
-
     union {
         struct {
             uint32_t parse_opts;
@@ -243,7 +238,6 @@ LY_ERR yin_parse_submodule(struct lysp_yin_ctx **yin_ctx, struct ly_ctx *ctx, st
  * @brief Parse XML string as a YANG data tree.
  *
  * @param[in] ctx libyang context.
- * @param[in] ext Optional extension instance to parse data following the schema tree specified in the extension instance
  * @param[in] parent Parent to connect the parsed nodes to, if any.
  * @param[in,out] first_p Pointer to the first top-level parsed node, used only if @p parent is NULL.
  * @param[in] in Input structure.
@@ -251,19 +245,16 @@ LY_ERR yin_parse_submodule(struct lysp_yin_ctx **yin_ctx, struct ly_ctx *ctx, st
  * @param[in] val_opts Options for the validation phase, see @ref datavalidationoptions.
  * @param[in] int_opts Internal data parser options.
  * @param[out] parsed Set to add all the parsed siblings into.
- * @param[out] subtree_sibling Set if ::LYD_PARSE_SUBTREE is used and another subtree is following in @p in.
  * @param[out] lydctx_p Data parser context to finish validation.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
-        struct ly_set *parsed, ly_bool *subtree_sibling, struct lyd_ctx **lydctx_p);
+LY_ERR lyd_parse_xml(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_in *in,
+        uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts, struct ly_set *parsed, struct lyd_ctx **lydctx_p);
 
 /**
  * @brief Parse XML string as a NETCONF message.
  *
  * @param[in] ctx libyang context.
- * @param[in] ext Optional extension instance to parse data following the schema tree specified in the extension instance
  * @param[in] parent Parent to connect the parsed nodes to, if any.
  * @param[in,out] first_p Pointer to the first top-level parsed node, used only if @p parent is NULL.
  * @param[in] in Input structure.
@@ -272,19 +263,17 @@ LY_ERR lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *e
  * @param[in] data_type Expected NETCONF data type of the data.
  * @param[out] envp Individual parsed envelopes tree, may be returned possibly even on an error.
  * @param[out] parsed Set to add all the parsed siblings into.
- * @param[out] subtree_sibling Set if ::LYD_PARSE_SUBTREE is used and another subtree is following in @p in.
  * @param[out] lydctx_p Data parser context to finish validation.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type,
-        struct lyd_node **envp, struct ly_set *parsed, struct lyd_ctx **lydctx_p);
+LY_ERR lyd_parse_xml_netconf(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p,
+        struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type, struct lyd_node **envp,
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p);
 
 /**
  * @brief Parse JSON string as a YANG data tree.
  *
  * @param[in] ctx libyang context.
- * @param[in] ext Optional extension instance to parse data following the schema tree specified in the extension instance
  * @param[in] parent Parent to connect the parsed nodes to, if any.
  * @param[in] schema Optional schema node of the parsed node (mandatory when parsing JSON value fragment).
  * @param[in,out] first_p Pointer to the first top-level parsed node, used only if @p parent is NULL.
@@ -293,20 +282,17 @@ LY_ERR lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_ins
  * @param[in] val_opts Options for the validation phase, see @ref datavalidationoptions.
  * @param[in] int_opts Internal data parser options.
  * @param[out] parsed Set to add all the parsed siblings into.
- * @param[out] subtree_sibling Set if ::LYD_PARSE_SUBTREE is used and another subtree is following in @p in.
  * @param[out] lydctx_p Optional data parser context to finish validation.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parse_json(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        const struct lysc_node *schema, struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts,
-        uint32_t val_opts, uint32_t int_opts, struct ly_set *parsed, ly_bool *subtree_sibling,
-        struct lyd_ctx **lydctx_p);
+LY_ERR lyd_parse_json(const struct ly_ctx *ctx, struct lyd_node *parent, const struct lysc_node *schema,
+        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p);
 
 /**
  * @brief Parse JSON string as a RESTCONF message.
  *
  * @param[in] ctx libyang context.
- * @param[in] ext Optional extension instance to parse data following the schema tree specified in the extension instance
  * @param[in] parent Parent to connect the parsed nodes to, if any.
  * @param[in,out] first_p Pointer to the first top-level parsed node, used only if @p parent is NULL.
  * @param[in] in Input structure.
@@ -315,19 +301,17 @@ LY_ERR lyd_parse_json(const struct ly_ctx *ctx, const struct lysc_ext_instance *
  * @param[in] data_type Expected RESTCONF data type of the data.
  * @param[out] envp Individual parsed envelopes tree, may be returned possibly even on an error.
  * @param[out] parsed Set to add all the parsed siblings into.
- * @param[out] subtree_sibling Set if ::LYD_PARSE_SUBTREE is used and another subtree is following in @p in.
  * @param[out] lydctx_p Data parser context to finish validation.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parse_json_restconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type,
-        struct lyd_node **envp, struct ly_set *parsed, struct lyd_ctx **lydctx_p);
+LY_ERR lyd_parse_json_restconf(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p,
+        struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type, struct lyd_node **envp,
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p);
 
 /**
  * @brief Parse binary LYB data as a YANG data tree.
  *
  * @param[in] ctx libyang context.
- * @param[in] ext Optional extension instance to parse data following the schema tree specified in the extension instance
  * @param[in] parent Parent to connect the parsed nodes to, if any.
  * @param[in,out] first_p Pointer to the first top-level parsed node, used only if @p parent is NULL.
  * @param[in] in Input structure.
@@ -335,13 +319,11 @@ LY_ERR lyd_parse_json_restconf(const struct ly_ctx *ctx, const struct lysc_ext_i
  * @param[in] val_opts Options for the validation phase, see @ref datavalidationoptions.
  * @param[in] int_opts Internal data parser options.
  * @param[out] parsed Set to add all the parsed siblings into.
- * @param[out] subtree_sibling Set if ::LYD_PARSE_SUBTREE is used and another subtree is following in @p in.
  * @param[out] lydctx_p Data parser context to finish validation.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
-        struct ly_set *parsed, ly_bool *subtree_sibling, struct lyd_ctx **lydctx_p);
+LY_ERR lyd_parse_lyb(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_in *in,
+        uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts, struct ly_set *parsed, struct lyd_ctx **lydctx_p);
 
 /**
  * @brief Validate eventTime date-and-time value.
@@ -362,14 +344,6 @@ LY_ERR lyd_parser_notif_eventtime_validate(const struct lyd_node *node);
  */
 LY_ERR lyd_parser_find_operation(const struct lyd_node *parent, uint32_t int_opts, struct lyd_node **op);
 
-/**
- * @brief Get schema node of a node being parsed, use nodes stored for logging.
- *
- * @param[in] node Node whose schema node to get.
- * @return Schema node even for an opaque node, NULL if none found.
- */
-const struct lysc_node *lyd_parser_node_schema(const struct lyd_node *node);
-
 /**
  * @brief Check that a data node representing the @p snode is suitable based on options.
  *
@@ -384,6 +358,7 @@ LY_ERR lyd_parser_check_schema(struct lyd_ctx *lydctx, const struct lysc_node *s
  *
  * @param[in] lydctx Data parser context.
  * @param[in] schema Schema node of the new data node.
+ * @param[in] lnode Parent data node for logging.
  * @param[in] value String value to be parsed.
  * @param[in] value_size_bits Size of @p value in bits, must be set correctly.
  * @param[in,out] dynamic Flag if @p value is dynamically allocated, is adjusted when @p value is consumed.
@@ -395,9 +370,9 @@ LY_ERR lyd_parser_check_schema(struct lyd_ctx *lydctx, const struct lysc_node *s
  * @return LY_EINCOMPLETE in case data tree is needed to finish the validation.
  * @return LY_ERR value if an error occurred.
  */
-LY_ERR lyd_parser_create_term(struct lyd_ctx *lydctx, const struct lysc_node *schema, const void *value,
-        uint32_t value_size_bits, ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints,
-        struct lyd_node **node);
+LY_ERR lyd_parser_create_term(struct lyd_ctx *lydctx, const struct lysc_node *schema, const struct lyd_node *lnode,
+        const void *value, uint32_t value_size_bits, ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data,
+        uint32_t hints, struct lyd_node **node);
 
 /**
  * @brief Wrapper around ::lyd_create_meta() for data parsers.
@@ -415,11 +390,13 @@ LY_ERR lyd_parser_create_term(struct lyd_ctx *lydctx, const struct lysc_node *sc
  * @param[in] prefix_data Prefix format data (see ::ly_resolve_prefix()).
  * @param[in] hints [Value hint](@ref lydvalhints) from the parser regarding the value type.
  * @param[in] ctx_node Value context node.
+ * @param[in] lnode Data node for logging.
  * @return LY_ERR value.
  */
 LY_ERR lyd_parser_create_meta(struct lyd_ctx *lydctx, struct lyd_node *parent, struct lyd_meta **meta,
         const struct lys_module *mod, const char *name, uint32_t name_len, const void *value, uint32_t value_size_bits,
-        ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node);
+        ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
+        const struct lyd_node *lnode);
 
 /**
  * @brief Check that a list has all its keys.
@@ -462,7 +439,6 @@ void lyd_parser_node_free(struct lyd_node **first_p, struct lyd_node **node);
 /**
  * @brief Insert a parsed node.
  *
- * @param[in] ext Extension instance if @p node was parsed for one.
  * @param[in] parent Data node parent, if any.
  * @param[in,out] first_p First sibling on the level, if any.
  * @param[in] insert_anchor Optional insert anchor to use.
@@ -470,8 +446,8 @@ void lyd_parser_node_free(struct lyd_node **first_p, struct lyd_node **node);
  * @param[in] node Node to insert.
  * @return LY_ERR value.
  */
-LY_ERR lyd_parser_node_insert(const struct lysc_ext_instance *ext, struct lyd_node *parent, struct lyd_node **first_p,
-        struct lyd_node *insert_anchor, uint32_t parse_opts, struct lyd_node *node);
+LY_ERR lyd_parser_node_insert(struct lyd_node *parent, struct lyd_node **first_p, struct lyd_node *insert_anchor,
+        uint32_t parse_opts, struct lyd_node *node);
 
 /**
  * @brief Parse an instance extension statement.
