@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief LYB data parser for libyang
  *
- * Copyright (c) 2020 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2020 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -39,6 +39,7 @@
 #include "tree_data_internal.h"
 #include "tree_edit.h"
 #include "tree_schema.h"
+#include "tree_schema_internal.h"
 #include "validation.h"
 #include "xml.h"
 
@@ -578,7 +579,8 @@ cleanup:
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, uint32_t metadata_count, struct lyd_meta **meta)
+lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, uint32_t metadata_count,
+        struct lyd_meta **meta)
 {
     LY_ERR rc = LY_SUCCESS;
     ly_bool dynamic;
@@ -612,7 +614,7 @@ lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent,
         /* get metadata type */
         ant = lyd_get_meta_annotation(mod, meta_name, strlen(meta_name));
         if (!ant) {
-            LOGVAL(lybctx->parse_ctx->ctx, LYVE_REFERENCE, "Annotation definition for metadata \"%s:%s\" not found.",
+            LOGVAL(lybctx->parse_ctx->ctx, NULL, LYVE_REFERENCE, "Annotation definition for metadata \"%s:%s\" not found.",
                     mod->name, meta_name);
             rc = LY_EINT;
             goto cleanup;
@@ -626,7 +628,7 @@ lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent,
 
         /* create metadata */
         rc = lyd_parser_create_meta((struct lyd_ctx *)lybctx, NULL, meta, mod, meta_name, strlen(meta_name), value,
-                value_size_bits, &dynamic, LY_VALUE_LYB, NULL, LYD_HINT_DATA, sparent);
+                value_size_bits, &dynamic, LY_VALUE_LYB, NULL, LYD_HINT_DATA, sparent, NULL);
 
         /* free strings */
         free(meta_name);
@@ -915,11 +917,7 @@ lyb_parse_schema_hash(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
     /* find our node with matching hashes */
     sibling = NULL;
     while (1) {
-        if (!sparent && lybctx->ext) {
-            sibling = lys_getnext_ext(sibling, sparent, lybctx->ext, getnext_opts);
-        } else {
-            sibling = lys_getnext(sibling, sparent, mod ? mod->compiled : NULL, getnext_opts);
-        }
+        sibling = lys_getnext(sibling, sparent, mod ? mod->compiled : NULL, getnext_opts);
         if (!sibling) {
             break;
         }
@@ -931,10 +929,7 @@ lyb_parse_schema_hash(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
     }
 
     if (!sibling) {
-        if (lybctx->ext) {
-            LOGERR(lybctx->parse_ctx->ctx, LY_EINT, "Failed to find matching hash for a node from \"%s\" extension instance node.",
-                    lybctx->ext->def->name);
-        } else if (mod) {
+        if (mod) {
             LOGERR(lybctx->parse_ctx->ctx, LY_EINT, "Failed to find matching hash for a top-level node from \"%s\".",
                     mod->name);
         } else {
@@ -952,33 +947,31 @@ lyb_parse_schema_hash(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
 }
 
 /**
- * @brief Parse schema node name of a nested extension data node.
+ * @brief Parse schema node name of an extension data node.
  *
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent.
  * @param[in] mod_name Module name of the node.
- * @param[out] snode Parsed found schema node of a nested extension.
+ * @param[out] snode Parsed found schema node of an extension.
+ * @param[out] ext Ext instance of @p snode.
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_parse_schema_nested_ext(struct lyd_lyb_ctx *lybctx, const struct lyd_node *parent, const char *mod_name,
-        const struct lysc_node **snode)
+lyb_parse_schema_ext(struct lyd_lyb_ctx *lybctx, const struct lyd_node *parent, const char *mod_name,
+        const struct lysc_node **snode, struct lysc_ext_instance **ext)
 {
     LY_ERR rc = LY_SUCCESS, r;
     char *name = NULL;
-    struct lysc_ext_instance *ext;
-
-    assert(parent);
 
     /* read schema node name */
     LY_CHECK_GOTO(rc = lyb_read_string(&name, lybctx->parse_ctx), cleanup);
 
     /* check for extension data */
-    r = ly_nested_ext_schema(parent, NULL, mod_name, mod_name ? strlen(mod_name) : 0, LY_VALUE_JSON, NULL, name,
-            strlen(name), snode, &ext);
+    r = lys_find_child_node_ext(lybctx->parse_ctx->ctx, NULL, parent, NULL, mod_name, mod_name ? strlen(mod_name) : 0,
+            LY_VALUE_JSON, NULL, name, strlen(name), 0, snode, ext);
     if (r == LY_ENOT) {
         /* failed to parse */
-        LOGERR(lybctx->parse_ctx->ctx, LY_EINVAL, "Failed to parse node \"%s\" as nested extension instance data.", name);
+        LOGERR(lybctx->parse_ctx->ctx, LY_EINVAL, "Failed to parse node \"%s\" as extension instance data.", name);
         rc = LY_EINVAL;
         goto cleanup;
     } else if (r) {
@@ -1014,12 +1007,8 @@ lyb_insert_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_
         struct ly_set *parsed)
 {
     /* insert, keep first pointer correct */
-    if (parent && (LYD_CTX(parent) != LYD_CTX(node))) {
-        lyplg_ext_insert(parent, node);
-    } else {
-        lyd_insert_node(parent, first_p, node,
-                lybctx->parse_opts & LYD_PARSE_ORDERED ? LYD_INSERT_NODE_LAST : LYD_INSERT_NODE_DEFAULT);
-    }
+    lyd_insert_node(parent, first_p, node,
+            lybctx->parse_opts & LYD_PARSE_ORDERED ? LYD_INSERT_NODE_LAST : LYD_INSERT_NODE_DEFAULT);
     while (!parent && (*first_p)->prev->next) {
         *first_p = (*first_p)->prev;
     }
@@ -1065,15 +1054,16 @@ lyb_finish_opaq(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent of the sibling, must be set if @p first_p is not.
  * @param[in] flags Node flags to set.
+ * @param[in] ext Ext instance of @p node, if any.
  * @param[in,out] meta Metadata to be attached. Finally set to NULL.
  * @param[in,out] node Parsed node to finish.
  * @param[in,out] first_p First top-level sibling, must be set if @p parent is not.
  * @param[out] parsed Set of all successfully parsed nodes.
  * @return LY_ERR value.
  */
-static void
-lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t flags, struct lyd_meta **meta,
-        struct lyd_node **node, struct lyd_node **first_p, struct ly_set *parsed)
+static LY_ERR
+lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t flags, const struct lysc_ext_instance *ext,
+        struct lyd_meta **meta, struct lyd_node **node, struct lyd_node **first_p, struct ly_set *parsed)
 {
     struct lyd_meta *m;
 
@@ -1091,11 +1081,17 @@ lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t fl
     lyb_insert_node(lybctx, parent, *node, first_p, parsed);
 
     if (!(lybctx->parse_opts & LYD_PARSE_ONLY)) {
+        if (ext) {
+            /* parsed for an extension, validate the subtree using the same extension */
+            LY_CHECK_RET(lyd_validate_tree_ext(*node, ext, &lybctx->ext_val));
+        }
+
         /* store for ext instance node validation, if needed */
-        (void)lyd_validate_node_ext(*node, &lybctx->ext_val);
+        LY_CHECK_RET(lyd_validate_node_ext(*node, &lybctx->ext_val));
     }
 
     *node = NULL;
+    return LY_SUCCESS;
 }
 
 /**
@@ -1109,7 +1105,8 @@ lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t fl
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_parse_node_header(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, uint32_t metadata_count, uint32_t *flags, struct lyd_meta **meta)
+lyb_parse_node_header(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, uint32_t metadata_count,
+        uint32_t *flags, struct lyd_meta **meta)
 {
     /* create and read metadata */
     LY_CHECK_RET(lyb_parse_metadata(lybctx, sparent, metadata_count, meta));
@@ -1132,11 +1129,13 @@ lyb_parse_node_header(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
  *
  * @param[in] lybctx LYB context.
  * @param[in] snode Schema of the term node.
+ * @param[in] lnode Parent data node for logging.
  * @param[out] node Created term node.
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_create_term(struct lyd_lyb_ctx *lybctx, const struct lysc_node *snode, struct lyd_node **node)
+lyb_create_term(struct lyd_lyb_ctx *lybctx, const struct lysc_node *snode, const struct lyd_node *lnode,
+        struct lyd_node **node)
 {
     LY_ERR rc;
     ly_bool dynamic;
@@ -1148,7 +1147,7 @@ lyb_create_term(struct lyd_lyb_ctx *lybctx, const struct lysc_node *snode, struc
     dynamic = 1;
 
     /* create node */
-    rc = lyd_parser_create_term((struct lyd_ctx *)lybctx, snode, value, value_size_bits, &dynamic, LY_VALUE_LYB,
+    rc = lyd_parser_create_term((struct lyd_ctx *)lybctx, snode, lnode, value, value_size_bits, &dynamic, LY_VALUE_LYB,
             NULL, LYD_HINT_DATA, node);
     if (dynamic) {
         free(value);
@@ -1242,9 +1241,6 @@ lyb_parse_node_opaq(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct
             value, strlen(value), &dynamic, format, val_prefix_data, LYD_HINT_DATA, &node);
     LY_CHECK_ERR_GOTO(ret, ly_free_prefix_data(format, val_prefix_data), cleanup);
 
-    assert(node);
-    LOG_LOCSET(NULL, node);
-
     /* process children */
     ret = lyb_parse_siblings(lybctx, node, 0, NULL, NULL);
     LY_CHECK_GOTO(ret, cleanup);
@@ -1253,13 +1249,9 @@ lyb_parse_node_opaq(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct
         /* register parsed opaq node */
         lyb_finish_opaq(lybctx, parent, &attr, &node, first_p, parsed);
         assert(!attr && !node);
-        LOG_LOCBACK(0, 1);
     } /* else is freed */
 
 cleanup:
-    if (node) {
-        LOG_LOCBACK(0, 1);
-    }
     free(prefix);
     free(module_key);
     free(name);
@@ -1278,15 +1270,16 @@ cleanup:
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent of the sibling.
  * @param[in] snode Schema of the node to be parsed.
+ * @param[in] ext Ext instance of @p snode, if any.
  * @param[in,out] first_p First top-level sibling.
  * @param[out] parsed Set of all successfully parsed nodes.
  * @return LY_ERR value.
  */
 static LY_ERR
 lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const struct lysc_node *snode,
-        struct lyd_node **first_p, struct ly_set *parsed)
+        const struct lysc_ext_instance *ext, struct lyd_node **first_p, struct ly_set *parsed)
 {
-    LY_ERR rc;
+    LY_ERR rc = LY_SUCCESS;
     struct lyd_node *node = NULL, *tree = NULL;
     struct lyd_meta *meta = NULL;
     LYD_ANYDATA_VALUETYPE value_type = 0;
@@ -1296,7 +1289,7 @@ lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const st
 
     /* read necessary basic data */
     rc = lyb_parse_node_header(lybctx, snode, UINT32_MAX, &flags, &meta);
-    LY_CHECK_GOTO(rc, error);
+    LY_CHECK_GOTO(rc, cleanup);
 
     /* parse value type */
     lyb_read_count((uint32_t *)&value_type, lybctx->parse_ctx);
@@ -1314,11 +1307,11 @@ lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const st
         rc = lyb_parse_siblings(lybctx, NULL, 0, &tree, NULL);
         lybctx->parse_opts = prev_parse_opts;
         lybctx->int_opts = prev_int_opts;
-        LY_CHECK_GOTO(rc, error);
+        LY_CHECK_GOTO(rc, cleanup);
 
         /* use the data tree value */
-        rc = lyd_create_any(snode, tree, value_type, 1, &node);
-        LY_CHECK_GOTO(rc, error);
+        rc = lyd_create_any(snode, tree, value_type, 1, 0, &node);
+        LY_CHECK_GOTO(rc, cleanup);
         tree = NULL;
         break;
     case LYD_ANYDATA_STRING:
@@ -1326,29 +1319,24 @@ lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const st
     case LYD_ANYDATA_JSON:
         /* string value */
         rc = lyb_read_string(&value, lybctx->parse_ctx);
-        LY_CHECK_GOTO(rc, error);
+        LY_CHECK_GOTO(rc, cleanup);
 
         /* use the string value */
-        rc = lyd_create_any(snode, value, value_type, 1, &node);
-        LY_CHECK_GOTO(rc, error);
+        rc = lyd_create_any(snode, value, value_type, 1, 0, &node);
+        LY_CHECK_GOTO(rc, cleanup);
         value = NULL;
         break;
     default:
         LOGINT(ctx);
         rc = LY_EINT;
-        goto error;
+        goto cleanup;
     }
 
-    assert(node);
-    LOG_LOCSET(NULL, node);
-
     /* register parsed anydata node */
-    lyb_finish_node(lybctx, parent, flags, &meta, &node, first_p, parsed);
+    rc = lyb_finish_node(lybctx, parent, flags, ext, &meta, &node, first_p, parsed);
+    LY_CHECK_GOTO(rc, cleanup);
 
-    LOG_LOCBACK(0, 1);
-    return LY_SUCCESS;
-
-error:
+cleanup:
     lyd_free_meta_siblings(meta);
     lyd_free_siblings(tree);
     free(value);
@@ -1362,37 +1350,35 @@ error:
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent of the sibling, must be set if @p first is not.
  * @param[in] snode Schema of the node to be parsed.
+ * @param[in] ext Ext instance of @p snode, if any.
  * @param[in,out] first_p First top-level sibling, must be set if @p parent is not.
  * @param[out] parsed Set of all successfully parsed nodes.
  * @return LY_ERR value.
  */
 static LY_ERR
 lyb_parse_node_inner(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const struct lysc_node *snode,
-        struct lyd_node **first_p, struct ly_set *parsed)
+        const struct lysc_ext_instance *ext, struct lyd_node **first_p, struct ly_set *parsed)
 {
-    LY_ERR rc;
+    LY_ERR rc = LY_SUCCESS;
     struct lyd_node *node = NULL;
     struct lyd_meta *meta = NULL;
     uint32_t flags = 0;
 
     /* read necessary basic data */
     rc = lyb_parse_node_header(lybctx, snode, UINT32_MAX, &flags, &meta);
-    LY_CHECK_GOTO(rc, error);
+    LY_CHECK_GOTO(rc, cleanup);
 
     /* create node */
     rc = lyd_create_inner(snode, &node);
-    LY_CHECK_GOTO(rc, error);
-
-    assert(node);
-    LOG_LOCSET(NULL, node);
+    LY_CHECK_GOTO(rc, cleanup);
 
     /* process children */
     rc = lyb_parse_siblings(lybctx, node, 0, NULL, NULL);
-    LY_CHECK_GOTO(rc, error);
+    LY_CHECK_GOTO(rc, cleanup);
 
     /* additional procedure for inner node */
     rc = lyb_validate_node_inner(lybctx, node);
-    LY_CHECK_GOTO(rc, error);
+    LY_CHECK_GOTO(rc, cleanup);
 
     if (snode->nodetype & (LYS_RPC | LYS_ACTION | LYS_NOTIF)) {
         /* rememeber the RPC/action/notification */
@@ -1400,15 +1386,10 @@ lyb_parse_node_inner(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const
     }
 
     /* register parsed node */
-    lyb_finish_node(lybctx, parent, flags, &meta, &node, first_p, parsed);
+    rc = lyb_finish_node(lybctx, parent, flags, ext, &meta, &node, first_p, parsed);
+    LY_CHECK_GOTO(rc, cleanup);
 
-    LOG_LOCBACK(0, 1);
-    return LY_SUCCESS;
-
-error:
-    if (node) {
-        LOG_LOCBACK(0, 1);
-    }
+cleanup:
     lyd_free_meta_siblings(meta);
     lyd_free_tree(node);
     return rc;
@@ -1420,6 +1401,7 @@ error:
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent of the sibling.
  * @param[in] snode Schema of the node to be parsed.
+ * @param[in] ext Ext instance of @p snode, if any.
  * @param[in] metadata_count Number of metadata already read for the node.
  * @param[in,out] first_p First top-level sibling.
  * @param[out] parsed Set of all successfully parsed nodes.
@@ -1427,33 +1409,28 @@ error:
  */
 static LY_ERR
 lyb_parse_node_leaf(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const struct lysc_node *snode,
-        uint32_t metadata_count, struct lyd_node **first_p, struct ly_set *parsed)
+        const struct lysc_ext_instance *ext, uint32_t metadata_count, struct lyd_node **first_p, struct ly_set *parsed)
 {
-    LY_ERR ret;
+    LY_ERR rc = LY_SUCCESS;
     struct lyd_node *node = NULL;
     struct lyd_meta *meta = NULL;
     uint32_t flags = 0;
 
     /* read necessary basic data */
-    ret = lyb_parse_node_header(lybctx, snode, metadata_count, &flags, &meta);
-    LY_CHECK_GOTO(ret, error);
+    rc = lyb_parse_node_header(lybctx, snode, metadata_count, &flags, &meta);
+    LY_CHECK_GOTO(rc, cleanup);
 
     /* read value of term node and create it */
-    ret = lyb_create_term(lybctx, snode, &node);
-    LY_CHECK_GOTO(ret, error);
+    rc = lyb_create_term(lybctx, snode, parent, &node);
+    LY_CHECK_GOTO(rc, cleanup);
 
-    assert(node);
-    LOG_LOCSET(NULL, node);
+    rc = lyb_finish_node(lybctx, parent, flags, ext, &meta, &node, first_p, parsed);
+    LY_CHECK_GOTO(rc, cleanup);
 
-    lyb_finish_node(lybctx, parent, flags, &meta, &node, first_p, parsed);
-
-    LOG_LOCBACK(0, 1);
-    return LY_SUCCESS;
-
-error:
+cleanup:
     lyd_free_meta_siblings(meta);
     lyd_free_tree(node);
-    return ret;
+    return rc;
 }
 
 /**
@@ -1468,7 +1445,7 @@ error:
  */
 static LY_ERR
 lyb_parse_node_leaflist(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const struct lysc_node *snode,
-        struct lyd_node **first_p, struct ly_set *parsed)
+        const struct lysc_ext_instance *ext, struct lyd_node **first_p, struct ly_set *parsed)
 {
     uint32_t metadata_count;
 
@@ -1482,7 +1459,7 @@ lyb_parse_node_leaflist(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, con
         }
 
         /* next instance */
-        LY_CHECK_RET(lyb_parse_node_leaf(lybctx, parent, snode, metadata_count, first_p, parsed));
+        LY_CHECK_RET(lyb_parse_node_leaf(lybctx, parent, snode, ext, metadata_count, first_p, parsed));
     }
 
     return LY_SUCCESS;
@@ -1494,19 +1471,19 @@ lyb_parse_node_leaflist(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, con
  * @param[in] lybctx LYB context.
  * @param[in] parent Data parent of the sibling.
  * @param[in] snode Schema of the nodes to be parsed.
+ * @param[in] ext Ext instance of @p snode, if any.
  * @param[in,out] first_p First top-level sibling.
  * @param[out] parsed Set of all successfully parsed nodes.
  * @return LY_ERR value.
  */
 static LY_ERR
 lyb_parse_node_list(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const struct lysc_node *snode,
-        struct lyd_node **first_p, struct ly_set *parsed)
+        const struct lysc_ext_instance *ext, struct lyd_node **first_p, struct ly_set *parsed)
 {
-    LY_ERR rc;
+    LY_ERR rc = LY_SUCCESS;
     struct lyd_node *node = NULL;
     struct lyd_meta *meta = NULL;
     uint32_t flags = 0, metadata_count;
-    ly_bool log_node = 0;
 
     while (1) {
         /* read metadata count to check for end of instances */
@@ -1519,23 +1496,19 @@ lyb_parse_node_list(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const s
 
         /* read necessary basic data */
         rc = lyb_parse_node_header(lybctx, snode, metadata_count, &flags, &meta);
-        LY_CHECK_GOTO(rc, error);
+        LY_CHECK_GOTO(rc, cleanup);
 
         /* create list node */
         rc = lyd_create_inner(snode, &node);
-        LY_CHECK_GOTO(rc, error);
-
-        assert(node);
-        LOG_LOCSET(NULL, node);
-        log_node = 1;
+        LY_CHECK_GOTO(rc, cleanup);
 
         /* process children */
         rc = lyb_parse_siblings(lybctx, node, 0, NULL, NULL);
-        LY_CHECK_GOTO(rc, error);
+        LY_CHECK_GOTO(rc, cleanup);
 
         /* additional procedure for inner node */
         rc = lyb_validate_node_inner(lybctx, node);
-        LY_CHECK_GOTO(rc, error);
+        LY_CHECK_GOTO(rc, cleanup);
 
         if (snode->nodetype & (LYS_RPC | LYS_ACTION | LYS_NOTIF)) {
             /* rememeber the RPC/action/notification */
@@ -1543,18 +1516,11 @@ lyb_parse_node_list(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const s
         }
 
         /* register parsed list node */
-        lyb_finish_node(lybctx, parent, flags, &meta, &node, first_p, parsed);
-
-        LOG_LOCBACK(0, 1);
-        log_node = 0;
+        rc = lyb_finish_node(lybctx, parent, flags, ext, &meta, &node, first_p, parsed);
+        LY_CHECK_GOTO(rc, cleanup);
     }
 
-    return LY_SUCCESS;
-
-error:
-    if (log_node) {
-        LOG_LOCBACK(0, 1);
-    }
+cleanup:
     lyd_free_meta_siblings(meta);
     lyd_free_tree(node);
     return rc;
@@ -1576,6 +1542,7 @@ lyb_parse_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_n
 {
     LY_ERR rc = LY_SUCCESS;
     const struct lysc_node *snode;
+    struct lysc_ext_instance *ext = NULL;
     const struct lys_module *mod;
     enum lylyb_node_type lyb_type = 0;
 
@@ -1603,29 +1570,29 @@ lyb_parse_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_n
         break;
     case LYB_NODE_CHILD:
         /* read hash, find the schema node starting from parent schema, if any */
-        LY_CHECK_GOTO(rc = lyb_parse_schema_hash(lybctx, lyd_parser_node_schema(parent), NULL, &snode), cleanup);
+        LY_CHECK_GOTO(rc = lyb_parse_schema_hash(lybctx, parent ? parent->schema : NULL, NULL, &snode), cleanup);
         break;
     case LYB_NODE_EXT:
         /* ext, read module name, always unshrinked format */
         LY_CHECK_GOTO(rc = lyb_parse_module(lybctx, &mod), cleanup);
 
-        /* read schema node name, find the nested ext schema node */
-        LY_CHECK_GOTO(rc = lyb_parse_schema_nested_ext(lybctx, parent, mod->name, &snode), cleanup);
+        /* read schema node name, find the ext schema node */
+        LY_CHECK_GOTO(rc = lyb_parse_schema_ext(lybctx, parent, mod->name, &snode, &ext), cleanup);
         break;
     }
 
     if (!snode) {
         rc = lyb_parse_node_opaq(lybctx, parent, first_p, parsed);
     } else if (snode->nodetype & LYS_LEAFLIST) {
-        rc = lyb_parse_node_leaflist(lybctx, parent, snode, first_p, parsed);
+        rc = lyb_parse_node_leaflist(lybctx, parent, snode, ext, first_p, parsed);
     } else if (snode->nodetype == LYS_LIST) {
-        rc = lyb_parse_node_list(lybctx, parent, snode, first_p, parsed);
+        rc = lyb_parse_node_list(lybctx, parent, snode, ext, first_p, parsed);
     } else if (snode->nodetype & LYD_NODE_ANY) {
-        rc = lyb_parse_node_any(lybctx, parent, snode, first_p, parsed);
+        rc = lyb_parse_node_any(lybctx, parent, snode, ext, first_p, parsed);
     } else if (snode->nodetype & LYD_NODE_INNER) {
-        rc = lyb_parse_node_inner(lybctx, parent, snode, first_p, parsed);
+        rc = lyb_parse_node_inner(lybctx, parent, snode, ext, first_p, parsed);
     } else {
-        rc = lyb_parse_node_leaf(lybctx, parent, snode, UINT32_MAX, first_p, parsed);
+        rc = lyb_parse_node_leaf(lybctx, parent, snode, ext, UINT32_MAX, first_p, parsed);
     }
     LY_CHECK_GOTO(rc, cleanup);
 
@@ -1755,9 +1722,8 @@ lyb_parse_header(struct lyd_lyb_ctx *lybctx)
 }
 
 LY_ERR
-lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
-        struct ly_set *parsed, ly_bool *subtree_sibling, struct lyd_ctx **lydctx_p)
+lyd_parse_lyb(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_in *in,
+        uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts, struct ly_set *parsed, struct lyd_ctx **lydctx_p)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lyd_lyb_ctx *lybctx = NULL;
@@ -1765,17 +1731,11 @@ lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     assert(!(parse_opts & ~LYD_PARSE_OPTS_MASK));
     assert(!(val_opts & ~LYD_VALIDATE_OPTS_MASK));
 
-    LY_CHECK_ARG_RET(ctx, !(parse_opts & LYD_PARSE_SUBTREE), LY_EINVAL);
-
     if (!(ctx->opts & LY_CTX_LYB_HASHES)) {
         /* generate LYB hashes */
         LY_CHECK_GOTO(rc = ly_ctx_set_options((struct ly_ctx *)ctx, LY_CTX_LYB_HASHES), cleanup);
     }
 
-    if (subtree_sibling) {
-        *subtree_sibling = 0;
-    }
-
     lybctx = calloc(1, sizeof *lybctx);
     LY_CHECK_ERR_GOTO(!lybctx, LOGMEM(ctx); rc = LY_EMEM, cleanup);
     lybctx->parse_ctx = calloc(1, sizeof *lybctx->parse_ctx);
@@ -1787,7 +1747,6 @@ lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     lybctx->val_opts = val_opts;
     lybctx->int_opts = int_opts;
     lybctx->free = lyb_parse_ctx_free;
-    lybctx->ext = ext;
 
     /* find the operation node if it exists already */
     LY_CHECK_GOTO(rc = lyd_parser_find_operation(parent, int_opts, &lybctx->op_node), cleanup);
@@ -1805,7 +1764,7 @@ lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     LY_CHECK_GOTO(rc, cleanup);
 
     if ((int_opts & (LYD_INTOPT_RPC | LYD_INTOPT_ACTION | LYD_INTOPT_NOTIF | LYD_INTOPT_REPLY)) && !lybctx->op_node) {
-        LOGVAL(ctx, LYVE_DATA, "Missing the operation node.");
+        LOGVAL(ctx, NULL, LYVE_DATA, "Missing the operation node.");
         rc = LY_EVALID;
         goto cleanup;
     }
