@@ -56,24 +56,25 @@ lyd_xml_ctx_free(struct lyd_ctx *lydctx)
 /**
  * @brief Log namespace error.
  *
- * @param[in] xmlctx XML context
+ * @param[in] ctx Context for logging.
+ * @param[in] lnode Data node to log.
  * @param[in] prefix XML prefix.
  * @param[in] prefix_len XML prefix length.
  * @param[in] attr_name Current XML attribute name.
  * @param[in] attr_len Current XML attribute name length.
  */
 static void
-lydxml_log_namespace_err(struct lyxml_ctx *xmlctx, const char *prefix, size_t prefix_len,
+lydxml_log_namespace_err(const struct ly_ctx *ctx, const struct lyd_node *lnode, const char *prefix, size_t prefix_len,
         const char *attr_name, size_t attr_len)
 {
     if (prefix_len && attr_len) {
-        LOGVAL(xmlctx->ctx, LYVE_REFERENCE, "Unknown XML prefix \"%.*s\" at attribute \"%.*s\".",
+        LOGVAL(ctx, lnode, LYVE_REFERENCE, "Unknown XML prefix \"%.*s\" at attribute \"%.*s\".",
                 (int)prefix_len, prefix, (int)attr_len, attr_name);
     } else if (prefix_len) {
-        LOGVAL(xmlctx->ctx, LYVE_REFERENCE, "Unknown XML prefix \"%.*s\".",
+        LOGVAL(ctx, lnode, LYVE_REFERENCE, "Unknown XML prefix \"%.*s\".",
                 (int)prefix_len, prefix);
     } else {
-        LOGVAL(xmlctx->ctx, LYVE_REFERENCE, "Missing XML namespace.");
+        LOGVAL(ctx, lnode, LYVE_REFERENCE, "Missing XML namespace.");
     }
 }
 
@@ -82,11 +83,13 @@ lydxml_log_namespace_err(struct lyxml_ctx *xmlctx, const char *prefix, size_t pr
  *
  * @param[in] lydctx XML data parser context.
  * @param[in] sparent Schema node of the parent.
+ * @param[in] lnode Parent data node for logging.
  * @param[out] meta List of created metadata instances.
  * @return LY_ERR value.
  */
 static LY_ERR
-lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, struct lyd_meta **meta)
+lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, const struct lyd_node *lnode,
+        struct lyd_meta **meta)
 {
     LY_ERR ret = LY_SUCCESS;
     const struct lyxml_ns *ns;
@@ -99,8 +102,6 @@ lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, str
 
     *meta = NULL;
 
-    LOG_LOCSET(sparent, NULL);
-
     /* check for NETCONF filter unqualified attributes */
     if (!strcmp(sparent->module->name, "notifications")) {
         /* ancient module that does not even use the extension */
@@ -122,8 +123,10 @@ lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, str
                     !ly_strncmp("select", xmlctx->name, xmlctx->name_len))) {
                 mod = ly_ctx_get_module_implemented(xmlctx->ctx, "ietf-netconf");
                 if (!mod) {
-                    LOGVAL(xmlctx->ctx, LYVE_REFERENCE,
+                    LOG_LOCSET(sparent);
+                    LOGVAL(xmlctx->ctx, lnode, LYVE_REFERENCE,
                             "Missing (or not implemented) YANG module \"ietf-netconf\" for special filter attributes.");
+                    LOG_LOCBACK(1);
                     ret = LY_ENOTFOUND;
                     goto cleanup;
                 }
@@ -131,8 +134,10 @@ lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, str
             }
 
             if (lydctx->parse_opts & LYD_PARSE_STRICT) {
-                LOGVAL(xmlctx->ctx, LYVE_REFERENCE, "Missing mandatory prefix for XML metadata \"%.*s\".",
+                LOG_LOCSET(sparent);
+                LOGVAL(xmlctx->ctx, lnode, LYVE_REFERENCE, "Missing mandatory prefix for XML metadata \"%.*s\".",
                         (int)xmlctx->name_len, xmlctx->name);
+                LOG_LOCBACK(1);
                 /* If LYD_VALIDATE_MULTI_ERROR is set, then continue parsing, because otherwise the parser context
                  * will remain in a bad state, which will cause termination on some assert or undefined behavior.
                  */
@@ -149,7 +154,9 @@ lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, str
         /* get namespace of the attribute to find its annotation definition */
         ns = lyxml_ns_get(&xmlctx->ns, xmlctx->prefix, xmlctx->prefix_len);
         if (!ns) {
-            lydxml_log_namespace_err(xmlctx, xmlctx->prefix, xmlctx->prefix_len, xmlctx->name, xmlctx->name_len);
+            LOG_LOCSET(sparent);
+            lydxml_log_namespace_err(xmlctx->ctx, lnode, xmlctx->prefix, xmlctx->prefix_len, xmlctx->name, xmlctx->name_len);
+            LOG_LOCBACK(1);
             ret = LY_ENOTFOUND;
             goto cleanup;
         }
@@ -158,10 +165,12 @@ lydxml_metadata(struct lyd_xml_ctx *lydctx, const struct lysc_node *sparent, str
         mod = ly_ctx_get_module_implemented_ns(xmlctx->ctx, ns->uri);
         if (!mod) {
             if (lydctx->parse_opts & LYD_PARSE_STRICT) {
-                LOGVAL(xmlctx->ctx, LYVE_REFERENCE,
+                LOG_LOCSET(sparent);
+                LOGVAL(xmlctx->ctx, lnode, LYVE_REFERENCE,
                         "Unknown (or not implemented) YANG module with namespace \"%s\" for metadata \"%.*s%s%.*s\".",
                         ns->uri, (int)xmlctx->prefix_len, xmlctx->prefix, xmlctx->prefix_len ? ":" : "",
                         (int)xmlctx->name_len, xmlctx->name);
+                LOG_LOCBACK(1);
                 ret = LY_ENOTFOUND;
                 goto cleanup;
             }
@@ -182,7 +191,7 @@ create_meta:
 
         /* create metadata */
         ret = lyd_parser_create_meta((struct lyd_ctx *)lydctx, NULL, meta, mod, name, name_len, xmlctx->value,
-                xmlctx->value_len * 8, &xmlctx->dynamic, LY_VALUE_XML, &xmlctx->ns, LYD_HINT_DATA, sparent);
+                xmlctx->value_len * 8, &xmlctx->dynamic, LY_VALUE_XML, &xmlctx->ns, LYD_HINT_DATA, sparent, lnode);
         LY_CHECK_GOTO(ret, cleanup);
 
         /* next attribute */
@@ -190,7 +199,6 @@ create_meta:
     }
 
 cleanup:
-    LOG_LOCBACK(1, 0);
     if (ret) {
         lyd_free_meta_siblings(*meta);
         *meta = NULL;
@@ -199,7 +207,7 @@ cleanup:
 }
 
 static LY_ERR
-lydxml_attrs(struct lyxml_ctx *xmlctx, struct lyd_attr **attr)
+lydxml_attrs(struct lyxml_ctx *xmlctx, const struct lyd_node *lnode, struct lyd_attr **attr)
 {
     LY_ERR ret = LY_SUCCESS;
     const struct lyxml_ns *ns;
@@ -240,7 +248,7 @@ lydxml_attrs(struct lyxml_ctx *xmlctx, struct lyd_attr **attr)
         if (prefix_len) {
             ns = lyxml_ns_get(&xmlctx->ns, prefix, prefix_len);
             if (!ns) {
-                lydxml_log_namespace_err(xmlctx, prefix, prefix_len, name, name_len);
+                lydxml_log_namespace_err(xmlctx->ctx, lnode, prefix, prefix_len, name, name_len);
                 ret = LY_EVALID;
                 goto cleanup;
             }
@@ -273,6 +281,13 @@ cleanup:
     return ret;
 }
 
+/**
+ * @brief Check the current element is a valid list instance.
+ *
+ * @param[in] lydctx Parsed context.
+ * @param[in] list List schema node to use.
+ * @return LY_ERR value.
+ */
 static LY_ERR
 lydxml_check_list(struct lyd_xml_ctx *lydctx, const struct lysc_node *list)
 {
@@ -316,7 +331,7 @@ lydxml_check_list(struct lyd_xml_ctx *lydctx, const struct lysc_node *list)
         if (i < key_set.count) {
             /* validate the value */
             r = ly_value_validate(NULL, snode, xmlctx->value, xmlctx->value_len * 8, LY_VALUE_XML, &xmlctx->ns,
-                    LYD_HINT_DATA, lydctx->ext);
+                    LYD_HINT_DATA);
             if (!r) {
                 /* key with a valid value, remove from the set */
                 ly_set_rm_index(&key_set, i, NULL);
@@ -424,8 +439,7 @@ lydxml_data_check_opaq(struct lyd_xml_ctx *lydctx, const struct lysc_node **snod
     if ((*snode)->nodetype & LYD_NODE_TERM) {
         /* value may not be valid in which case we parse it as an opaque node */
         prev_lo = ly_temp_log_options(&temp_lo);
-        r = ly_value_validate(NULL, *snode, xmlctx->value, xmlctx->value_len * 8, LY_VALUE_XML, &xmlctx->ns,
-                LYD_HINT_DATA, lydctx->ext);
+        r = ly_value_validate(NULL, *snode, xmlctx->value, xmlctx->value_len * 8, LY_VALUE_XML, &xmlctx->ns, LYD_HINT_DATA);
         ly_temp_log_options(prev_lo);
         if (r) {
             LOGVRB("Parsing opaque term node \"%s\" with invalid value \"%.*s\".", (*snode)->name, (int)xmlctx->value_len,
@@ -553,7 +567,8 @@ lydxml_subtree_get_snode(struct lyd_xml_ctx *lydctx, const struct lyd_node *pare
     struct lyxml_ctx *xmlctx;
     const struct ly_ctx *ctx;
     const struct lyxml_ns *ns;
-    struct lys_module *mod;
+    const struct lys_module *mod = NULL;
+    const struct lysc_node *sparent;
     uint32_t getnext_opts;
 
     xmlctx = lydctx->xmlctx;
@@ -563,84 +578,61 @@ lydxml_subtree_get_snode(struct lyd_xml_ctx *lydctx, const struct lyd_node *pare
     *snode = NULL;
     *ext = NULL;
 
-    /* get current namespace */
-    ns = lyxml_ns_get(&xmlctx->ns, prefix, prefix_len);
-    if (!ns) {
-        if (lydctx->int_opts & LYD_INTOPT_ANY) {
-            goto unknown_module;
-        }
-        lydxml_log_namespace_err(xmlctx, prefix, prefix_len, NULL, 0);
-        return LY_EVALID;
-    }
-
-    /* get the element module, use parent context if possible because of extensions */
-    mod = ly_ctx_get_module_implemented_ns(parent ? LYD_CTX(parent) : ctx, ns->uri);
-    if (!mod) {
-        /* check for extension data */
-        r = ly_nested_ext_schema(parent, NULL, prefix, prefix_len, LY_VALUE_XML, &lydctx->xmlctx->ns, name, name_len,
-                snode, ext);
-        if (r != LY_ENOT) {
-            /* success or error */
-            return r;
-        }
-
-unknown_module:
-        if (lydctx->parse_opts & LYD_PARSE_STRICT) {
-            if (ns) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No module with namespace \"%s\" in the context.", ns->uri);
-            } else if (prefix_len) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No module with namespace \"%.*s\" in the context.", (int)prefix_len, prefix);
-            } else {
-                LOGVAL(ctx, LYVE_REFERENCE, "No default namespace in the context.");
-            }
-            return LY_EVALID;
-        }
-        return LY_SUCCESS;
-    }
-
-    /* get the schema node */
-    if (!parent && lydctx->ext) {
-        *snode = lysc_ext_find_node(lydctx->ext, mod, name, name_len, 0, getnext_opts);
+    /* try to find parent schema node */
+    if (parent && parent->schema && !(parent->schema->nodetype & LYD_NODE_ANY)) {
+        /* use only a schema parent */
+        sparent = parent->schema;
     } else {
-        /* try to find parent schema node even if it is an opaque node (not connected to the parent) */
-        *snode = lys_find_child(lyd_parser_node_schema(parent), mod, name, name_len, 0, getnext_opts);
+        sparent = NULL;
     }
-    if (!*snode) {
-        /* check for extension data */
-        r = ly_nested_ext_schema(parent, NULL, prefix, prefix_len, LY_VALUE_XML, &lydctx->xmlctx->ns, name,
-                name_len, snode, ext);
-        if (r != LY_ENOT) {
-            /* success or error */
-            return r;
-        }
+    if (!prefix_len) {
+        prefix = NULL;
+    }
+    r = lys_find_child_node(parent ? LYD_CTX(parent) : ctx, sparent, NULL, prefix, prefix_len, LY_VALUE_XML,
+            &lydctx->xmlctx->ns, name, name_len, getnext_opts, snode, ext);
+    LY_CHECK_RET(r && (r != LY_ENOT), r);
 
-        /* unknown data node */
-        if (lydctx->parse_opts & LYD_PARSE_STRICT) {
-            if (parent) {
-                LOGVAL(ctx, LYVE_REFERENCE, "Node \"%.*s\" not found as a child of \"%s\" node.",
-                        (int)name_len, name, LYD_NAME(parent));
-            } else if (lydctx->ext) {
-                if (lydctx->ext->argument) {
-                    LOGVAL(ctx, LYVE_REFERENCE, "Node \"%.*s\" not found in the \"%s\" %s extension instance.",
-                            (int)name_len, name, lydctx->ext->argument, lydctx->ext->def->name);
-                } else {
-                    LOGVAL(ctx, LYVE_REFERENCE, "Node \"%.*s\" not found in the %s extension instance.",
-                            (int)name_len, name, lydctx->ext->def->name);
-                }
-            } else {
-                LOGVAL(ctx, LYVE_REFERENCE, "Node \"%.*s\" not found in the \"%s\" module.",
-                        (int)name_len, name, mod->name);
-            }
-            return LY_EVALID;
-        }
-        return LY_SUCCESS;
-    } else {
+    if (!r) {
         /* check that schema node is valid and can be used */
         LY_CHECK_RET(lyd_parser_check_schema((struct lyd_ctx *)lydctx, *snode));
         LY_CHECK_RET(lydxml_data_check_opaq(lydctx, snode));
+        return LY_SUCCESS;
     }
 
-    return LY_SUCCESS;
+    /* generate error, check namespace */
+    ns = lyxml_ns_get(&xmlctx->ns, prefix, prefix_len);
+    if (!ns && !(lydctx->int_opts & LYD_INTOPT_ANY)) {
+        lydxml_log_namespace_err(xmlctx->ctx, parent, prefix, prefix_len, NULL, 0);
+        return LY_EVALID;
+    }
+    if (!(lydctx->parse_opts & LYD_PARSE_STRICT)) {
+        return LY_SUCCESS;
+    }
+
+    if (ns) {
+        /* get the element module, use parent context if possible because of extensions */
+        mod = ly_ctx_get_module_implemented_ns(parent ? LYD_CTX(parent) : ctx, ns->uri);
+    }
+    if (!mod) {
+        if (ns) {
+            LOGVAL(ctx, parent, LYVE_REFERENCE, "No module with namespace \"%s\" in the context.", ns->uri);
+        } else if (prefix_len) {
+            LOGVAL(ctx, parent, LYVE_REFERENCE, "No module with namespace \"%.*s\" in the context.", (int)prefix_len, prefix);
+        } else {
+            LOGVAL(ctx, parent, LYVE_REFERENCE, "No default namespace in the context.");
+        }
+        return LY_EVALID;
+    }
+
+    /* must be an unknown node name then */
+    if (sparent) {
+        LOGVAL(ctx, parent, LYVE_REFERENCE, "Node \"%.*s\" not found as a child of \"%s\" node.",
+                (int)name_len, name, sparent->name);
+    } else {
+        LOGVAL(ctx, parent, LYVE_REFERENCE, "Node \"%.*s\" not found in the \"%s\" module.", (int)name_len, name,
+                mod->name);
+    }
+    return LY_EVALID;
 }
 
 /**
@@ -694,7 +686,7 @@ lydxml_subtree_opaq(struct lyd_xml_ctx *lydctx, const char *prefix, uint32_t pre
     ns_uri = ns ? ns->uri : NULL;
 
     /* get best-effort node hints */
-    lydxml_get_hints_opaq(name, name_len, xmlctx->value, xmlctx->value_len, parent ? lyd_child(parent) : *first_p,
+    lydxml_get_hints_opaq(name, name_len, xmlctx->value, xmlctx->value_len, parent ? lyd_child_any(parent) : *first_p,
             ns_uri, &hints, &insert_anchor);
 
     /* create the node without value */
@@ -702,11 +694,8 @@ lydxml_subtree_opaq(struct lyd_xml_ctx *lydctx, const char *prefix, uint32_t pre
             NULL, format, NULL, hints, node);
     LY_CHECK_GOTO(rc, cleanup);
 
-    assert(*node);
-    LOG_LOCSET(NULL, *node);
-
     /* insert */
-    rc = lyd_parser_node_insert(NULL, parent, first_p, insert_anchor, lydctx->parse_opts, *node);
+    rc = lyd_parser_node_insert(parent, first_p, insert_anchor, lydctx->parse_opts, *node);
     LY_CHECK_GOTO(rc, cleanup);
 
     /* parser next */
@@ -723,7 +712,8 @@ lydxml_subtree_opaq(struct lyd_xml_ctx *lydctx, const char *prefix, uint32_t pre
     opaq = (struct lyd_node_opaq *)*node;
     if (opaq->child) {
         if (!ws_only) {
-            LOGVAL(xmlctx->ctx, LYVE_SYNTAX_XML, "Mixed XML content node \"%s\" found, not supported.", LYD_NAME(opaq));
+            LOGVAL(xmlctx->ctx, *node, LYVE_SYNTAX_XML, "Mixed XML content node \"%s\" found, not supported.",
+                    LYD_NAME(opaq));
             rc = LY_EVALID;
             goto cleanup;
         }
@@ -743,9 +733,6 @@ lydxml_subtree_opaq(struct lyd_xml_ctx *lydctx, const char *prefix, uint32_t pre
     val_prefix_data = NULL;
 
 cleanup:
-    if (*node) {
-        LOG_LOCBACK(0, 1);
-    }
     ly_free_prefix_data(format, val_prefix_data);
     if (dynamic) {
         free((char *)value);
@@ -778,16 +765,15 @@ lydxml_subtree_term(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode, c
     *node = NULL;
 
     /* create node */
-    r = lyd_parser_create_term((struct lyd_ctx *)lydctx, snode, xmlctx->value, xmlctx->value_len * 8, &xmlctx->dynamic,
-            LY_VALUE_XML, &xmlctx->ns, LYD_HINT_DATA, node);
+    r = lyd_parser_create_term((struct lyd_ctx *)lydctx, snode, parent, xmlctx->value, xmlctx->value_len * 8,
+            &xmlctx->dynamic, LY_VALUE_XML, &xmlctx->ns, LYD_HINT_DATA, node);
     LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
 
-    if (*node) {
-        LOG_LOCSET(NULL, *node);
+    /* insert, needs LYD_EXT flag */
+    if (ext) {
+        (*node)->flags |= LYD_EXT;
     }
-
-    /* insert */
-    r = lyd_parser_node_insert(ext, parent, first_p, NULL, lydctx->parse_opts, *node);
+    r = lyd_parser_node_insert(parent, first_p, NULL, lydctx->parse_opts, *node);
     LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
     if (*node && parent && (snode->flags & LYS_KEY)) {
@@ -795,7 +781,7 @@ lydxml_subtree_term(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode, c
         anchor = lyd_insert_get_next_anchor(lyd_child(parent), *node);
         if (anchor && anchor->schema && (anchor->schema->flags & LYS_KEY)) {
             if (lydctx->parse_opts & LYD_PARSE_STRICT) {
-                LOGVAL(xmlctx->ctx, LYVE_DATA, "Invalid position of the key \"%s\" in a list.", snode->name);
+                LOGVAL(xmlctx->ctx, *node, LYVE_DATA, "Invalid position of the key \"%s\" in a list.", snode->name);
                 r = LY_EVALID;
                 LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
             } else {
@@ -810,16 +796,13 @@ lydxml_subtree_term(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode, c
 
     /* no children expected */
     if (xmlctx->status == LYXML_ELEMENT) {
-        LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Child element \"%.*s\" inside a terminal node \"%s\" found.",
+        LOGVAL(xmlctx->ctx, *node, LYVE_SYNTAX, "Child element \"%.*s\" inside a terminal node \"%s\" found.",
                 (int)xmlctx->name_len, xmlctx->name, snode->name);
         r = LY_EVALID;
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
     }
 
 cleanup:
-    if (*node) {
-        LOG_LOCBACK(0, 1);
-    }
     if (rc && (!(lydctx->val_opts & LYD_VALIDATE_MULTI_ERROR) || (rc != LY_EVALID))) {
         lyd_parser_node_free(first_p, node);
     }
@@ -844,12 +827,13 @@ lydxml_subtree_inner(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode,
     LY_ERR r, rc = LY_SUCCESS;
     struct lyxml_ctx *xmlctx = lydctx->xmlctx;
     uint32_t prev_parse_opts = lydctx->parse_opts;
+    struct lyplg_ext *plg_ext;
 
     *node = NULL;
 
     if (!xmlctx->ws_only) {
         /* value in inner node */
-        LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Text value \"%.*s\" inside an inner node \"%s\" found.",
+        LOGVAL(xmlctx->ctx, parent, LYVE_SYNTAX, "Text value \"%.*s\" inside an inner node \"%s\" found.",
                 (int)xmlctx->value_len, xmlctx->value, snode->name);
         r = LY_EVALID;
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
@@ -859,11 +843,11 @@ lydxml_subtree_inner(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode,
     rc = lyd_create_inner(snode, node);
     LY_CHECK_GOTO(rc, cleanup);
 
-    assert(*node);
-    LOG_LOCSET(NULL, *node);
-
-    /* insert */
-    r = lyd_parser_node_insert(ext, parent, first_p, NULL, lydctx->parse_opts, *node);
+    /* insert, needs LYD_EXT flag */
+    if (ext) {
+        (*node)->flags |= LYD_EXT;
+    }
+    r = lyd_parser_node_insert(parent, first_p, NULL, lydctx->parse_opts, *node);
     LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
     /* parser next */
@@ -871,8 +855,11 @@ lydxml_subtree_inner(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode,
     LY_CHECK_GOTO(rc, cleanup);
 
     if (ext) {
-        /* only parse these extension data and validate afterwards */
-        lydctx->parse_opts |= LYD_PARSE_ONLY;
+        plg_ext = LYSC_GET_EXT_PLG(ext->def->plugin_ref);
+        if (plg_ext && plg_ext->validate) {
+            /* only parse these extension data and validate afterwards */
+            lydctx->parse_opts |= LYD_PARSE_ONLY;
+        }
     }
 
     /* process children */
@@ -881,7 +868,7 @@ lydxml_subtree_inner(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode,
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
 
         /* insert again, node may be a list that had its keys missing */
-        r = lyd_parser_node_insert(ext, parent, first_p, NULL, lydctx->parse_opts, *node);
+        r = lyd_parser_node_insert(parent, first_p, NULL, lydctx->parse_opts, *node);
         LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
     }
 
@@ -906,9 +893,6 @@ lydxml_subtree_inner(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode,
     }
 
 cleanup:
-    if (*node) {
-        LOG_LOCBACK(0, 1);
-    }
     lydctx->parse_opts = prev_parse_opts;
     if (rc && ((*node && !(*node)->hash) || !(lydctx->val_opts & LYD_VALIDATE_MULTI_ERROR) || (rc != LY_EVALID))) {
         /* list without keys is unusable or an error */
@@ -935,78 +919,69 @@ lydxml_subtree_any(struct lyd_xml_ctx *lydctx, const struct lysc_node *snode, co
     LY_ERR r, rc = LY_SUCCESS;
     struct lyxml_ctx *xmlctx = lydctx->xmlctx;
     uint32_t prev_parse_opts = lydctx->parse_opts, prev_int_opts = lydctx->int_opts;
-    struct lyd_node *child = NULL;
     char *val = NULL;
-    ly_bool log_node = 0;
+    ly_bool datatree_val = 0;
 
     *node = NULL;
 
     if ((snode->nodetype == LYS_ANYDATA) && !xmlctx->ws_only) {
         /* value in anydata node, we expect a tree */
-        LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Text value \"%.*s\" inside an anydata node \"%s\" found.",
+        LOGVAL(xmlctx->ctx, parent, LYVE_SYNTAX, "Text value \"%.*s\" inside an anydata node \"%s\" found.",
                 xmlctx->value_len < 20 ? (int)xmlctx->value_len : 20, xmlctx->value, snode->name);
         r = LY_EVALID;
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
     }
 
-    if (!xmlctx->ws_only) {
+    if (xmlctx->ws_only) {
+        /* create empty node first */
+        r = lyd_create_any(snode, NULL, LYD_ANYDATA_DATATREE, 1, 0, node);
+        LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
+        datatree_val = 1;
+    } else {
         /* use an arbitrary text value for anyxml */
         val = strndup(xmlctx->value, xmlctx->value_len);
         LY_CHECK_ERR_GOTO(!val, LOGMEM(xmlctx->ctx); rc = LY_EMEM, cleanup);
 
-        /* parser next */
-        r = lyxml_ctx_next(xmlctx);
-        LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
-
         /* create node */
-        r = lyd_create_any(snode, val, LYD_ANYDATA_STRING, 1, node);
+        r = lyd_create_any(snode, val, LYD_ANYDATA_STRING, 1, 1, node);
         LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
         val = NULL;
-    } else {
-        /* create node */
-        r = lyd_create_any(snode, NULL, LYD_ANYDATA_DATATREE, 1, node);
-        LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
+    }
 
-        assert(*node);
-        LOG_LOCSET(NULL, *node);
-        log_node = 1;
+    /* insert, needs LYD_EXT flag */
+    if (ext) {
+        (*node)->flags |= LYD_EXT;
+    }
+    r = lyd_parser_node_insert(parent, first_p, NULL, lydctx->parse_opts, *node);
+    LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
-        /* parser next */
-        r = lyxml_ctx_next(xmlctx);
-        LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
+    /* parser next */
+    r = lyxml_ctx_next(xmlctx);
+    LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
+    if (datatree_val) {
         if (lydctx->parse_opts & LYD_PARSE_ANYDATA_STRICT) {
+            /* explicit strict data parsing */
             lydctx->parse_opts |= LYD_PARSE_STRICT;
         } else {
-            /* update options so that generic data can be parsed */
+            /* make the parser process data as opaq nodes */
             lydctx->parse_opts &= ~LYD_PARSE_STRICT;
+            lydctx->parse_opts |= LYD_PARSE_OPAQ;
         }
-        lydctx->parse_opts |= LYD_PARSE_OPAQ | (ext ? LYD_PARSE_ONLY : 0);
+        lydctx->parse_opts |= (ext ? LYD_PARSE_ONLY : 0);
         lydctx->int_opts |= LYD_INTOPT_ANY | LYD_INTOPT_WITH_SIBLINGS;
 
         /* parse any data tree */
         while (xmlctx->status == LYXML_ELEMENT) {
-            r = lydxml_subtree_r(lydctx, NULL, &child, NULL);
+            r = lydxml_subtree_r(lydctx, *node, &((struct lyd_node_any *)*node)->child, NULL);
             LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
         }
-
-        /* assign the data tree */
-        ((struct lyd_node_any *)*node)->value.tree = child;
-        child = NULL;
     }
 
-    /* insert */
-    r = lyd_parser_node_insert(ext, parent, first_p, NULL, lydctx->parse_opts, *node);
-    LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
-
 cleanup:
-    if (log_node) {
-        LOG_LOCBACK(0, 1);
-    }
     lydctx->parse_opts = prev_parse_opts;
     lydctx->int_opts = prev_int_opts;
     free(val);
-    lyd_free_tree(child);
     if (rc && (!(lydctx->val_opts & LYD_VALIDATE_MULTI_ERROR) || (rc != LY_EVALID))) {
         lyd_parser_node_free(first_p, node);
     }
@@ -1034,20 +1009,13 @@ lydxml_subtree_r(struct lyd_xml_ctx *lydctx, struct lyd_node *parent, struct lyd
     struct lyd_attr *attr = NULL;
     const struct lysc_node *snode = NULL;
     struct lysc_ext_instance *ext = NULL;
-    uint32_t orig_parse_opts;
     struct lyd_node *node = NULL;
-    ly_bool parse_subtree;
 
     assert(parent || first_p);
 
     xmlctx = lydctx->xmlctx;
     ctx = xmlctx->ctx;
 
-    parse_subtree = lydctx->parse_opts & LYD_PARSE_SUBTREE ? 1 : 0;
-    /* all descendants should be parsed */
-    lydctx->parse_opts &= ~LYD_PARSE_SUBTREE;
-    orig_parse_opts = lydctx->parse_opts;
-
     assert(xmlctx->status == LYXML_ELEMENT);
 
     /* remember element prefix and name */
@@ -1070,7 +1038,7 @@ lydxml_subtree_r(struct lyd_xml_ctx *lydctx, struct lyd_node *parent, struct lyd
         LY_CHECK_GOTO(rc, cleanup);
 
         /* insert */
-        r = lyd_parser_node_insert(NULL, parent, first_p, NULL, lydctx->parse_opts, node);
+        r = lyd_parser_node_insert(parent, first_p, NULL, lydctx->parse_opts, node);
         LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
         /* validate the value */
@@ -1081,7 +1049,7 @@ lydxml_subtree_r(struct lyd_xml_ctx *lydctx, struct lyd_node *parent, struct lyd
         r = lyxml_ctx_next(xmlctx);
         LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
         if (xmlctx->status != LYXML_ELEM_CLOSE) {
-            LOGVAL(ctx, LYVE_DATA, "Unexpected notification \"eventTime\" node children.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Unexpected notification \"eventTime\" node children.");
             rc = LY_EVALID;
             goto cleanup;
         }
@@ -1111,10 +1079,10 @@ lydxml_subtree_r(struct lyd_xml_ctx *lydctx, struct lyd_node *parent, struct lyd
     /* create metadata/attributes */
     if (xmlctx->status == LYXML_ATTRIBUTE) {
         if (snode) {
-            r = lydxml_metadata(lydctx, snode, &meta);
+            r = lydxml_metadata(lydctx, snode, parent, &meta);
         } else {
             assert(lydctx->parse_opts & LYD_PARSE_OPAQ);
-            r = lydxml_attrs(xmlctx, &attr);
+            r = lydxml_attrs(xmlctx, parent, &attr);
         }
     }
     LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
@@ -1141,20 +1109,12 @@ node_parsed:
         /* add/correct flags */
         r = lyd_parser_set_data_flags(node, &meta, (struct lyd_ctx *)lydctx, ext);
         LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
-
-        if (!(lydctx->parse_opts & LYD_PARSE_ONLY)) {
-            /* store for ext instance node validation, if needed */
-            r = lyd_validate_node_ext(node, &lydctx->ext_val);
-            LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
-        }
     }
 
     /* parser next */
     assert(xmlctx->status == LYXML_ELEM_CLOSE);
-    if (!parse_subtree) {
-        r = lyxml_ctx_next(xmlctx);
-        LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
-    }
+    r = lyxml_ctx_next(xmlctx);
+    LY_CHECK_ERR_GOTO(r, rc = r, cleanup);
 
     LY_CHECK_GOTO(!node, cleanup);
 
@@ -1173,7 +1133,6 @@ node_parsed:
     }
 
 cleanup:
-    lydctx->parse_opts = orig_parse_opts;
     lyd_free_meta_siblings(meta);
     lyd_free_attr_siblings(ctx, attr);
     return rc;
@@ -1214,7 +1173,7 @@ lydxml_envelope(struct lyxml_ctx *xmlctx, const char *name, const char *uri, ly_
     prefix_len = xmlctx->prefix_len;
     ns = lyxml_ns_get(&xmlctx->ns, prefix, prefix_len);
     if (!ns) {
-        lydxml_log_namespace_err(xmlctx, prefix, prefix_len, NULL, 0);
+        lydxml_log_namespace_err(xmlctx->ctx, NULL, prefix, prefix_len, NULL, 0);
         return LY_EVALID;
     } else if (strcmp(ns->uri, uri)) {
         /* different namespace */
@@ -1225,12 +1184,12 @@ lydxml_envelope(struct lyxml_ctx *xmlctx, const char *name, const char *uri, ly_
 
     /* create attributes */
     if (xmlctx->status == LYXML_ATTRIBUTE) {
-        LY_CHECK_RET(lydxml_attrs(xmlctx, &attr));
+        LY_CHECK_RET(lydxml_attrs(xmlctx, NULL, &attr));
     }
 
     assert(xmlctx->status == LYXML_ELEM_CONTENT);
     if (!value && !xmlctx->ws_only) {
-        LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Unexpected value \"%.*s\" in the \"%s\" element.",
+        LOGVAL(xmlctx->ctx, NULL, LYVE_SYNTAX, "Unexpected value \"%.*s\" in the \"%s\" element.",
                 (int)xmlctx->value_len, xmlctx->value, name);
         rc = LY_EVALID;
         goto cleanup;
@@ -1258,15 +1217,13 @@ cleanup:
 }
 
 LY_ERR
-lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
-        struct ly_set *parsed, ly_bool *subtree_sibling, struct lyd_ctx **lydctx_p)
+lyd_parse_xml(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_in *in,
+        uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts, struct ly_set *parsed, struct lyd_ctx **lydctx_p)
 {
     LY_ERR r, rc = LY_SUCCESS;
     struct lyd_xml_ctx *lydctx;
     ly_bool parsed_data_nodes = 0, close_elem = 0;
     struct lyd_node *act = NULL;
-    enum LYXML_PARSER_STATUS status;
 
     assert(ctx && in && lydctx_p);
     assert(!(parse_opts & ~LYD_PARSE_OPTS_MASK));
@@ -1280,7 +1237,6 @@ lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     lydctx->val_opts = val_opts;
     lydctx->int_opts = int_opts;
     lydctx->free = lyd_xml_ctx_free;
-    lydctx->ext = ext;
 
     /* find the operation node if it exists already */
     LY_CHECK_GOTO(rc = lyd_parser_find_operation(parent, int_opts, &lydctx->op_node), cleanup);
@@ -1309,8 +1265,8 @@ lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     if (close_elem) {
         if (lydctx->xmlctx->status != LYXML_ELEM_CLOSE) {
             assert(lydctx->xmlctx->status == LYXML_ELEMENT);
-            LOGVAL(lydctx->xmlctx->ctx, LYVE_SYNTAX, "Unexpected child element \"%.*s\".",
-                    (int)lydctx->xmlctx->name_len, lydctx->xmlctx->name);
+            LOGVAL(ctx, NULL, LYVE_SYNTAX, "Unexpected child element \"%.*s\".", (int)lydctx->xmlctx->name_len,
+                    lydctx->xmlctx->name);
             rc = LY_EVALID;
             goto cleanup;
         }
@@ -1320,12 +1276,12 @@ lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
 
     /* check final state */
     if ((int_opts & LYD_INTOPT_NO_SIBLINGS) && (lydctx->xmlctx->status == LYXML_ELEMENT)) {
-        LOGVAL(ctx, LYVE_SYNTAX, "Unexpected sibling node.");
+        LOGVAL(ctx, NULL, LYVE_SYNTAX, "Unexpected sibling node.");
         r = LY_EVALID;
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
     }
     if ((int_opts & (LYD_INTOPT_RPC | LYD_INTOPT_ACTION | LYD_INTOPT_NOTIF | LYD_INTOPT_REPLY)) && !lydctx->op_node) {
-        LOGVAL(ctx, LYVE_DATA, "Missing the operation node.");
+        LOGVAL(ctx, NULL, LYVE_DATA, "Missing the operation node.");
         r = LY_EVALID;
         LY_DPARSER_ERR_GOTO(r, rc = r, lydctx, cleanup);
     }
@@ -1335,16 +1291,6 @@ lyd_parse_xml(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
         lydctx->op_node = NULL;
     }
 
-    if (parse_opts & LYD_PARSE_SUBTREE) {
-        /* check for a sibling element */
-        assert(subtree_sibling);
-        if (!lyxml_ctx_peek(lydctx->xmlctx, &status) && (status == LYXML_ELEMENT)) {
-            *subtree_sibling = 1;
-        } else {
-            *subtree_sibling = 0;
-        }
-    }
-
 cleanup:
     /* there should be no unres stored if validation should be skipped */
     assert(!(parse_opts & LYD_PARSE_ONLY) || (!lydctx->node_types.count && !lydctx->meta_types.count &&
@@ -1441,7 +1387,7 @@ lydxml_env_netconf_reply(struct lyd_xml_ctx *lydctx, struct lyd_node **envp, uin
 
     /* there must be some child */
     if (xmlctx->status == LYXML_ELEM_CLOSE) {
-        LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Missing child elements of \"rpc-reply\".");
+        LOGVAL(xmlctx->ctx, NULL, LYVE_SYNTAX, "Missing child elements of \"rpc-reply\".");
         rc = LY_EVALID;
         goto cleanup;
     }
@@ -1455,7 +1401,7 @@ lydxml_env_netconf_reply(struct lyd_xml_ctx *lydctx, struct lyd_node **envp, uin
         /* finish child parsing */
         if (xmlctx->status != LYXML_ELEM_CLOSE) {
             assert(xmlctx->status == LYXML_ELEMENT);
-            LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Unexpected child element \"%.*s\" of \"ok\".",
+            LOGVAL(xmlctx->ctx, NULL, LYVE_SYNTAX, "Unexpected child element \"%.*s\" of \"ok\".",
                     (int)xmlctx->name_len, xmlctx->name);
             rc = LY_EVALID;
             goto cleanup;
@@ -1482,7 +1428,7 @@ finish:
         /* NETCONF rpc-reply with no data */
         if (xmlctx->status != LYXML_ELEM_CLOSE) {
             assert(xmlctx->status == LYXML_ELEMENT);
-            LOGVAL(xmlctx->ctx, LYVE_SYNTAX, "Unexpected sibling element \"%.*s\" of \"%s\".",
+            LOGVAL(xmlctx->ctx, NULL, LYVE_SYNTAX, "Unexpected sibling element \"%.*s\" of \"%s\".",
                     (int)xmlctx->name_len, xmlctx->name, parsed_elem);
             rc = LY_EVALID;
             goto cleanup;
@@ -1502,9 +1448,9 @@ cleanup:
 }
 
 LY_ERR
-lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
-        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type,
-        struct lyd_node **envp, struct ly_set *parsed, struct lyd_ctx **lydctx_p)
+lyd_parse_xml_netconf(const struct ly_ctx *ctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_in *in,
+        uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type, struct lyd_node **envp, struct ly_set *parsed,
+        struct lyd_ctx **lydctx_p)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lyd_xml_ctx *lydctx;
@@ -1515,7 +1461,6 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
     assert(ctx && in && lydctx_p);
     assert(!(parse_opts & ~LYD_PARSE_OPTS_MASK));
     assert(!(val_opts & ~LYD_VALIDATE_OPTS_MASK));
-    assert(!(parse_opts & LYD_PARSE_SUBTREE));
 
     /* init context */
     lydctx = calloc(1, sizeof *lydctx);
@@ -1524,14 +1469,13 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
     lydctx->parse_opts = parse_opts;
     lydctx->val_opts = val_opts;
     lydctx->free = lyd_xml_ctx_free;
-    lydctx->ext = ext;
 
     switch (data_type) {
     case LYD_TYPE_RPC_NETCONF:
         assert(!parent);
         rc = lydxml_env_netconf_rpc(lydctx->xmlctx, envp, &int_opts, &close_elem);
         if (rc == LY_ENOT) {
-            LOGVAL(ctx, LYVE_DATA, "Missing NETCONF <rpc> envelope or in incorrect namespace.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing NETCONF <rpc> envelope or in incorrect namespace.");
         }
         LY_CHECK_GOTO(rc, cleanup);
         break;
@@ -1541,7 +1485,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
         /* parse "notification" */
         rc = lydxml_envelope(lydctx->xmlctx, "notification", "urn:ietf:params:xml:ns:netconf:notification:1.0", 0, envp);
         if (rc == LY_ENOT) {
-            LOGVAL(ctx, LYVE_DATA, "Missing NETCONF <notification> envelope or in incorrect namespace.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing NETCONF <notification> envelope or in incorrect namespace.");
         }
         LY_CHECK_GOTO(rc, cleanup);
 
@@ -1553,7 +1497,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
         assert(parent);
         rc = lydxml_env_netconf_reply(lydctx, envp, &int_opts, &close_elem);
         if (rc == LY_ENOT) {
-            LOGVAL(ctx, LYVE_DATA, "Missing NETCONF <rpc-reply> envelope or in incorrect namespace.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing NETCONF <rpc-reply> envelope or in incorrect namespace.");
         }
         LY_CHECK_GOTO(rc, cleanup);
         break;
@@ -1563,7 +1507,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
         /* parse "input" */
         rc = lydxml_envelope(lydctx->xmlctx, "input", lyd_node_module(parent)->ns, 0, envp);
         if (rc == LY_ENOT) {
-            LOGVAL(ctx, LYVE_DATA, "Missing RESTCONF \"input\" object or in incorrect namespace.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing RESTCONF \"input\" object or in incorrect namespace.");
         }
         LY_CHECK_GOTO(rc, cleanup);
 
@@ -1576,7 +1520,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
         /* parse "output" */
         rc = lydxml_envelope(lydctx->xmlctx, "output", lyd_node_module(parent)->ns, 0, envp);
         if (rc == LY_ENOT) {
-            LOGVAL(ctx, LYVE_DATA, "Missing RESTCONF \"output\" object or in incorrect namespace.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing RESTCONF \"output\" object or in incorrect namespace.");
         }
         LY_CHECK_GOTO(rc, cleanup);
 
@@ -1608,7 +1552,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
     for (i = 0; i < close_elem; ++i) {
         if (lydctx->xmlctx->status != LYXML_ELEM_CLOSE) {
             assert(lydctx->xmlctx->status == LYXML_ELEMENT);
-            LOGVAL(lydctx->xmlctx->ctx, LYVE_SYNTAX, "Unexpected child element \"%.*s\".",
+            LOGVAL(lydctx->xmlctx->ctx, NULL, LYVE_SYNTAX, "Unexpected child element \"%.*s\".",
                     (int)lydctx->xmlctx->name_len, lydctx->xmlctx->name);
             rc = LY_EVALID;
             goto cleanup;
@@ -1619,12 +1563,12 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
 
     /* check final state */
     if ((int_opts & LYD_INTOPT_NO_SIBLINGS) && (lydctx->xmlctx->status == LYXML_ELEMENT)) {
-        LOGVAL(ctx, LYVE_SYNTAX, "Unexpected sibling node.");
+        LOGVAL(ctx, NULL, LYVE_SYNTAX, "Unexpected sibling node.");
         rc = LY_EVALID;
         goto cleanup;
     }
     if ((int_opts & (LYD_INTOPT_RPC | LYD_INTOPT_ACTION | LYD_INTOPT_NOTIF | LYD_INTOPT_REPLY)) && !lydctx->op_node) {
-        LOGVAL(ctx, LYVE_DATA, "Missing the operation node.");
+        LOGVAL(ctx, NULL, LYVE_DATA, "Missing the operation node.");
         rc = LY_EVALID;
         goto cleanup;
     }
@@ -1632,7 +1576,7 @@ lyd_parse_xml_netconf(const struct ly_ctx *ctx, const struct lysc_ext_instance *
         /* parse as a child of the envelope */
         node = (*first_p)->prev;
         if (node->schema) {
-            LOGVAL(ctx, LYVE_DATA, "Missing notification \"eventTime\" node.");
+            LOGVAL(ctx, NULL, LYVE_DATA, "Missing notification \"eventTime\" node.");
             rc = LY_EVALID;
             goto cleanup;
         } else {
