@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Path structure and manipulation routines.
  *
- * Copyright (c) 2020 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2020 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -37,11 +37,11 @@ struct lyxp_expr;
  */
 #define LOGVAL_PATH(CTX, CUR_SCNODE, CTX_SCNODE, ...) \
         if ((CUR_SCNODE) || (CTX_SCNODE)) { \
-            LOG_LOCSET((CUR_SCNODE) ? (CUR_SCNODE) : (CTX_SCNODE), NULL); \
+            LOG_LOCSET((CUR_SCNODE) ? (CUR_SCNODE) : (CTX_SCNODE)); \
         } \
-        ly_vlog(CTX, NULL, __VA_ARGS__); \
+        ly_vlog(CTX, NULL, NULL, __VA_ARGS__); \
         if ((CUR_SCNODE) || (CTX_SCNODE)) { \
-            LOG_LOCBACK(1, 0); \
+            LOG_LOCBACK(1); \
         }
 
 /**
@@ -76,11 +76,11 @@ struct ly_path_predicate {
  * simple predicates. Is used as a [sized array](@ref sizedarrays).
  */
 struct ly_path {
-    const struct lysc_node *node; /**< Schema node representing the path segment, first node has special meaning:
-                                       - is a top-level node - path is absolute,
-                                       - is inner node - path is relative */
-    const struct lysc_ext_instance *ext;    /**< Extension instance of @p node, if any */
-    struct ly_path_predicate *predicates;   /**< [Sized array](@ref sizedarrays) of the path segment's predicates */
+    const struct lysc_node *node; /**< Schema node representing the path segment. */
+    const struct lysc_ext_instance *ext;    /**< Extension instance of @p node, if any. */
+    struct ly_path_predicate *predicates;   /**< [Sized array](@ref sizedarrays) of the path segment's predicates. */
+    ly_bool doc_root;                       /**< Node is relative to the document root, set for the first node in an
+                                                 absolute path, unset for all nodes in a relative path. */
 };
 
 /**
@@ -166,33 +166,25 @@ LY_ERR ly_path_parse_predicate(const struct ly_ctx *ctx, const struct lysc_node
  * @brief Compile path into ly_path structure.
  *
  * @param[in] ctx libyang context.
- * @param[in] cur_mod Current module of the path (where it was "instantiated"). Used for nodes in schema-nodeid
- * without a prefix for ::LY_VALUE_SCHEMA and ::LY_VALUE_SCHEMA_RESOLVED format.
  * @param[in] ctx_node Optional context node.
- * @param[in] top_ext Extension instance containing the definition of the data being created. It is used to find the top-level
- * node inside the extension instance instead of a module. Note that this is the case not only if the @p ctx_node is NULL,
- * but also if the relative path starting in @p ctx_node reaches the document root via double dots.
  * @param[in] expr Parsed path.
  * @param[in] oper Oper option (@ref path_oper_options).
  * @param[in] target Target option (@ref path_target_options).
- * @param[in] limit_access_tree Whether to limit accessible tree.
+ * @param[in] is_xpath Whether we are compiling an XPath path and should limit the accessible tree.
  * @param[in] format Format of the path.
  * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
  * @param[out] path Compiled path.
  * @return LY_ERR value.
  */
-LY_ERR ly_path_compile(const struct ly_ctx *ctx, const struct lys_module *cur_mod, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *top_ext, const struct lyxp_expr *expr, uint16_t oper, uint16_t target,
-        ly_bool limit_access_tree, LY_VALUE_FORMAT format, void *prefix_data, struct ly_path **path);
+LY_ERR ly_path_compile(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const struct lyxp_expr *expr,
+        uint16_t oper, uint16_t target, ly_bool is_xpath, LY_VALUE_FORMAT format, void *prefix_data,
+        struct ly_path **path);
 
 /**
  * @brief Compile path into ly_path structure. Any predicates of a leafref are only checked, not compiled.
  *
  * @param[in] ctx libyang context.
  * @param[in] ctx_node Context node.
- * @param[in] top_ext Extension instance containing the definition of the data being created. It is used to find the top-level
- * node inside the extension instance instead of a module. Note that this is the case not only if the @p ctx_node is NULL,
- * but also if the relative path starting in @p ctx_node reaches the document root via double dots.
  * @param[in] expr Parsed path.
  * @param[in] oper Oper option (@ref path_oper_options).
  * @param[in] target Target option (@ref path_target_options).
@@ -201,19 +193,15 @@ LY_ERR ly_path_compile(const struct ly_ctx *ctx, const struct lys_module *cur_mo
  * @param[out] path Compiled path.
  * @return LY_ERR value.
  */
-LY_ERR ly_path_compile_leafref(const struct ly_ctx *ctx, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *top_ext, const struct lyxp_expr *expr, uint16_t oper, uint16_t target,
-        LY_VALUE_FORMAT format, void *prefix_data, struct ly_path **path);
+LY_ERR ly_path_compile_leafref(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const struct lyxp_expr *expr,
+        uint16_t oper, uint16_t target, LY_VALUE_FORMAT format, void *prefix_data, struct ly_path **path);
 
 /**
  * @brief Compile predicate into ly_path_predicate structure. Only simple predicates (not leafref) are supported.
  *
  * @param[in] ctx libyang context.
  * @param[in] cur_node Optional current (original context) node.
- * @param[in] cur_mod Current module of the path (where it was "instantiated"). Used for nodes without a prefix
- * for ::LY_VALUE_SCHEMA and ::LY_VALUE_SCHEMA_RESOLVED format.
  * @param[in] ctx_node Context node, node for which the predicate is defined.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[in] expr Parsed path.
  * @param[in,out] tok_idx Index in @p expr, is adjusted for parsed tokens.
  * @param[in] format Format of the path.
@@ -221,17 +209,17 @@ LY_ERR ly_path_compile_leafref(const struct ly_ctx *ctx, const struct lysc_node
  * @param[out] predicates Compiled predicates.
  * @return LY_ERR value.
  */
-LY_ERR ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_node, const struct lys_module *cur_mod,
-        const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext, const struct lyxp_expr *expr,
-        uint32_t *tok_idx, LY_VALUE_FORMAT format, void *prefix_data, struct ly_path_predicate **predicates);
+LY_ERR ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_node,
+        const struct lysc_node *ctx_node, const struct lyxp_expr *expr, uint32_t *tok_idx, LY_VALUE_FORMAT format,
+        void *prefix_data, struct ly_path_predicate **predicates);
 
 /**
  * @brief Resolve at least partially the target defined by ly_path structure. Not supported for leafref!
  *
  * @param[in] path Path structure specifying the target.
- * @param[in] start Starting node for relative paths, can be any for absolute paths.
+ * @param[in] ctx_node Context node, NULL for the root node.
+ * @param[in] tree Whoe data tree to search, must be set if @p ctx_node is not.
  * @param[in] vars Array of defined variables to use in predicates, may be NULL.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[in] with_opaq Whether to consider opaque nodes or not.
  * @param[out] path_idx Last found path segment index, can be NULL, set to 0 if not found.
  * @param[out] match Last found matching node, can be NULL, set to NULL if not found.
@@ -240,23 +228,22 @@ LY_ERR ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_nod
  * @return LY_SUCCESS when the last node in the path was found,
  * @return LY_ERR on another error.
  */
-LY_ERR ly_path_eval_partial(const struct ly_path *path, const struct lyd_node *start, const struct lyxp_var *vars,
-        const struct lysc_ext_instance *top_ext, ly_bool with_opaq, LY_ARRAY_COUNT_TYPE *path_idx, struct lyd_node **match);
+LY_ERR ly_path_eval_partial(const struct ly_path *path, const struct lyd_node *ctx_node, const struct lyd_node *tree,
+        const struct lyxp_var *vars, ly_bool with_opaq, LY_ARRAY_COUNT_TYPE *path_idx, struct lyd_node **match);
 
 /**
  * @brief Resolve the target defined by ly_path structure. Not supported for leafref!
  *
  * @param[in] path Path structure specifying the target.
- * @param[in] start Starting node for relative paths, can be any for absolute paths.
+ * @param[in] ctx_node Context node for relative paths, can be any for absolute paths.
  * @param[in] vars Array of defined variables to use in predicates, may be NULL.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[out] match Found matching node, can be NULL, set to NULL if not found.
  * @return LY_ENOTFOUND if no nodes were found,
  * @return LY_SUCCESS when the last node in the path was found,
  * @return LY_ERR on another error.
  */
-LY_ERR ly_path_eval(const struct ly_path *path, const struct lyd_node *start, const struct lyxp_var *vars,
-        const struct lysc_ext_instance *top_ext, struct lyd_node **match);
+LY_ERR ly_path_eval(const struct ly_path *path, const struct lyd_node *ctx_node, const struct lyxp_var *vars,
+        struct lyd_node **match);
 
 /**
  * @brief Duplicate ly_path structure.
