@@ -109,7 +109,7 @@ extern "C" {
 /**
  * @brief Extensions API version
  */
-#define LYPLG_EXT_API_VERSION 10
+#define LYPLG_EXT_API_VERSION 11
 
 /**
  * @brief Mask for an operation statement.
@@ -833,50 +833,66 @@ LIBYANG_API_DECL LY_ERR lyplg_ext_sprinter_ptree_add_nodes(const struct lyspr_tr
 /** @} pluginsExtensionsSprinterTree */
 
 /*
- * data node
+ * node xpath
  */
 
 /**
  * @brief Callback for getting the first child data node of an XPath document root of the extension instance.
  *
  * @param[in] ext Compiled extension instance.
- * @param[in] tree Whole data tree.
+ * @param[in] cur_node Current (original context) node.
  * @param[out] node First XPath document root child node, if any.
  */
-typedef void (*lyplg_ext_data_node_xpath_clb)(struct lysc_ext_instance *ext, const struct lyd_node *tree,
+typedef void (*lyplg_ext_node_xpath_clb)(struct lysc_ext_instance *ext, const struct lyd_node *cur_node,
         const struct lyd_node **node);
 
+/*
+ * snode xpath
+ */
+
+/**
+ * @brief Callback for getting the first child schema node of an XPath document root of the extension instance.
+ *
+ * @param[in] ext Compiled extension instance.
+ * @param[in] prefix Node prefix, if any.
+ * @param[in] prefix_len Length of @p prefix.
+ * @param[in] format Format of @p prefix.
+ * @param[in] prefix_data Format-specific prefix data.
+ * @param[in] name Node name.
+ * @param[in] name_len Length of @p name.
+ * @param[out] snode First XPath document root child schema node, if any.
+ */
+typedef LY_ERR (*lyplg_ext_snode_xpath_clb)(struct lysc_ext_instance *ext, const char *prefix, uint32_t prefix_len,
+        LY_VALUE_FORMAT format, void *prefix_data, const char *name, uint32_t name_len, const struct lysc_node **snode);
+
 /*
  * data snode
  */
 
 /**
  * @brief Callback for getting a schema node for new YANG instance data described by an extension instance.
- * Needed only if the extension instance defines some instantiable YANG data nodes.
+ *
+ * If this callback is defined, ::lyplg_ext_data_validate_clb must also be defined for validating the data node subtrees
+ * parsed using this callback.
  *
  * 1) Schema nodes are compiled and connected to each other:
  *    - this callback is NOT called;
  *    - storage of a data-def-stmt is retrieved from the ext-inst and the nodes connected to it.
  *
  * 2) YANG instance data is being parsed:
- *    - this callback is called with @p in_xpath 0;
- *    - schema node that can be instantiated in data should be returned (matching any set parameters).
- *
- * 3) XPath expression is being evaluated during schema compilation (must, when, leafref path, unique):
- *    - this callback is called with @p in_xpath 1;
- *    - first child of the document root of this extension should be returned.
+ *    - this callback is called;
+ *    - schema node that can be instantiated in data should be returned (matching any set parameters);
+ *    - if this callback is not defined, the same process as in 1) is used.
  *
  * @param[in] ext Compiled extension instance.
  * @param[in] parent Parsed parent data node.
  * @param[in] sparent Schema parent node.
- * @param[in] prefix Element prefix, if any.
+ * @param[in] prefix Node prefix, if any.
  * @param[in] prefix_len Length of @p prefix.
  * @param[in] format Format of @p prefix.
  * @param[in] prefix_data Format-specific prefix data.
- * @param[in] name Element name. If NULL, the first node should be returned (top-level, @p parent and @p sparent will
- * not be set).
+ * @param[in] name Node name.
  * @param[in] name_len Length of @p name.
- * @param[in] in_xpath Whether we are in an XPath accessible tree context or standard YANG data handling (parsing).
  * @param[out] snode Schema node to use for parsing the node.
  * @return LY_SUCCESS on success.
  * @return LY_ENOT if the data are not described by @p ext.
@@ -884,7 +900,7 @@ typedef void (*lyplg_ext_data_node_xpath_clb)(struct lysc_ext_instance *ext, con
  */
 typedef LY_ERR (*lyplg_ext_data_snode_clb)(struct lysc_ext_instance *ext, const struct lyd_node *parent,
         const struct lysc_node *sparent, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data,
-        const char *name, uint32_t name_len, ly_bool in_xpath, const struct lysc_node **snode);
+        const char *name, uint32_t name_len, const struct lysc_node **snode);
 
 /*
  * data validate
@@ -894,21 +910,23 @@ typedef LY_ERR (*lyplg_ext_data_snode_clb)(struct lysc_ext_instance *ext, const
  * @brief Callback for validating parsed YANG instance data described by an extension instance.
  *
  * This callback is called in 2 distinct cases:
- * 1) For nested data definition (with a standard YANG schema parent) when all @p sibling nodes have ::LYD_EXT flag set;
- * 2) For data nodes of a) schema nodes or b) their types with the extension instance (no special flag).
+ * 1) For data nodes created by ::lyplg_ext_data_snode_clb with @p node flag ::LYD_EXT set. If this callback is
+ *    defined, the whole subtree is validated by this callback;
+ * 2) For any data nodes whose a) schema node or b) their type has the extension instance. These nodes are also always
+ *    validated according to the standard YANG node validation rules.
  *
  * @param[in] ext Compiled extension instance.
- * @param[in] sibling First sibling with schema node returned by ::lyplg_ext_data_snode_clb for nested data, otherwise
- * the data node with the extension instance.
+ * @param[in] node Node/subtree to validate.
  * @param[in] dep_tree Tree to be used for validating references from the operation subtree, if operation.
  * @param[in] data_type Validated data type, can be ::LYD_TYPE_DATA_YANG, ::LYD_TYPE_RPC_YANG, ::LYD_TYPE_NOTIF_YANG,
  * or ::LYD_TYPE_REPLY_YANG.
  * @param[in] val_opts Validation options, see @ref datavalidationoptions.
  * @param[out] diff Optional diff with any changes made by the validation.
  * @return LY_SUCCESS on success.
+ * @return LY_ENOT if @p node are not data matching this extension instance.
  * @return LY_ERR on error.
  */
-typedef LY_ERR (*lyplg_ext_data_validate_clb)(struct lysc_ext_instance *ext, struct lyd_node *sibling,
+typedef LY_ERR (*lyplg_ext_data_validate_clb)(struct lysc_ext_instance *ext, struct lyd_node *node,
         const struct lyd_node *dep_tree, enum lyd_type data_type, uint32_t val_opts, struct lyd_node **diff);
 
 /*
@@ -1061,7 +1079,8 @@ struct lyplg_ext {
     lyplg_ext_sprinter_info_clb printer_info;   /**< callback to print the compiled content (info format) */
     lyplg_ext_sprinter_ctree_clb printer_ctree; /**< callback to print tree format of a compiled node */
     lyplg_ext_sprinter_ptree_clb printer_ptree; /**< callback to print tree format of a parsed node */
-    lyplg_ext_data_node_xpath_clb node_xpath;   /**< callback to get first XPath document root child node */
+    lyplg_ext_node_xpath_clb node_xpath;    /**< callback to get first XPath document root data child node */
+    lyplg_ext_snode_xpath_clb snode_xpath;  /**< callback to get first XPath document root schema child node */
     lyplg_ext_data_snode_clb snode;         /**< callback to get schema node in various use-cases */
     lyplg_ext_data_validate_clb validate;   /**< callback to validate parsed data instances */
 
@@ -1154,16 +1173,6 @@ LIBYANG_API_DECL LY_ERR lyplg_ext_get_data(const struct ly_ctx *ctx, const struc
  */
 LIBYANG_API_DECL LY_ERR lyplg_ext_set_parent_ctx(struct ly_ctx *ctx, const struct ly_ctx *parent_ctx);
 
-/**
- * @brief Insert extension instance data into a parent.
- *
- * @param[in] parent Parent node to insert into.
- * @param[in] first First top-level sibling node to insert.
- * @return LY_SUCCESS on success.
- * @return LY_ERR error on error.
- */
-LIBYANG_API_DECL LY_ERR lyplg_ext_insert(struct lyd_node *parent, struct lyd_node *first);
-
 /**
  * @brief Expand parent-reference xpath expressions
  *
