@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief libyang extension plugin - Schema Mount (RFC 8528)
  *
- * Copyright (c) 2021 - 2024 CESNET, z.s.p.o.
+ * Copyright (c) 2021 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -434,7 +434,7 @@ schema_mount_get_content_id(struct lysc_ext_instance *ext, const struct lyd_node
     *content_id = NULL;
 
     /* find the content-id node */
-    snode = lys_find_child(ext_yl_data->schema, ext_yl_data->schema->module, "content-id", 0, 0, 0);
+    snode = lys_find_child(NULL, ext_yl_data->schema, ext_yl_data->schema->module, NULL, 0, "content-id", 0, 0);
     assert(snode);
 
     /* get yang-library content-id */
@@ -923,6 +923,33 @@ cleanup:
     return ret;
 }
 
+/**
+ * @brief Snode xpath callback for schema mount.
+ */
+static LY_ERR
+schema_mount_snode_xpath(struct lysc_ext_instance *ext, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        void *prefix_data, const char *name, uint32_t name_len, const struct lysc_node **snode)
+{
+    LY_ERR r;
+    const struct lys_module *mod;
+    const struct ly_ctx *ext_ctx = NULL;
+
+    /* get context based on ietf-yang-library data */
+    if ((r = lyplg_ext_schema_mount_get_ctx(ext, NULL, &ext_ctx))) {
+        return r;
+    }
+
+    /* get the module */
+    mod = lys_find_module(ext_ctx, NULL, prefix, prefix_len, format, prefix_data);
+    if (!mod) {
+        return LY_ENOT;
+    }
+
+    /* get the top-level schema node */
+    *snode = lys_find_child(NULL, NULL, mod, NULL, 0, name, name_len, 0);
+    return *snode ? LY_SUCCESS : LY_ENOT;
+}
+
 /**
  * @brief Snode callback for schema mount.
  * Check if data are valid for schema mount and returns their schema node.
@@ -930,7 +957,7 @@ cleanup:
 static LY_ERR
 schema_mount_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct lysc_node *sparent,
         const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
-        uint32_t name_len, ly_bool UNUSED(in_xpath), const struct lysc_node **snode)
+        uint32_t name_len, const struct lysc_node **snode)
 {
     LY_ERR r;
     const struct lys_module *mod;
@@ -945,7 +972,7 @@ schema_mount_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent,
     }
 
     /* get the module */
-    mod = lyplg_type_identity_module(ext_ctx, parent ? parent->schema : sparent, prefix, prefix_len, format, prefix_data);
+    mod = lys_find_module(ext_ctx, parent ? parent->schema : sparent, prefix, prefix_len, format, prefix_data);
     if (!mod) {
         return LY_ENOT;
     }
@@ -957,7 +984,7 @@ schema_mount_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent,
     }
 
     /* get the top-level schema node */
-    *snode = lys_find_child(NULL, mod, name, name_len, 0, 0);
+    *snode = lys_find_child(NULL, NULL, mod, NULL, 0, name, name_len, 0);
     return *snode ? LY_SUCCESS : LY_ENOT;
 }
 
@@ -1044,7 +1071,7 @@ schema_mount_dup_parent_ref(const struct lysc_ext_instance *ext, const struct ly
 
             /* go top-level */
             while (dup->parent) {
-                dup = lyd_parent(dup);
+                dup = dup->parent;
             }
 
             /* check whether the top-level node exists */
@@ -1125,7 +1152,7 @@ lyplg_ext_schema_mount_get_parent_ref(const struct lysc_ext_instance *ext, const
         LYD_VALUE_GET(&term->value, xp_val);
         rc = lyplg_type_print_xpath10_value(xp_val, LY_VALUE_JSON, NULL, &value, &err);
         if (rc) {
-            ly_err_print(ext->module->ctx, err);
+            ly_err_print(ext->module->ctx, err, NULL, NULL);
             ly_err_free(err);
             goto cleanup;
         }
@@ -1158,28 +1185,28 @@ cleanup:
  * @brief Validate callback for schema mount.
  */
 static LY_ERR
-schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *sibling, const struct lyd_node *dep_tree,
+schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *node, const struct lyd_node *dep_tree,
         enum lyd_type data_type, uint32_t val_opts, struct lyd_node **diff)
 {
     LY_ERR ret = LY_SUCCESS;
     uint32_t i;
-    struct lyd_node *iter, *ext_data = NULL, *ref_first = NULL, *orig_parent = lyd_parent(sibling), *op_tree;
+    struct lyd_node *iter, *ext_data = NULL, *ref_first = NULL, *orig_parent = node->parent, *op_tree;
     struct lyd_node *ext_diff = NULL, *diff_parent = NULL, *sm_root = NULL;
     ly_bool ext_data_free = 0;
     struct ly_set *ref_set = NULL;
 
-    if (!sibling) {
+    if (!node) {
         /* some data had to be parsed for this callback to be called */
         EXT_LOGERR_INT_RET(NULL, ext);
     }
 
-    if (!(sibling->flags & LYD_EXT)) {
+    if (!(node->flags & LYD_EXT)) {
         /* no validation of the node with the mount-point */
         goto cleanup;
     }
 
     /* get operational data with ietf-yang-library and ietf-yang-schema-mount data */
-    if ((ret = lyplg_ext_get_data(ext->module->ctx, ext, lyd_parent(sibling), (void **)&ext_data, &ext_data_free))) {
+    if ((ret = lyplg_ext_get_data(ext->module->ctx, ext, node->parent, (void **)&ext_data, &ext_data_free))) {
         goto cleanup;
     }
     if (!ext_data) {
@@ -1207,45 +1234,45 @@ schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *sibling, c
     }
 
     /* duplicate the referenced parent nodes into ext context */
-    if ((ret = schema_mount_dup_parent_ref(ext, orig_parent, ext_data, LYD_CTX(sibling), &ref_set))) {
+    if ((ret = schema_mount_dup_parent_ref(ext, orig_parent, ext_data, LYD_CTX(node), &ref_set))) {
         goto cleanup;
     }
 
     if (data_type != LYD_TYPE_DATA_YANG) {
         /* remember the operation data tree, it may be moved */
-        op_tree = sibling;
+        op_tree = node;
     }
 
     /* create accessible tree, remove LYD_EXT to not call this callback recursively */
-    LY_CHECK_GOTO(lyd_unlink_siblings(sibling), cleanup);
-    LY_LIST_FOR(sibling, iter) {
+    LY_CHECK_GOTO(lyd_unlink_siblings(node), cleanup);
+    LY_LIST_FOR(node, iter) {
         iter->flags &= ~LYD_EXT;
     }
     if (ref_set->count) {
-        if ((ret = lyd_insert_sibling(sibling, ref_set->dnodes[0], &sibling))) {
+        if ((ret = lyd_insert_sibling(node, ref_set->dnodes[0], &node))) {
             goto cleanup;
         }
     }
 
     if (data_type == LYD_TYPE_DATA_YANG) {
         /* validate all the modules with data */
-        ret = lyd_validate_all(&sibling, NULL, val_opts | LYD_VALIDATE_PRESENT, diff ? &ext_diff : NULL);
+        ret = lyd_validate_all(&node, NULL, val_opts | LYD_VALIDATE_PRESENT, diff ? &ext_diff : NULL);
     } else {
         /* validate the operation */
         ret = lyd_validate_op(op_tree, dep_tree, data_type, diff ? &ext_diff : NULL);
     }
 
-    /* restore sibling tree */
+    /* restore node tree */
     for (i = 0; i < ref_set->count; ++i) {
-        if (ref_set->dnodes[i] == sibling) {
-            sibling = sibling->next;
+        if (ref_set->dnodes[i] == node) {
+            node = node->next;
         }
         lyd_free_tree(ref_set->dnodes[i]);
     }
-    LY_LIST_FOR(sibling, iter) {
+    LY_LIST_FOR(node, iter) {
         iter->flags |= LYD_EXT;
     }
-    lyplg_ext_insert(orig_parent, sibling);
+    lyd_insert_child(orig_parent, node);
 
     if (ret) {
         goto cleanup;
@@ -1259,17 +1286,17 @@ schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *sibling, c
         }
 
         /* create the parent and insert the diff */
-        if ((ret = lyd_dup_single(lyd_parent(sibling), NULL, LYD_DUP_WITH_PARENTS | LYD_DUP_NO_META, &diff_parent))) {
+        if ((ret = lyd_dup_single(node->parent, NULL, LYD_DUP_WITH_PARENTS | LYD_DUP_NO_META, &diff_parent))) {
             goto cleanup;
         }
-        if ((ret = lyplg_ext_insert(diff_parent, ext_diff))) {
+        if ((ret = lyd_insert_child(diff_parent, ext_diff))) {
             goto cleanup;
         }
         ext_diff = NULL;
 
         /* go top-level and set the operation */
-        while (lyd_parent(diff_parent)) {
-            diff_parent = lyd_parent(diff_parent);
+        while (diff_parent->parent) {
+            diff_parent = diff_parent->parent;
         }
         if ((ret = lyd_new_meta(LYD_CTX(diff_parent), diff_parent, NULL, "yang:operation", "none", 0, NULL))) {
             goto cleanup;
@@ -1571,6 +1598,7 @@ const struct lyplg_ext_record plugins_schema_mount[] = {
         .plugin.printer_ctree = schema_mount_sprinter_ctree,
         .plugin.printer_ptree = schema_mount_sprinter_ptree,
         .plugin.node_xpath = NULL,
+        .plugin.snode_xpath = schema_mount_snode_xpath,
         .plugin.snode = schema_mount_snode,
         .plugin.validate = schema_mount_validate,
         .plugin.pfree = NULL,
