@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief libyang extension plugin - structure (RFC 8791)
  *
- * Copyright (c) 2022 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2022 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -560,21 +560,55 @@ structure_sprinter_ptree(struct lysp_ext_instance *ext, const struct lyspr_tree_
  * @brief Node xpath callback for structure.
  */
 static void
-structure_node_xpath(struct lysc_ext_instance *ext, const struct lyd_node *tree, const struct lyd_node **node)
+structure_node_xpath(struct lysc_ext_instance *ext, const struct lyd_node *cur_node, const struct lyd_node **node)
 {
     *node = NULL;
 
-    if (!tree) {
+    if (!cur_node) {
         return;
     }
 
+    while (cur_node && !(cur_node->flags & LYD_EXT)) {
+        cur_node = cur_node->parent;
+    }
+    assert(cur_node);
+
     /* virtual top-level container expected */
-    assert(!strcmp(ext->argument, LYD_NAME(tree)));
+    assert(!strcmp(ext->argument, LYD_NAME(cur_node)));
     (void)ext;
 
     /* return the child */
-    *node = lyd_child(tree);
-    return;
+    *node = lyd_child(cur_node);
+}
+
+/**
+ * @brief Snode xpath callback for structure.
+ */
+static LY_ERR
+structure_snode_xpath(struct lysc_ext_instance *ext, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        void *prefix_data, const char *name, uint32_t name_len, const struct lysc_node **snode)
+{
+    struct lysc_ext_instance_structure *struct_cdata = ext->compiled;
+    const struct lysc_node *schema = NULL;
+    const struct lys_module *mod;
+
+    if (prefix && prefix_len) {
+        /* check module */
+        mod = lys_find_module(ext->module->ctx, NULL, prefix, prefix_len, format, prefix_data);
+        if (!mod || (ext->module != mod)) {
+            return LY_ENOT;
+        }
+    }
+
+    /* find the schema node in the substatements */
+    while ((schema = lys_getnext(schema, &struct_cdata->top_cont->node, NULL, 0))) {
+        if (!ly_strncmp(schema->name, name, name_len)) {
+            *snode = schema;
+            return LY_SUCCESS;
+        }
+    }
+
+    return LY_ENOT;
 }
 
 /**
@@ -582,26 +616,51 @@ structure_node_xpath(struct lysc_ext_instance *ext, const struct lyd_node *tree,
  */
 static LY_ERR
 structure_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct lysc_node *sparent,
-        const char *prefix, uint32_t UNUSED(prefix_len), LY_VALUE_FORMAT UNUSED(format), void *UNUSED(prefix_data),
-        const char *name, uint32_t UNUSED(name_len), ly_bool in_xpath, const struct lysc_node **snode)
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, const struct lysc_node **snode)
 {
     struct lysc_ext_instance_structure *struct_cdata = ext->compiled;
+    const struct lys_module *mod;
 
-    assert(!parent && !sparent && !prefix && !name);
+    /* may be anywhere in the data. in top-level or nested */
     (void)parent;
     (void)sparent;
-    (void)prefix;
-    (void)name;
 
-    if (in_xpath) {
-        /* XPath starts at the substatements */
-        *snode = struct_cdata->top_cont->child;
-    } else {
-        /* data tree start at the top-level virtual container */
-        *snode = &struct_cdata->top_cont->node;
+    if (prefix && prefix_len) {
+        /* check module */
+        mod = lys_find_module(ext->module->ctx, NULL, prefix, prefix_len, format, prefix_data);
+        if (!mod || (ext->module != mod)) {
+            return LY_ENOT;
+        }
     }
 
-    return *snode ? LY_SUCCESS : LY_ENOT;
+    /* check name */
+    if (name && name_len) {
+        if (ly_strncmp(struct_cdata->top_cont->name, name, name_len)) {
+            return LY_ENOT;
+        }
+    }
+
+    /* data tree start at the top-level virtual container */
+    *snode = &struct_cdata->top_cont->node;
+
+    return LY_SUCCESS;
+}
+
+/**
+ * @brief Validate callback for structure.
+ */
+static LY_ERR
+structure_validate(struct lysc_ext_instance *ext, struct lyd_node *node, const struct lyd_node *UNUSED(dep_tree),
+        enum lyd_type data_type, uint32_t val_opts, struct lyd_node **diff)
+{
+    if (data_type != LYD_TYPE_DATA_YANG) {
+        /* not supported */
+        return LY_ENOT;
+    }
+
+    /* validate all the modules with data */
+    return lyd_validate_ext(&node, ext, val_opts, diff);
 }
 
 /**
@@ -674,8 +733,9 @@ const struct lyplg_ext_record plugins_structure[] = {
         .plugin.printer_ctree = structure_sprinter_ctree,
         .plugin.printer_ptree = structure_sprinter_ptree,
         .plugin.node_xpath = structure_node_xpath,
+        .plugin.snode_xpath = structure_snode_xpath,
         .plugin.snode = structure_snode,
-        .plugin.validate = NULL,
+        .plugin.validate = structure_validate,
         .plugin.pfree = structure_pfree,
         .plugin.cfree = structure_cfree,
         .plugin.compiled_size = structure_compiled_size,
@@ -693,6 +753,7 @@ const struct lyplg_ext_record plugins_structure[] = {
         .plugin.printer_ctree = structure_aug_sprinter_ctree,
         .plugin.printer_ptree = structure_aug_sprinter_ptree,
         .plugin.node_xpath = NULL,
+        .plugin.snode_xpath = NULL,
         .plugin.snode = NULL,
         .plugin.validate = NULL,
         .plugin.pfree = structure_pfree,
