@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief libyang extension plugin - yang-data (RFC 8040)
  *
- * Copyright (c) 2021 - 2024 CESNET, z.s.p.o.
+ * Copyright (c) 2021 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -20,8 +20,13 @@
 
 #include "compat.h"
 #include "libyang.h"
+#include "ly_common.h"
 #include "plugins_exts.h"
+#include "plugins_types.h"
 
+static LY_ERR yangdata_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct lysc_node *sparent,
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, const struct lysc_node **snode);
 static void yangdata_cfree(const struct ly_ctx *ctx, struct lysc_ext_instance *ext);
 
 /**
@@ -178,24 +183,68 @@ yangdata_printer_info(struct lyspr_ctx *ctx, struct lysc_ext_instance *ext, ly_b
     return LY_SUCCESS;
 }
 
+/**
+ * @brief Snode xpath callback for yang-data.
+ */
+static LY_ERR
+yangdata_snode_xpath(struct lysc_ext_instance *ext, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        void *prefix_data, const char *name, uint32_t name_len, const struct lysc_node **snode)
+{
+    return yangdata_snode(ext, NULL, NULL, prefix, prefix_len, format, prefix_data, name, name_len, snode);
+}
+
 /**
  * @brief Snode callback for yang-data.
  */
 static LY_ERR
 yangdata_snode(struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct lysc_node *sparent,
-        const char *prefix, uint32_t UNUSED(prefix_len), LY_VALUE_FORMAT UNUSED(format), void *UNUSED(prefix_data),
-        const char *name, uint32_t UNUSED(name_len), ly_bool UNUSED(in_xpath), const struct lysc_node **snode)
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, const struct lysc_node **snode)
 {
-    assert(!parent && !sparent && !prefix && !name);
-    (void)parent;
-    (void)sparent;
-    (void)prefix;
-    (void)name;
+    const struct lysc_node *schema = ext->compiled;
+    const struct lys_module *mod;
 
-    /* first top-level node */
-    *snode = ext->compiled;
+    if (parent || sparent) {
+        /* matches only top-level data */
+        return LY_ENOT;
+    }
 
-    return LY_SUCCESS;
+    if (prefix && prefix_len) {
+        /* check module */
+        mod = lys_find_module(ext->module->ctx, NULL, prefix, prefix_len, format, prefix_data);
+        if (!mod || (ext->module != mod)) {
+            return LY_ENOT;
+        }
+    }
+
+    /* check name */
+    if (name && name_len) {
+        LY_LIST_FOR(schema, schema) {
+            if (!ly_strncmp(schema->name, name, name_len)) {
+                break;
+            }
+        }
+    }
+
+    /* first top-level node or the found one, if any */
+    *snode = schema;
+    return schema ? LY_SUCCESS : LY_ENOT;
+}
+
+/**
+ * @brief Validate callback for yang-data.
+ */
+static LY_ERR
+yangdata_validate(struct lysc_ext_instance *ext, struct lyd_node *node, const struct lyd_node *UNUSED(dep_tree),
+        enum lyd_type data_type, uint32_t val_opts, struct lyd_node **diff)
+{
+    if (data_type != LYD_TYPE_DATA_YANG) {
+        /* not supported */
+        return LY_ENOT;
+    }
+
+    /* validate all the modules with data */
+    return lyd_validate_ext(&node, ext, val_opts, diff);
 }
 
 /**
@@ -306,8 +355,9 @@ const struct lyplg_ext_record plugins_yangdata[] = {
         .plugin.printer_ctree = yangdata_sprinter_ctree,
         .plugin.printer_ptree = yangdata_sprinter_ptree,
         .plugin.node_xpath = NULL,
+        .plugin.snode_xpath = yangdata_snode_xpath,
         .plugin.snode = yangdata_snode,
-        .plugin.validate = NULL,
+        .plugin.validate = yangdata_validate,
         .plugin.pfree = yangdata_pfree,
         .plugin.cfree = yangdata_cfree,
         .plugin.compiled_size = yandgata_compiled_size,
