@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Built-in types plugins and interface for user types plugins.
  *
- * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -40,141 +40,6 @@
 #include "xml.h"
 #include "xpath.h"
 
-/**
- * @brief Find import prefix in imports.
- */
-static const struct lys_module *
-ly_schema_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len, const void *prefix_data)
-{
-    const struct lysp_module *prefix_mod = prefix_data;
-    LY_ARRAY_COUNT_TYPE u;
-    const char *local_prefix;
-
-    local_prefix = prefix_mod->is_submod ? ((struct lysp_submodule *)prefix_mod)->prefix : prefix_mod->mod->prefix;
-    if (!prefix_len || !ly_strncmp(local_prefix, prefix, prefix_len)) {
-        /* it is the prefix of the module itself */
-        return prefix_mod->mod;
-    }
-
-    /* search in imports */
-    LY_ARRAY_FOR(prefix_mod->imports, u) {
-        if (!ly_strncmp(prefix_mod->imports[u].prefix, prefix, prefix_len)) {
-            return prefix_mod->imports[u].module;
-        }
-    }
-
-    return NULL;
-}
-
-/**
- * @brief Find resolved module for a prefix in prefix - module pairs.
- */
-static const struct lys_module *
-ly_schema_resolved_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len,
-        const void *prefix_data)
-{
-    const struct lysc_prefix *prefixes = prefix_data;
-    LY_ARRAY_COUNT_TYPE u;
-
-    LY_ARRAY_FOR(prefixes, u) {
-        if ((!prefixes[u].prefix && !prefix_len) || (prefixes[u].prefix && !ly_strncmp(prefixes[u].prefix, prefix, prefix_len))) {
-            return prefixes[u].mod;
-        }
-    }
-
-    return NULL;
-}
-
-/**
- * @brief Find XML namespace prefix in XML namespaces, which are then mapped to modules.
- */
-static const struct lys_module *
-ly_xml_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *prefix_data)
-{
-    const struct lys_module *mod;
-    const struct lyxml_ns *ns;
-    const struct ly_set *ns_set = prefix_data;
-
-    ns = lyxml_ns_get(ns_set, prefix, prefix_len);
-    if (!ns) {
-        return NULL;
-    }
-
-    mod = ly_ctx_get_module_implemented_ns(ctx, ns->uri);
-    if (!mod) {
-        /* for YIN extension prefix resolution */
-        mod = ly_ctx_get_module_latest_ns(ctx, ns->uri);
-    }
-    return mod;
-}
-
-/**
- * @brief Find module name.
- */
-static const struct lys_module *
-ly_json_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *UNUSED(prefix_data))
-{
-    return ly_ctx_get_module_implemented2(ctx, prefix, prefix_len);
-}
-
-const struct lys_module *
-ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
-        const void *prefix_data)
-{
-    const struct lys_module *mod = NULL;
-
-    LY_CHECK_ARG_RET(ctx, prefix, prefix_len, NULL);
-
-    switch (format) {
-    case LY_VALUE_SCHEMA:
-        mod = ly_schema_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        break;
-    case LY_VALUE_SCHEMA_RESOLVED:
-        mod = ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        break;
-    case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
-        mod = ly_xml_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        break;
-    case LY_VALUE_CANON:
-    case LY_VALUE_JSON:
-    case LY_VALUE_LYB:
-        mod = ly_json_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        break;
-    }
-
-    return mod;
-}
-
-LIBYANG_API_DEF const struct lys_module *
-lyplg_type_identity_module(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const char *prefix,
-        uint32_t prefix_len, LY_VALUE_FORMAT format, const void *prefix_data)
-{
-    if (prefix_len) {
-        return ly_resolve_prefix(ctx, prefix, prefix_len, format, prefix_data);
-    } else {
-        switch (format) {
-        case LY_VALUE_SCHEMA:
-            /* use local module */
-            return ly_schema_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        case LY_VALUE_SCHEMA_RESOLVED:
-            /* use local module */
-            return ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
-        case LY_VALUE_CANON:
-        case LY_VALUE_JSON:
-        case LY_VALUE_LYB:
-        case LY_VALUE_STR_NS:
-            /* use context node module (as specified) */
-            return ctx_node ? ctx_node->module : NULL;
-        case LY_VALUE_XML:
-            /* use the default namespace */
-            return ly_xml_resolve_prefix(ctx, NULL, 0, prefix_data);
-        }
-    }
-
-    return NULL;
-}
-
 /**
  * @brief Find module in import prefixes.
  */
@@ -867,8 +732,8 @@ lyplg_type_lypath_check_status(const struct lysc_node *ctx_node, const struct ly
 
 LIBYANG_API_DEF LY_ERR
 lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, uint32_t value_len, uint32_t options,
-        LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext,
-        struct lys_glob_unres *unres, struct ly_path **path, struct ly_err_item **err)
+        LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *ctx_node, struct lys_glob_unres *unres,
+        struct ly_path **path, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lyxp_expr *exp = NULL;
@@ -917,7 +782,7 @@ lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, uint32_t valu
 
     /* resolve it on schema tree */
     oper = (ctx_node && (ctx_node->flags & LYS_IS_OUTPUT)) ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    ret = ly_path_compile(ctx, NULL, ctx_node, top_ext, exp, oper, LY_PATH_TARGET_SINGLE, 1, format, prefix_data, path);
+    ret = ly_path_compile(ctx, ctx_node, exp, oper, LY_PATH_TARGET_SINGLE, 1, format, prefix_data, path);
     if (ret) {
         err_fmt = "Invalid instance-identifier \"%.*s\" value - semantic error%s%s";
         goto cleanup;
@@ -963,10 +828,10 @@ lyplg_type_print_val(const struct lysc_node *node, const char *canon, LY_VALUE_F
 
     /* store the value */
     r = type_plg->store(node->module->ctx, type, canon, strlen(canon) * 8, LYPLG_TYPE_STORE_ONLY, LY_VALUE_CANON,
-            NULL, LYD_HINT_DATA, node, NULL, &storage, NULL, &err);
+            NULL, LYD_HINT_DATA, node, &storage, NULL, &err);
     if (r && (r != LY_EINCOMPLETE)) {
         if (err) {
-            ly_err_print(node->module->ctx, err);
+            ly_err_print(node->module->ctx, err, NULL, node);
             ly_err_free(err);
         }
         return r;
@@ -1022,7 +887,6 @@ lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_i
  *
  * @param[in] path Leafref path.
  * @param[in] ctx_node Leafref context node.
- * @param[in] top_ext Extension instance whose XPath context we are evaluating in.
  * @param[in] format Format of @p path.
  * @param[in] prefix_data Prefix data of @p path.
  * @param[in] target_val Leafref target value.
@@ -1033,8 +897,7 @@ lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_i
  */
 static LY_ERR
 lyplg_type_resolve_leafref_get_target_path(const struct lyxp_expr *path, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *top_ext, LY_VALUE_FORMAT format, void *prefix_data, const char *target_val,
-        struct lyxp_expr **target_path)
+        LY_VALUE_FORMAT format, void *prefix_data, const char *target_val, struct lyxp_expr **target_path)
 {
     LY_ERR rc = LY_SUCCESS;
     uint8_t oper;
@@ -1047,7 +910,7 @@ lyplg_type_resolve_leafref_get_target_path(const struct lyxp_expr *path, const s
 
     /* compile, has already been so it must succeed */
     oper = (ctx_node->flags & LYS_IS_OUTPUT) ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    if (ly_path_compile_leafref(ctx_node->module->ctx, ctx_node, top_ext, path, oper, LY_PATH_TARGET_MANY, format,
+    if (ly_path_compile_leafref(ctx_node->module->ctx, ctx_node, path, oper, LY_PATH_TARGET_MANY, format,
             prefix_data, &p)) {
         /* the target was found before but is disabled so it was removed */
         return LY_ENOT;
@@ -1091,7 +954,7 @@ lyplg_type_resolve_leafref_get_target_path(const struct lyxp_expr *path, const s
     }
 
     /* parse into an expression */
-    LY_CHECK_GOTO(lyxp_expr_parse(ctx_node->module->ctx, str_path, 0, 1, target_path), cleanup);
+    LY_CHECK_GOTO(lyxp_expr_parse(ctx_node->module->ctx, NULL, str_path, 0, 1, target_path), cleanup);
 
 cleanup:
     ly_path_free(p);
@@ -1101,7 +964,7 @@ cleanup:
 
 LIBYANG_API_DEF LY_ERR
 lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct lyd_node *node, struct lyd_value *value,
-        const struct lyd_node *tree, const struct lysc_ext_instance *top_ext, struct ly_set **targets, char **errmsg)
+        const struct lyd_node *tree, struct ly_set **targets, char **errmsg)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lyxp_expr *target_path = NULL;
@@ -1124,7 +987,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
 
     if (!strchr(val_str, '\"') || !strchr(val_str, '\'')) {
         /* get the path with the value */
-        r = lyplg_type_resolve_leafref_get_target_path(lref->path, node->schema, top_ext, LY_VALUE_SCHEMA_RESOLVED,
+        r = lyplg_type_resolve_leafref_get_target_path(lref->path, node->schema, LY_VALUE_SCHEMA_RESOLVED,
                 lref->prefixes, val_str, &target_path);
         if (r == LY_ENOT) {
             goto cleanup;
@@ -1136,7 +999,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
 
     /* find the target data instance(s) */
     rc = lyxp_eval(LYD_CTX(node), target_path ? target_path : lref->path, node->schema->module,
-            LY_VALUE_SCHEMA_RESOLVED, lref->prefixes, node, node, tree, NULL, top_ext, &set, LYXP_IGNORE_WHEN);
+            LY_VALUE_SCHEMA_RESOLVED, lref->prefixes, node, node, tree, NULL, &set, LYXP_IGNORE_WHEN);
     if (rc) {
         e = ly_err_last(LYD_CTX(node));
         if (e && (e->err == rc)) {
