@@ -109,7 +109,7 @@ identityref_str2ident(const char *value, uint32_t value_size, LY_VALUE_FORMAT fo
         return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid empty identityref value.");
     }
 
-    mod = lyplg_type_identity_module(ctx, ctx_node, prefix, prefix_len, format, prefix_data);
+    mod = lys_find_module(ctx, ctx_node, prefix, prefix_len, format, prefix_data);
     if (!mod) {
         return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL,
                 "Invalid identityref \"%.*s\" value - unable to map prefix to YANG schema.", (int)value_size, value);
@@ -206,8 +206,8 @@ identityref_check_base(const struct lysc_ident *ident, struct lysc_type_identity
  * @return LY_ERR value.
  */
 static LY_ERR
-identityref_check_ident(const struct lysc_ident *ident, const char *value,
-        uint32_t value_size, uint32_t options, struct lys_glob_unres *unres, struct ly_err_item **err)
+identityref_check_ident(const struct lysc_ident *ident, const char *value, uint32_t value_size, uint32_t options,
+        struct lys_glob_unres *unres, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
 
@@ -231,8 +231,7 @@ identityref_check_ident(const struct lysc_ident *ident, const char *value,
 static LY_ERR
 lyplg_type_store_identityref(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *UNUSED(top_ext), struct lyd_value *storage, struct lys_glob_unres *unres,
-        struct ly_err_item **err)
+        struct lyd_value *storage, struct lys_glob_unres *unres, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lysc_type_identityref *type_ident = (struct lysc_type_identityref *)type;
