@@ -77,7 +77,7 @@ lyplg_type_xpath10_print_token(const char *token, uint16_t tok_len, ly_bool is_n
             has_prefix = 1;
 
             /* resolve the module in the original format */
-            mod = lyplg_type_identity_module(resolve_ctx, NULL, str_begin, len, resolve_format, resolve_prefix_data);
+            mod = lys_find_module(resolve_ctx, NULL, str_begin, len, resolve_format, resolve_prefix_data);
             if (!mod && is_nametest) {
                 ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Failed to resolve prefix \"%.*s\".",
                         (int)len, str_begin);
@@ -245,11 +245,11 @@ lyplg_type_print_xpath10_value(const struct lyd_value_xpath10 *xp_val, LY_VALUE_
 static LY_ERR
 lyplg_type_store_xpath10(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *UNUSED(top_ext), struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres),
-        struct ly_err_item **err)
+        struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres), struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
-    uint32_t value_size;
+    const struct ly_err_item *e;
+    uint32_t value_size, temp_lo = LY_LOSTORE;
     struct lyd_value_xpath10 *val;
     char *canon;
 
@@ -269,8 +269,18 @@ lyplg_type_store_xpath10(const struct ly_ctx *ctx, const struct lysc_type *type,
     LY_CHECK_GOTO(ret, cleanup);
 
     /* parse */
-    ret = lyxp_expr_parse(ctx, value_size ? value : "", value_size, 1, &val->exp);
-    LY_CHECK_GOTO(ret, cleanup);
+    ly_temp_log_options(&temp_lo);
+    ret = lyxp_expr_parse(ctx, NULL, value_size ? value : "", value_size, 1, &val->exp);
+    ly_temp_log_options(NULL);
+    if (ret) {
+        /* get a copy of the error */
+        e = ly_err_last(ctx);
+        if (e) {
+            ly_err_new(err, e->err, e->vecode, e->data_path, e->apptag, "%s", e->msg);
+            ly_err_clean(ctx, (struct ly_err_item *)e);
+        }
+        goto cleanup;
+    }
     val->ctx = ctx;
 
     if (ctx_node && !strcmp(ctx_node->name, "parent-reference") && !strcmp(ctx_node->module->name, "ietf-yang-schema-mount")) {
@@ -373,8 +383,8 @@ cleanup:
  */
 static LY_ERR
 lyplg_type_validate_tree_xpath10(const struct ly_ctx *UNUSED(ctx), const struct lysc_type *UNUSED(type),
-        const struct lyd_node *ctx_node, const struct lyd_node *UNUSED(tree), const struct lysc_ext_instance *UNUSED(top_ext),
-        struct lyd_value *storage, struct ly_err_item **err)
+        const struct lyd_node *ctx_node, const struct lyd_node *UNUSED(tree), struct lyd_value *storage,
+        struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lyd_value_xpath10 *val;
@@ -457,7 +467,7 @@ lyplg_type_print_xpath10(const struct ly_ctx *ctx, const struct lyd_value *value
     /* print in the specific format */
     if (lyplg_type_print_xpath10_value(val, format, prefix_data, &ret, &err)) {
         if (err) {
-            ly_err_print(ctx, err);
+            ly_err_print(ctx, err, NULL, NULL);
             ly_err_free(err);
         }
         return NULL;
