@@ -553,7 +553,7 @@ json_print_attributes(struct jsonpr_ctx *pctx, const struct lyd_node *node, ly_b
 
     if (node->schema && (df_mod || node_has_printable_meta(node))) {
         if (inner) {
-            LY_CHECK_RET(json_print_member2(pctx, lyd_parent(node), LY_VALUE_JSON, NULL, 1));
+            LY_CHECK_RET(json_print_member2(pctx, node->parent, LY_VALUE_JSON, NULL, 1));
         } else {
             LY_CHECK_RET(json_print_member(pctx, node, NULL, 1));
         }
@@ -565,9 +565,9 @@ json_print_attributes(struct jsonpr_ctx *pctx, const struct lyd_node *node, ly_b
         LEVEL_PRINTED;
     } else if (!node->schema && ((struct lyd_node_opaq *)node)->attr) {
         if (inner) {
-            LY_CHECK_RET(json_print_member2(pctx, lyd_parent(node), LY_VALUE_JSON, NULL, 1));
+            LY_CHECK_RET(json_print_member2(pctx, node->parent, LY_VALUE_JSON, NULL, 1));
         } else {
-            LY_CHECK_RET(json_print_member2(pctx, lyd_parent(node), ((struct lyd_node_opaq *)node)->format,
+            LY_CHECK_RET(json_print_member2(pctx, node->parent, ((struct lyd_node_opaq *)node)->format,
                     &((struct lyd_node_opaq *)node)->name, 1));
         }
         ly_print_(pctx->out, "{%s", (DO_FORMAT ? "\n" : ""));
@@ -633,7 +633,7 @@ json_print_any_content(struct jsonpr_ctx *pctx, struct lyd_node_any *any)
         prev_opts = pctx->options;
         pctx->parent = &any->node;
         pctx->options &= ~LYD_PRINT_SIBLINGS;
-        LY_LIST_FOR(any->value.tree, iter) {
+        LY_LIST_FOR(any->child, iter) {
             ret = json_print_node(pctx, iter);
             LY_CHECK_ERR_RET(ret, LEVEL_DEC, ret);
         }
@@ -649,7 +649,7 @@ json_print_any_content(struct jsonpr_ctx *pctx, struct lyd_node_any *any)
         }
         break;
     case LYD_ANYDATA_JSON:
-        if (!any->value.json) {
+        if (!any->value) {
             /* no content */
             if (any->schema->nodetype == LYS_ANYXML) {
                 ly_print_(pctx->out, "null");
@@ -658,12 +658,12 @@ json_print_any_content(struct jsonpr_ctx *pctx, struct lyd_node_any *any)
             }
         } else {
             /* print without escaping special characters */
-            ly_print_(pctx->out, "%s", any->value.json);
+            ly_print_(pctx->out, "%s", any->value);
         }
         break;
     case LYD_ANYDATA_STRING:
     case LYD_ANYDATA_XML:
-        if (!any->value.str) {
+        if (!any->value) {
             /* no content */
             if (any->schema->nodetype == LYS_ANYXML) {
                 ly_print_(pctx->out, "null");
@@ -672,7 +672,7 @@ json_print_any_content(struct jsonpr_ctx *pctx, struct lyd_node_any *any)
             }
         } else {
             /* print as a string */
-            json_print_string(pctx->out, any->value.str);
+            json_print_string(pctx->out, any->value);
         }
         break;
     }
@@ -934,7 +934,7 @@ json_print_meta_attr_leaflist(struct jsonpr_ctx *pctx)
         LY_CHECK_RET(json_print_member(pctx, node, NULL, 1));
     } else {
         opaq = (struct lyd_node_opaq *)node;
-        LY_CHECK_RET(json_print_member2(pctx, lyd_parent(node), opaq->format, &opaq->name, 1));
+        LY_CHECK_RET(json_print_member2(pctx, node->parent, opaq->format, &opaq->name, 1));
     }
 
     ly_print_(pctx->out, "[%s", (DO_FORMAT ? "\n" : ""));
