@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Parsing and validation common functions for data trees
  *
- * Copyright (c) 2015 - 2024 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -126,7 +126,8 @@ lyd_dup_inst_next(struct lyd_node **inst, struct ly_ht **dup_inst_ht)
     }
 
     if (dup_inst->used == dup_inst->set->count) {
-        if (lysc_is_dup_inst_list((*inst)->schema)) {
+        /* config user-ordered data with several instances are invalid, but it can be supported */
+        if (lysc_is_dup_inst_list((*inst)->schema) || lysc_is_userordered((*inst)->schema)) {
             /* we have used all the instances */
             *inst = NULL;
         } /* else just keep using the last (ideally only) instance */
@@ -304,7 +305,7 @@ lyd_owner_module(const struct lyd_node *node)
     }
 
     while (!node->schema && node->parent) {
-        node = lyd_parent(node);
+        node = node->parent;
     }
 
     if (!node->schema) {
@@ -359,7 +360,7 @@ lyd_node_module(const struct lyd_node *node)
             break;
         }
 
-        node = lyd_parent(node);
+        node = node->parent;
     }
 
     return NULL;
@@ -477,39 +478,10 @@ lyd_data_next_module(struct lyd_node **next, struct lyd_node **first)
     return mod;
 }
 
-/**
- * @brief Log generated error item and use log location information if not in the error item.
- *
- * @param[in] ctx Context to use.
- * @param[in] node Optional data node to log.
- * @param[in] scnode Optional schema node to log.
- * @param[in] eitem Error item to log.
- */
-static void
-ly_err_print_build_path(const struct ly_ctx *ctx, const struct lyd_node *node, const struct lysc_node *scnode,
-        struct ly_err_item *eitem)
-{
-    if (eitem->data_path || eitem->schema_path || eitem->line) {
-        ly_err_print(ctx, eitem);
-    } else {
-        if (node) {
-            LOG_LOCSET(NULL, node);
-        } else if (scnode) {
-            LOG_LOCSET(scnode, NULL);
-        }
-        ly_vlog(ctx, eitem->apptag, eitem->err == LY_EVALID ? eitem->vecode : LYVE_DATA, "%s", eitem->msg);
-        if (node) {
-            LOG_LOCBACK(0, 1);
-        } else if (scnode) {
-            LOG_LOCBACK(1, 0);
-        }
-    }
-}
-
 LY_ERR
-lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct lysc_type *type, const void *value,
-        uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format,
-        void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext,
+lyd_value_store(const struct ly_ctx *ctx, const struct lyd_node *lnode, struct lyd_value *val,
+        const struct lysc_type *type, const void *value, uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only,
+        ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_snode,
         ly_bool *incomplete)
 {
     LY_ERR r;
@@ -535,7 +507,7 @@ lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct ly
     }
 
     r = LYSC_GET_TYPE_PLG(type->plugin_ref)->store(ctx, type, value, value_size_bits, options, format, prefix_data,
-            hints, ctx_node, top_ext, val, NULL, &err);
+            hints, ctx_snode, val, NULL, &err);
     if (dynamic) {
         *dynamic = 0;
     }
@@ -546,10 +518,16 @@ lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct ly
         }
     } else if (r) {
         if (err) {
-            ly_err_print_build_path(ctx, NULL, ctx_node, err);
+            ly_err_print(ctx, err, lnode, ctx_snode);
             ly_err_free(err);
         } else {
-            LOGVAL(ctx, LYVE_OTHER, "Storing value failed.");
+            if (ctx_snode) {
+                LOG_LOCSET(ctx_snode);
+            }
+            LOGVAL(ctx, NULL, LYVE_OTHER, "Storing value failed.");
+            if (ctx_snode) {
+                LOG_LOCBACK(1);
+            }
         }
         return r;
     }
@@ -559,7 +537,7 @@ lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct ly
 
 LY_ERR
 lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *type, struct lyd_value *val,
-        const struct lyd_node *ctx_node, const struct lyd_node *tree, const struct lysc_ext_instance *top_ext)
+        const struct lyd_node *ctx_node, const struct lyd_node *tree)
 {
     LY_ERR ret;
     struct ly_err_item *err = NULL;
@@ -568,13 +546,13 @@ lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *
     type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
     assert(type_plg && type_plg->validate_tree);
 
-    ret = type_plg->validate_tree(ctx, type, ctx_node, tree, top_ext, val, &err);
+    ret = type_plg->validate_tree(ctx, type, ctx_node, tree, val, &err);
     if (ret) {
         if (err) {
-            ly_err_print_build_path(ctx, ctx_node, NULL, err);
+            ly_err_print(ctx, err, ctx_node, NULL);
             ly_err_free(err);
         } else {
-            LOGVAL(ctx, LYVE_OTHER, "Resolving value \"%s\" failed.",
+            LOGVAL(ctx, ctx_node, LYVE_OTHER, "Resolving value \"%s\" failed.",
                     (char *)type_plg->print(ctx, val, LY_VALUE_CANON, NULL, NULL, NULL));
         }
         return ret;
@@ -585,7 +563,7 @@ lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *
 
 LY_ERR
 ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const void *value, uint32_t value_size_bits,
-        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_ext_instance *top_ext)
+        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints)
 {
     LY_ERR rc = LY_SUCCESS;
     struct ly_err_item *err = NULL;
@@ -601,14 +579,14 @@ ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const
 
     type = ((struct lysc_node_leaf *)node)->type;
     rc = LYSC_GET_TYPE_PLG(type->plugin_ref)->store(ctx ? ctx : node->module->ctx, type, value,
-            value_size_bits, 0, format, prefix_data, hints, node, top_ext, &storage, NULL, &err);
+            value_size_bits, 0, format, prefix_data, hints, node, &storage, NULL, &err);
     if (rc == LY_EINCOMPLETE) {
         /* actually success */
         rc = LY_SUCCESS;
     } else if (rc && err) {
         if (ctx) {
             /* log only in case the ctx was provided as input parameter */
-            ly_err_print_build_path(ctx, NULL, node, err);
+            ly_err_print(ctx, err, NULL, node);
         }
         ly_err_free(err);
     }
@@ -625,7 +603,7 @@ lyd_value_validate(const struct lysc_node *schema, const char *value, uint32_t v
 {
     LY_CHECK_ARG_RET(NULL, schema, !value_len || value, LY_EINVAL);
 
-    return lyd_value_validate3(schema, value, value_len, LY_VALUE_JSON, NULL, LYD_HINT_DATA, ctx_node, NULL,
+    return lyd_value_validate3(schema, value, value_len, LY_VALUE_JSON, NULL, LYD_HINT_DATA, ctx_node,
             1, realtype, canonical);
 }
 
@@ -636,13 +614,13 @@ lyd_value_validate_dflt(const struct lysc_node *schema, const char *value, struc
     LY_CHECK_ARG_RET(NULL, schema, LY_EINVAL);
 
     return lyd_value_validate3(schema, value, value ? strlen(value) : 0, LY_VALUE_SCHEMA_RESOLVED, prefixes,
-            LYD_HINT_SCHEMA, ctx_node, NULL, 1, realtype, canonical);
+            LYD_HINT_SCHEMA, ctx_node, 1, realtype, canonical);
 }
 
 LY_ERR
 lyd_value_validate3(const struct lysc_node *schema, const char *value, size_t value_len, LY_VALUE_FORMAT format,
-        void *prefix_data, uint32_t hints, const struct lyd_node *ctx_node, const struct lysc_ext_instance *top_ext,
-        int log, const struct lysc_type **realtype, const char **canonical)
+        void *prefix_data, uint32_t hints, const struct lyd_node *ctx_node, int log, const struct lysc_type **realtype,
+        const char **canonical)
 {
     LY_ERR rc;
     const struct ly_ctx *ctx;
@@ -661,20 +639,20 @@ lyd_value_validate3(const struct lysc_node *schema, const char *value, size_t va
     type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
 
     /* store */
-    rc = type_plg->store(ctx, type, value, value_len * 8, 0, format, prefix_data, hints, schema, top_ext, &val, NULL, &err);
+    rc = type_plg->store(ctx, type, value, value_len * 8, 0, format, prefix_data, hints, schema, &val, NULL, &err);
     if (!rc || (rc == LY_EINCOMPLETE)) {
         stored = 1;
     }
 
     if (ctx_node && (rc == LY_EINCOMPLETE)) {
         /* resolve */
-        rc = type_plg->validate_tree(ctx, type, ctx_node, ctx_node, top_ext, &val, &err);
+        rc = type_plg->validate_tree(ctx, type, ctx_node, ctx_node, &val, &err);
     }
 
     if (rc && (rc != LY_EINCOMPLETE) && err) {
         if (log) {
             /* log error */
-            ly_err_print_build_path(ctx, ctx_node, schema, err);
+            ly_err_print(ctx, err, ctx_node, schema);
         }
         ly_err_free(err);
     }
@@ -707,22 +685,19 @@ LIBYANG_API_DEF LY_ERR
 lyd_value_compare(const struct lyd_node_term *node, const char *value, uint32_t value_len)
 {
     LY_ERR ret = LY_SUCCESS;
-    struct ly_ctx *ctx;
+    const struct ly_ctx *ctx;
     struct lysc_type *type;
     struct lyd_value val = {0};
     struct lyplg_type *type_plg;
 
-    LY_CHECK_ARG_RET(node ? node->schema->module->ctx : NULL, node, value, LY_EINVAL);
+    LY_CHECK_ARG_RET(node ? LYD_CTX(node) : NULL, node, value, LY_EINVAL);
 
-    ctx = node->schema->module->ctx;
+    ctx = LYD_CTX(node);
     type = ((struct lysc_node_leaf *)node->schema)->type;
 
     /* store the value */
-    LOG_LOCSET(NULL, &node->node);
-    ret = lyd_value_store(ctx, &val, type, value, value_len * 8, 0, 0, NULL, LY_VALUE_JSON, NULL, LYD_HINT_DATA,
-            node->schema, NULL, NULL);
-    LOG_LOCBACK(0, 1);
-    LY_CHECK_RET(ret);
+    LY_CHECK_RET(lyd_value_store(ctx, &node->node, &val, type, value, value_len * 8, 0, 0, NULL, LY_VALUE_JSON, NULL,
+            LYD_HINT_DATA, node->schema, NULL));
 
     /* compare values */
     type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
@@ -803,7 +778,7 @@ lyd_first_sibling(const struct lyd_node *node)
 
     /* get the first sibling */
     if (node->parent) {
-        return node->parent->child;
+        return ((struct lyd_node_inner *)node->parent)->child;
     } else if (!node->prev->next) {
         return (struct lyd_node *)node;
     }
@@ -864,13 +839,13 @@ lyd_parse_opaq_list_error(const struct lyd_node *node, const struct lysc_node *s
         /* check value */
         opaq_k = (struct lyd_node_opaq *)child;
         ret = ly_value_validate(LYD_CTX(node), key, opaq_k->value, strlen(opaq_k->value) * 8, opaq_k->format,
-                opaq_k->val_prefix_data, opaq_k->hints, NULL);
+                opaq_k->val_prefix_data, opaq_k->hints);
         LY_CHECK_GOTO(ret, cleanup);
     }
 
     if (key_set.count) {
         /* missing keys */
-        LOGVAL(LYD_CTX(node), LY_VCODE_NOKEY, key_set.snodes[0]->name);
+        LOGVAL(LYD_CTX(node), node->parent, LY_VCODE_NOKEY, key_set.snodes[0]->name);
         ret = LY_EVALID;
         goto cleanup;
     }
@@ -889,21 +864,17 @@ lyd_parse_opaq_error(const struct lyd_node *node)
     const struct lyd_node *parent;
     const struct lys_module *mod;
     const struct lysc_node *sparent, *snode;
-    uint32_t loc_scnode = 0, loc_dnode = 0;
+    uint32_t loc_scnode = 0;
 
     LY_CHECK_ARG_RET(LYD_CTX(node), node, !node->schema, LY_EINVAL);
 
     ctx = LYD_CTX(node);
     opaq = (struct lyd_node_opaq *)node;
-    parent = lyd_parent(node);
+    parent = node->parent;
     sparent = lyd_node_schema(parent);
 
-    /* if parent is NULL, it is still added as root */
-    LOG_LOCSET(NULL, parent);
-    loc_dnode = 1;
-
     if (!opaq->name.module_ns) {
-        LOGVAL(ctx, LYVE_REFERENCE, "Unknown module of node \"%s\".", opaq->name.name);
+        LOGVAL(ctx, parent, LYVE_REFERENCE, "Unknown module of node \"%s\".", opaq->name.name);
         rc = LY_EVALID;
         goto cleanup;
     }
@@ -914,7 +885,7 @@ lyd_parse_opaq_error(const struct lyd_node *node)
         if (!sparent || strcmp(opaq->name.module_ns, sparent->module->ns)) {
             mod = ly_ctx_get_module_implemented_ns(ctx, opaq->name.module_ns);
             if (!mod) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No (implemented) module with namespace \"%s\" of node \"%s\" in the context.",
+                LOGVAL(ctx, parent, LYVE_REFERENCE, "No (implemented) module with namespace \"%s\" of node \"%s\" in the context.",
                         opaq->name.module_ns, opaq->name.name);
                 rc = LY_EVALID;
                 goto cleanup;
@@ -929,7 +900,7 @@ lyd_parse_opaq_error(const struct lyd_node *node)
         if (!sparent || strcmp(opaq->name.module_name, sparent->module->name)) {
             mod = ly_ctx_get_module_implemented(ctx, opaq->name.module_name);
             if (!mod) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No (implemented) module named \"%s\" of node \"%s\" in the context.",
+                LOGVAL(ctx, parent, LYVE_REFERENCE, "No (implemented) module named \"%s\" of node \"%s\" in the context.",
                         opaq->name.module_name, opaq->name.name);
                 rc = LY_EVALID;
                 goto cleanup;
@@ -946,32 +917,30 @@ lyd_parse_opaq_error(const struct lyd_node *node)
     }
 
     /* schema */
-    snode = lys_find_child(sparent, mod, opaq->name.name, 0, 0, 0);
+    snode = lys_find_child(LYD_CTX(node), sparent, mod, NULL, 0, opaq->name.name, 0, 0);
     if (!snode && sparent && (sparent->nodetype & (LYS_RPC | LYS_ACTION))) {
         /* maybe output node */
-        snode = lys_find_child(sparent, mod, opaq->name.name, 0, 0, LYS_GETNEXT_OUTPUT);
+        snode = lys_find_child(LYD_CTX(node), sparent, mod, NULL, 0, opaq->name.name, 0, LYS_GETNEXT_OUTPUT);
     }
     if (!snode) {
         if (sparent) {
-            LOGVAL(ctx, LYVE_REFERENCE, "Node \"%s\" not found as a child of \"%s\" node.", opaq->name.name,
+            LOGVAL(ctx, parent, LYVE_REFERENCE, "Node \"%s\" not found as a child of \"%s\" node.", opaq->name.name,
                     sparent->name);
         } else {
-            LOGVAL(ctx, LYVE_REFERENCE, "Node \"%s\" not found in the \"%s\" module.", opaq->name.name, mod->name);
+            LOGVAL(ctx, parent, LYVE_REFERENCE, "Node \"%s\" not found in the \"%s\" module.", opaq->name.name, mod->name);
         }
         rc = LY_EVALID;
         goto cleanup;
     }
 
     /* schema node exists */
-    LOG_LOCBACK(0, 1);
-    loc_dnode = 0;
-    LOG_LOCSET(snode, NULL);
+    LOG_LOCSET(snode);
     loc_scnode = 1;
 
     if (snode->nodetype & LYD_NODE_TERM) {
         /* leaf / leaf-list */
         rc = ly_value_validate(ctx, snode, opaq->value, strlen(opaq->value) * 8, opaq->format, opaq->val_prefix_data,
-                opaq->hints, NULL);
+                opaq->hints);
         LY_CHECK_GOTO(rc, cleanup);
     } else if (snode->nodetype == LYS_LIST) {
         /* list */
@@ -980,7 +949,7 @@ lyd_parse_opaq_error(const struct lyd_node *node)
     } else if (snode->nodetype & LYD_NODE_INNER) {
         /* inner node */
         if (opaq->value) {
-            LOGVAL(ctx, LYVE_DATA, "Invalid value \"%s\" for %s \"%s\".", opaq->value,
+            LOGVAL(ctx, NULL, LYVE_DATA, "Invalid value \"%s\" for %s \"%s\".", opaq->value,
                     lys_nodetype2str(snode->nodetype), snode->name);
             rc = LY_EVALID;
             goto cleanup;
@@ -995,7 +964,7 @@ lyd_parse_opaq_error(const struct lyd_node *node)
     rc = LY_EINVAL;
 
 cleanup:
-    LOG_LOCBACK(loc_scnode, loc_dnode);
+    LOG_LOCBACK(loc_scnode);
     return rc;
 }
 
@@ -1022,20 +991,20 @@ lyd_any_value_str(const struct lyd_node *any, char **value_str)
     a = (struct lyd_node_any *)any;
     *value_str = NULL;
 
-    if (!a->value.str) {
+    if (!a->child && !a->value) {
         /* there is no value in the union */
         return LY_SUCCESS;
     }
 
     switch (a->value_type) {
     case LYD_ANYDATA_DATATREE:
-        tree = a->value.tree;
+        tree = a->child;
         break;
     case LYD_ANYDATA_STRING:
     case LYD_ANYDATA_XML:
     case LYD_ANYDATA_JSON:
         /* simply use the string */
-        str = a->value.str;
+        str = a->value;
         break;
     }
 
@@ -1054,9 +1023,10 @@ cleanup:
 }
 
 LIBYANG_API_DEF LY_ERR
-lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_ANYDATA_VALUETYPE value_type)
+lyd_any_copy_value(struct lyd_node *trg, const void *value, LYD_ANYDATA_VALUETYPE value_type)
 {
     struct lyd_node_any *t;
+    struct lyd_node *node;
 
     LY_CHECK_ARG_RET(NULL, trg, LY_EINVAL);
     LY_CHECK_ARG_RET(NULL, trg->schema, trg->schema->nodetype & LYS_ANYDATA, LY_EINVAL);
@@ -1066,15 +1036,16 @@ lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_A
     /* free trg */
     switch (t->value_type) {
     case LYD_ANYDATA_DATATREE:
-        lyd_free_all(t->value.tree);
+        lyd_free_siblings(t->child);
+        t->child = NULL;
         break;
     case LYD_ANYDATA_STRING:
     case LYD_ANYDATA_XML:
     case LYD_ANYDATA_JSON:
-        lydict_remove(LYD_CTX(trg), t->value.str);
+        lydict_remove(LYD_CTX(trg), t->value);
+        t->value = NULL;
         break;
     }
-    t->value.str = NULL;
 
     if (!value) {
         /* only free value in this case */
@@ -1085,16 +1056,15 @@ lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_A
     t->value_type = value_type;
     switch (value_type) {
     case LYD_ANYDATA_DATATREE:
-        if (value->tree) {
-            LY_CHECK_RET(lyd_dup_siblings(value->tree, NULL, LYD_DUP_RECURSIVE, &t->value.tree));
+        LY_CHECK_RET(lyd_dup_siblings(value, NULL, LYD_DUP_RECURSIVE, &t->child));
+        LY_LIST_FOR(t->child, node) {
+            node->parent = &t->node;
         }
         break;
     case LYD_ANYDATA_STRING:
     case LYD_ANYDATA_XML:
     case LYD_ANYDATA_JSON:
-        if (value->str) {
-            LY_CHECK_RET(lydict_insert(LYD_CTX(trg), value->str, 0, &t->value.str));
-        }
+        LY_CHECK_RET(lydict_insert(LYD_CTX(trg), value, 0, &t->value));
         break;
     }
 
@@ -1115,7 +1085,7 @@ lyd_node_schema(const struct lyd_node *node)
     }
 
     /* find the first schema node in the parents */
-    for (iter = lyd_parent(node); iter && !iter->schema; iter = lyd_parent(iter)) {}
+    for (iter = node->parent; iter && !iter->schema; iter = iter->parent) {}
     if (iter) {
         prev_iter = iter;
         schema = prev_iter->schema;
@@ -1124,7 +1094,7 @@ lyd_node_schema(const struct lyd_node *node)
     /* get schema node of an opaque node */
     do {
         /* get next data node */
-        for (iter = node; lyd_parent(iter) != prev_iter; iter = lyd_parent(iter)) {}
+        for (iter = node; iter->parent != prev_iter; iter = iter->parent) {}
 
         /* get module */
         mod = lyd_node_module(iter);
@@ -1135,7 +1105,7 @@ lyd_node_schema(const struct lyd_node *node)
         }
 
         /* get schema node */
-        schema = lys_find_child(schema, mod, LYD_NAME(iter), 0, 0, 0);
+        schema = lys_find_child(LYD_CTX(node), schema, mod, NULL, 0, LYD_NAME(iter), 0, 0);
 
         /* move to the descendant */
         prev_iter = iter;
@@ -1186,8 +1156,7 @@ lyd_hash_table_schema_val_equal(void *val1_p, void *val2_p, ly_bool UNUSED(mod),
 LY_ERR
 lyd_find_sibling_schema(const struct lyd_node *siblings, const struct lysc_node *schema, struct lyd_node **match)
 {
-    struct lyd_node **match_p;
-    struct lyd_node_inner *parent;
+    struct lyd_node **match_p, *parent;
     uint32_t hash;
 
     assert(schema);
@@ -1200,14 +1169,15 @@ lyd_find_sibling_schema(const struct lyd_node *siblings, const struct lysc_node
     }
 
     parent = siblings->parent;
-    if (parent && parent->schema && parent->children_ht) {
+    if (parent && parent->schema && ((struct lyd_node_inner *)parent)->children_ht) {
         /* calculate our hash */
         hash = lyht_hash_multi(0, schema->module->name, strlen(schema->module->name));
         hash = lyht_hash_multi(hash, schema->name, strlen(schema->name));
         hash = lyht_hash_multi(hash, NULL, 0);
 
         /* find by hash but use special hash table function (and stay thread-safe) */
-        if (!lyht_find_with_val_cb(parent->children_ht, &schema, hash, lyd_hash_table_schema_val_equal, (void **)&match_p)) {
+        if (!lyht_find_with_val_cb(((struct lyd_node_inner *)parent)->children_ht, &schema, hash,
+                lyd_hash_table_schema_val_equal, (void **)&match_p)) {
             siblings = *match_p;
         } else {
             /* not found */
@@ -1216,7 +1186,7 @@ lyd_find_sibling_schema(const struct lyd_node *siblings, const struct lysc_node
     } else {
         /* find first sibling */
         if (siblings->parent) {
-            siblings = siblings->parent->child;
+            siblings = ((struct lyd_node_inner *)siblings->parent)->child;
         } else {
             while (siblings->prev->next) {
                 siblings = siblings->prev;
@@ -1299,7 +1269,7 @@ lyd_np_cont_dflt_set(struct lyd_node *parent)
         parent->flags |= LYD_DEFAULT;
 
         /* check all parent containers */
-        parent = lyd_parent(parent);
+        parent = parent->parent;
     }
 }
 
@@ -1308,57 +1278,10 @@ lyd_np_cont_dflt_del(struct lyd_node *parent)
 {
     while (parent && (parent->flags & LYD_DEFAULT)) {
         parent->flags &= ~LYD_DEFAULT;
-        parent = lyd_parent(parent);
+        parent = parent->parent;
     }
 }
 
-LY_ERR
-ly_nested_ext_schema(const struct lyd_node *parent, const struct lysc_node *sparent, const char *prefix,
-        size_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name, size_t name_len,
-        const struct lysc_node **snode, struct lysc_ext_instance **ext)
-{
-    LY_ERR r;
-    LY_ARRAY_COUNT_TYPE u;
-    struct lysc_ext_instance *nested_exts = NULL;
-    lyplg_ext_data_snode_clb ext_snode_cb;
-
-    /* check if there are any nested extension instances */
-    if (parent && parent->schema) {
-        nested_exts = parent->schema->exts;
-    } else if (sparent) {
-        nested_exts = sparent->exts;
-    }
-    LY_ARRAY_FOR(nested_exts, u) {
-        if (!nested_exts[u].def->plugin_ref) {
-            /* no plugin */
-            continue;
-        }
-
-        ext_snode_cb = LYSC_GET_EXT_PLG(nested_exts[u].def->plugin_ref)->snode;
-        if (!ext_snode_cb) {
-            /* not an extension with nested data */
-            continue;
-        }
-
-        /* try to get the schema node */
-        r = ext_snode_cb(&nested_exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len, 0, snode);
-        if (!r) {
-            if (ext) {
-                /* data successfully created, remember the ext instance */
-                *ext = &nested_exts[u];
-            }
-            return LY_SUCCESS;
-        } else if (r != LY_ENOT) {
-            /* fatal error */
-            return r;
-        }
-        /* data was not from this module, continue */
-    }
-
-    /* no extensions or none matched */
-    return LY_ENOT;
-}
-
 void
 ly_free_prefix_data(LY_VALUE_FORMAT format, void *prefix_data)
 {
@@ -1852,7 +1775,7 @@ ly_pattern_match(const struct ly_ctx *ctx, const char *pattern, const char *stri
     if (pat_comp && !*pat_comp) {
         r = ly_pat_compile(pattern, 0, pat_comp, &err);
         if (r) {
-            ly_err_print(ctx, err);
+            ly_err_print(ctx, err, NULL, NULL);
             ly_err_free(err);
             return r;
         }
@@ -1864,7 +1787,7 @@ ly_pattern_match(const struct ly_ctx *ctx, const char *pattern, const char *stri
     }
     r = ly_pat_match((pat_comp && *pat_comp) ? *pat_comp : NULL, pattern, 0, string, str_len, &err);
     if (r && (r != LY_ENOT)) {
-        ly_err_print(ctx, err);
+        ly_err_print(ctx, err, NULL, NULL);
     }
     ly_err_free(err);
 
@@ -1883,7 +1806,7 @@ ly_pattern_compile(const struct ly_ctx *ctx, const char *pattern, void **pat_com
 
     r = ly_pat_compile(pattern, 0, pat_comp, &err);
     if (r) {
-        ly_err_print(ctx, err);
+        ly_err_print(ctx, err, NULL, NULL);
         ly_err_free(err);
         return r;
     }
