@@ -1,9 +1,10 @@
 /**
  * @file tree_data_free.c
  * @author Radek Krejci <rkrejci@cesnet.cz>
+ * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Freeing functions for data tree structures
  *
- * Copyright (c) 2019 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -239,6 +240,8 @@ lyd_free_subtree(struct lyd_node *node)
             lyd_free_subtree(iter);
         }
     } else if (node->schema->nodetype & LYD_NODE_ANY) {
+        assert(!((struct lyd_node_any *)node)->children_ht);
+
         /* only frees the value this way */
         lyd_any_copy_value(node, NULL, 0);
     } else if (node->schema->nodetype & LYD_NODE_TERM) {
@@ -312,7 +315,7 @@ lyd_free_all(struct lyd_node *node)
     }
 
     /* get top-level node */
-    for ( ; node->parent; node = lyd_parent(node)) {}
+    for ( ; node->parent; node = node->parent) {}
 
     lyd_free_(node);
 }
