@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief internal functions for YANG schema trees.
  *
- * Copyright (c) 2015 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -153,27 +153,6 @@ void lyd_np_cont_dflt_set(struct lyd_node *parent);
  */
 void lyd_np_cont_dflt_del(struct lyd_node *parent);
 
-/**
- * @brief Try to get schema node for data with a parent based on an extension instance.
- *
- * @param[in] parent Parsed parent data node. Set if @p sparent is NULL.
- * @param[in] sparent Schema parent node. Set if @p sparent is NULL.
- * @param[in] prefix Element prefix, if any.
- * @param[in] prefix_len Length of @p prefix.
- * @param[in] format Format of @p prefix.
- * @param[in] prefix_data Format-specific data.
- * @param[in] name Element name.
- * @param[in] name_len Length of @p name.
- * @param[out] snode Found schema node, NULL if no suitable was found.
- * @param[out] ext Optional extension instance that provided @p snode.
- * @return LY_SUCCESS on success;
- * @return LY_ENOT if no extension instance parsed the data;
- * @return LY_ERR on error.
- */
-LY_ERR ly_nested_ext_schema(const struct lyd_node *parent, const struct lysc_node *sparent, const char *prefix,
-        size_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name, size_t name_len,
-        const struct lysc_node **snode, struct lysc_ext_instance **ext);
-
 /**
  * @brief Free stored prefix data.
  *
@@ -229,6 +208,7 @@ const char *ly_format2str(LY_VALUE_FORMAT format);
  * Hash is calculated and new node flag is set.
  *
  * @param[in] schema Schema node of the new data node.
+ * @param[in] lnode Parent node for logging.
  * @param[in] value Value to be parsed.
  * @param[in] value_size_bits Size of @p value in bits, must be set correctly.
  * @param[in] is_utf8 Whether @p value is a valid UTF-8 string, if applicable.
@@ -237,15 +217,14 @@ const char *ly_format2str(LY_VALUE_FORMAT format);
  * @param[in] format Input format of @p value.
  * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
  * @param[in] hints [Value hints](@ref lydvalhints) from the parser regarding the value type.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[out] incomplete Whether the value needs to be resolved, optional.
  * @param[out] node Created node.
  * @return LY_SUCCESS on success.
  * @return LY_ERR value if an error occurred.
  */
-LY_ERR lyd_create_term(const struct lysc_node *schema, const void *value, uint32_t value_size_bits, ly_bool is_utf8,
-        ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints,
-        const struct lysc_ext_instance *top_ext, ly_bool *incomplete, struct lyd_node **node);
+LY_ERR lyd_create_term(const struct lysc_node *schema, const struct lyd_node *lnode, const void *value,
+        uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format,
+        void *prefix_data, uint32_t hints, ly_bool *incomplete, struct lyd_node **node);
 
 /**
  * @brief Create an inner (container/list/RPC/action/notification) node.
@@ -270,13 +249,12 @@ LY_ERR lyd_create_inner(const struct lysc_node *schema, struct lyd_node **node);
  * @param[in] predicates Compiled key list predicates.
  * @param[in] vars Array of defined variables to use in predicates, may be NULL.
  * @param[in] store_only Whether to perform storing operation only.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[out] node Created node.
  * @return LY_SUCCESS on success.
  * @return LY_ERR value if an error occurred.
  */
 LY_ERR lyd_create_list(const struct lysc_node *schema, const struct ly_path_predicate *predicates,
-        const struct lyxp_var *vars, ly_bool store_only, const struct lysc_ext_instance *top_ext, struct lyd_node **node);
+        const struct lyxp_var *vars, ly_bool store_only, struct lyd_node **node);
 
 /**
  * @brief Create a list with all its keys (cannot be used for key-less list).
@@ -287,13 +265,12 @@ LY_ERR lyd_create_list(const struct lysc_node *schema, const struct ly_path_pred
  * @param[in] keys Key list predicates.
  * @param[in] keys_len Length of @p keys.
  * @param[in] store_only Whether to perform storing operation only.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[out] node Created node.
  * @return LY_SUCCESS on success.
  * @return LY_ERR value if an error occurred.
  */
 LY_ERR lyd_create_list2(const struct lysc_node *schema, const char *keys, size_t keys_len, ly_bool store_only,
-        const struct lysc_ext_instance *top_ext, struct lyd_node **node);
+        struct lyd_node **node);
 
 /**
  * @brief Create an anyxml/anydata node.
@@ -304,12 +281,13 @@ LY_ERR lyd_create_list2(const struct lysc_node *schema, const char *keys, size_t
  * @param[in] value Value of the any node.
  * @param[in] value_type Value type of the value.
  * @param[in] use_value Whether to use dynamic @p value or duplicate it.
+ * @param[in] try_parse Set if parsing the value into a data tree should be attempted.
  * @param[out] node Created node.
  * @return LY_SUCCESS on success.
  * @return LY_ERR value if an error occurred.
  */
 LY_ERR lyd_create_any(const struct lysc_node *schema, const void *value, LYD_ANYDATA_VALUETYPE value_type,
-        ly_bool use_value, struct lyd_node **node);
+        ly_bool use_value, ly_bool try_parse, struct lyd_node **node);
 
 /**
  * @brief Create an opaque node.
@@ -370,9 +348,6 @@ LY_ERR lyd_change_term_val(struct lyd_node *term, struct lyd_value *val, ly_bool
  * it may no longer be first if @p path is absolute and starts with a non-existing top-level node inserted
  * before @p parent. Use ::lyd_first_sibling() to adjust @p parent in these cases.
  * @param[in] ctx libyang context, must be set if @p parent is NULL.
- * @param[in] ext Extension instance where the node being created is defined. This argument takes effect only for absolute
- * path or when the relative paths touches document root (top-level). In such cases the present extension instance replaces
- * searching for the appropriate module.
  * @param[in] p Compiled path.
  * @param[in] path [Path](@ref howtoXPath) to create.
  * @param[in] value Value of the new leaf/leaf-list (const char *) in ::LY_VALUE_JSON format. If creating an
@@ -385,9 +360,9 @@ LY_ERR lyd_change_term_val(struct lyd_node *term, struct lyd_value *val, ly_bool
  * @param[out] new_node Optional last node created.
  * @return LY_ERR value.
  */
-LY_ERR lyd_new_path_create(struct lyd_node *parent, const struct ly_ctx *ctx, const struct lysc_ext_instance *ext,
-        struct ly_path *p, const char *path, const void *value, uint32_t value_size_bits, LYD_ANYDATA_VALUETYPE value_type,
-        uint32_t options, struct lyd_node **new_parent, struct lyd_node **new_node);
+LY_ERR lyd_new_path_create(struct lyd_node *parent, const struct ly_ctx *ctx, struct ly_path *p, const char *path,
+        const void *value, uint32_t value_size_bits, LYD_ANYDATA_VALUETYPE value_type, uint32_t options,
+        struct lyd_node **new_parent, struct lyd_node **new_node);
 
 /**
  * @brief Check the existence and create any non-existing implicit children.
@@ -396,7 +371,6 @@ LY_ERR lyd_new_path_create(struct lyd_node *parent, const struct ly_ctx *ctx, co
  * @param[in,out] first First sibling.
  * @param[in] sparent Schema parent of the siblings, NULL if schema of @p parent can be used.
  * @param[in] mod Module of the default values, NULL for nested siblings.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[in] node_when Optional set to add nodes with "when" conditions into.
  * @param[in] node_types Optional set to add nodes with unresolved types into.
  * @param[in] ext_val Optional set to add nodes with extension instances into.
@@ -406,9 +380,8 @@ LY_ERR lyd_new_path_create(struct lyd_node *parent, const struct ly_ctx *ctx, co
  * @return LY_ERR value.
  */
 LY_ERR lyd_new_implicit(struct lyd_node *parent, struct lyd_node **first, const struct lysc_node *sparent,
-        const struct lys_module *mod, const struct lysc_ext_instance *top_ext, struct ly_set *node_when,
-        struct ly_set *node_types, struct ly_set *ext_val, uint32_t impl_opts, struct ly_ht *getnext_ht,
-        struct lyd_node **diff);
+        const struct lys_module *mod, struct ly_set *node_when, struct ly_set *node_types, struct ly_set *ext_val,
+        uint32_t impl_opts, struct ly_ht *getnext_ht, struct lyd_node **diff);
 
 /**
  * @brief Check the existence and create any non-existing implicit children, recursively for containers.
@@ -417,7 +390,6 @@ LY_ERR lyd_new_implicit(struct lyd_node *parent, struct lyd_node **first, const
  * @param[in,out] first First sibling.
  * @param[in] sparent Schema parent of the siblings, NULL if schema of @p parent can be used.
  * @param[in] mod Module of the default values, NULL for nested siblings.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
  * @param[in] node_when Optional set to add nodes with "when" conditions into.
  * @param[in] node_types Optional set to add nodes with unresolved types into.
  * @param[in] ext_val Optional set to add nodes with extension instances into.
@@ -427,9 +399,8 @@ LY_ERR lyd_new_implicit(struct lyd_node *parent, struct lyd_node **first, const
  * @return LY_ERR value.
  */
 LY_ERR lyd_new_implicit_r(struct lyd_node *parent, struct lyd_node **first, const struct lysc_node *sparent,
-        const struct lys_module *mod, const struct lysc_ext_instance *top_ext, struct ly_set *node_when,
-        struct ly_set *node_types, struct ly_set *ext_val, uint32_t impl_opts, struct ly_ht *getnext_ht,
-        struct lyd_node **diff);
+        const struct lys_module *mod, struct ly_set *node_when, struct ly_set *node_types, struct ly_set *ext_val,
+        uint32_t impl_opts, struct ly_ht *getnext_ht, struct lyd_node **diff);
 
 /**
  * @brief Find the next node, before which to insert the new node.
@@ -554,7 +525,7 @@ struct lysc_ext_instance *lyd_get_meta_annotation(const struct lys_module *mod,
  * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
  * @param[in] hints [Value hints](@ref lydvalhints) from the parser regarding the value type.
  * @param[in] ctx_node Value context node, may be NULL for metadata.
- * @param[in] top_ext Extension instance containing the definition of the data being created.
+ * @param[in] lnode Data node for logging.
  * @param[in] clear_dflt Whether to clear dflt flag starting from @p parent, recursively all NP containers.
  * @param[out] incomplete Whether the value needs to be resolved.
  * @return LY_SUCCESS on success.
@@ -562,9 +533,9 @@ struct lysc_ext_instance *lyd_get_meta_annotation(const struct lys_module *mod,
  * @return LY_ERR value if an error occurred.
  */
 LY_ERR lyd_create_meta(struct lyd_node *parent, struct lyd_meta **meta, const struct lys_module *mod, const char *name,
-        uint32_t name_len, const void *value, uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic,
-        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        const struct lysc_ext_instance *top_ext, ly_bool clear_dflt, ly_bool *incomplete);
+        uint32_t name_len, const void *value, uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only,
+        ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
+        const struct lyd_node *lnode, ly_bool clear_dflt, ly_bool *incomplete);
 
 /**
  * @brief Create a copy of the metadata.
@@ -615,6 +586,7 @@ LY_ERR lyd_create_attr(struct lyd_node *parent, struct lyd_attr **attr, const st
  * @brief Store and canonize the given @p value into @p val according to the schema node type rules.
  *
  * @param[in] ctx libyang context.
+ * @param[in] lnode Data node for logging.
  * @param[in,out] val Storage for the value.
  * @param[in] type Type of the value.
  * @param[in] value Value to be parsed, must not be NULL.
@@ -625,15 +597,14 @@ LY_ERR lyd_create_attr(struct lyd_node *parent, struct lyd_attr **attr, const st
  * @param[in] format Input format of @p value.
  * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
  * @param[in] hints [Value hints](@ref lydvalhints) from the parser.
- * @param[in] ctx_node Context schema node.
- * @param[in] top_ext Extension instance containing the definition of the data being stored.
+ * @param[in] ctx_snode Context schema node.
  * @param[out] incomplete Optional, set if the value also needs to be resolved.
  * @return LY_SUCCESS on success,
  * @return LY_ERR value on error.
  */
-LY_ERR lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct lysc_type *type, const void *value,
-        uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format,
-        void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext,
+LY_ERR lyd_value_store(const struct ly_ctx *ctx, const struct lyd_node *lnode, struct lyd_value *val,
+        const struct lysc_type *type, const void *value, uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only,
+        ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_snode,
         ly_bool *incomplete);
 
 /**
@@ -644,12 +615,11 @@ LY_ERR lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const st
  * @param[in,out] val Stored value to resolve.
  * @param[in] ctx_node Context node for the resolution.
  * @param[in] tree Data tree for the resolution.
- * @param[in] top_ext Extension instance containing the definition of the data being validated.
  * @return LY_SUCCESS on success,
  * @return LY_ERR value on error.
  */
 LY_ERR lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *type, struct lyd_value *val,
-        const struct lyd_node *ctx_node, const struct lyd_node *tree, const struct lysc_ext_instance *top_ext);
+        const struct lyd_node *ctx_node, const struct lyd_node *tree);
 
 /**
  * @brief Check type restrictions applicable to the particular leaf/leaf-list with the given string @p value.
@@ -664,13 +634,11 @@ LY_ERR lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc
  * @param[in] format Value prefix format.
  * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
  * @param[in] hints Value encoding hints.
- * @param[in] top_ext Extension instance containing the definition of the data being validated.
  * @return LY_SUCCESS on success
  * @return LY_ERR value if an error occurred.
  */
 LY_ERR ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const void *value,
-        uint32_t value_size_bits, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints,
-        const struct lysc_ext_instance *top_ext);
+        uint32_t value_size_bits, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints);
 
 /**
  * @brief Check type restrictions applicable to the particular leaf/leaf-list with the given string @p value.
@@ -685,7 +653,6 @@ LY_ERR ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node,
  * @param[in] hints Value hints, bitmap of LYD_VALHINT_* values.
  * @param[in] ctx_node Optional data tree context node for the value (leafref target, instance-identifier).
  * If not set and is required for the validation to complete, ::LY_EINCOMPLETE is be returned.
- * @param[in] top_ext Extension instance containing the definition of the data being validated.
  * @param[in] log Whether to log errors or not.
  * @param[out] realtype Optional real type of @p value.
  * @param[out] canonical Optional canonical value of @p value (in the dictionary).
@@ -694,9 +661,9 @@ LY_ERR ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node,
  * (e.g. due to require-instance).
  * @return LY_ERR value if an error occurred.
  */
-LY_ERR lyd_value_validate3(const struct lysc_node *schema, const char *value, size_t value_len,
-        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lyd_node *ctx_node,
-        const struct lysc_ext_instance *top_ext, int log, const struct lysc_type **realtype, const char **canonical);
+LY_ERR lyd_value_validate3(const struct lysc_node *schema, const char *value, size_t value_len, LY_VALUE_FORMAT format,
+        void *prefix_data, uint32_t hints, const struct lyd_node *ctx_node, int log, const struct lysc_type **realtype,
+        const char **canonical);
 
 /**
  * @defgroup datahash Data nodes hash manipulation
