@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Schema tree implementation
  *
- * Copyright (c) 2015 - 2025 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -48,6 +48,7 @@
 #include "tree_edit.h"
 #include "tree_schema_free.h"
 #include "tree_schema_internal.h"
+#include "xml.h"
 #include "xpath.h"
 
 const char * const ly_devmod_list[] = {
@@ -119,6 +120,141 @@ lysc_module_dfs_full(const struct lys_module *mod, lysc_dfs_clb dfs_clb, void *d
     return LY_SUCCESS;
 }
 
+/**
+ * @brief Find import prefix in imports.
+ */
+static const struct lys_module *
+ly_schema_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len, const void *prefix_data)
+{
+    const struct lysp_module *prefix_mod = prefix_data;
+    LY_ARRAY_COUNT_TYPE u;
+    const char *local_prefix;
+
+    local_prefix = prefix_mod->is_submod ? ((struct lysp_submodule *)prefix_mod)->prefix : prefix_mod->mod->prefix;
+    if (!prefix_len || !ly_strncmp(local_prefix, prefix, prefix_len)) {
+        /* it is the prefix of the module itself */
+        return prefix_mod->mod;
+    }
+
+    /* search in imports */
+    LY_ARRAY_FOR(prefix_mod->imports, u) {
+        if (!ly_strncmp(prefix_mod->imports[u].prefix, prefix, prefix_len)) {
+            return prefix_mod->imports[u].module;
+        }
+    }
+
+    return NULL;
+}
+
+/**
+ * @brief Find resolved module for a prefix in prefix - module pairs.
+ */
+static const struct lys_module *
+ly_schema_resolved_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len,
+        const void *prefix_data)
+{
+    const struct lysc_prefix *prefixes = prefix_data;
+    LY_ARRAY_COUNT_TYPE u;
+
+    LY_ARRAY_FOR(prefixes, u) {
+        if ((!prefixes[u].prefix && !prefix_len) || (prefixes[u].prefix && !ly_strncmp(prefixes[u].prefix, prefix, prefix_len))) {
+            return prefixes[u].mod;
+        }
+    }
+
+    return NULL;
+}
+
+/**
+ * @brief Find XML namespace prefix in XML namespaces, which are then mapped to modules.
+ */
+static const struct lys_module *
+ly_xml_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *prefix_data)
+{
+    const struct lys_module *mod;
+    const struct lyxml_ns *ns;
+    const struct ly_set *ns_set = prefix_data;
+
+    ns = lyxml_ns_get(ns_set, prefix, prefix_len);
+    if (!ns) {
+        return NULL;
+    }
+
+    mod = ly_ctx_get_module_implemented_ns(ctx, ns->uri);
+    if (!mod) {
+        /* for YIN extension prefix resolution */
+        mod = ly_ctx_get_module_latest_ns(ctx, ns->uri);
+    }
+    return mod;
+}
+
+/**
+ * @brief Find module name.
+ */
+static const struct lys_module *
+ly_json_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *UNUSED(prefix_data))
+{
+    return ly_ctx_get_module_implemented2(ctx, prefix, prefix_len);
+}
+
+const struct lys_module *
+ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        const void *prefix_data)
+{
+    const struct lys_module *mod = NULL;
+
+    LY_CHECK_ARG_RET(ctx, prefix, prefix_len, NULL);
+
+    switch (format) {
+    case LY_VALUE_SCHEMA:
+        mod = ly_schema_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        break;
+    case LY_VALUE_SCHEMA_RESOLVED:
+        mod = ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        break;
+    case LY_VALUE_XML:
+    case LY_VALUE_STR_NS:
+        mod = ly_xml_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        break;
+    case LY_VALUE_CANON:
+    case LY_VALUE_JSON:
+    case LY_VALUE_LYB:
+        mod = ly_json_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        break;
+    }
+
+    return mod;
+}
+
+LIBYANG_API_DEF const struct lys_module *
+lys_find_module(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const char *prefix, uint32_t prefix_len,
+        LY_VALUE_FORMAT format, const void *prefix_data)
+{
+    if (prefix_len) {
+        return ly_resolve_prefix(ctx, prefix, prefix_len, format, prefix_data);
+    } else {
+        switch (format) {
+        case LY_VALUE_SCHEMA:
+            /* use local module */
+            return ly_schema_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        case LY_VALUE_SCHEMA_RESOLVED:
+            /* use local module */
+            return ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+        case LY_VALUE_CANON:
+        case LY_VALUE_JSON:
+        case LY_VALUE_LYB:
+        case LY_VALUE_STR_NS:
+            /* use context node module (as specified) */
+            return ctx_node ? ctx_node->module : NULL;
+        case LY_VALUE_XML:
+            /* use the default namespace */
+            return ly_xml_resolve_prefix(ctx, NULL, 0, prefix_data);
+        }
+    }
+
+    return NULL;
+}
+
 static void
 lys_getnext_into_case(const struct lysc_node_case *first_case, const struct lysc_node **last, const struct lysc_node **next)
 {
@@ -135,45 +271,13 @@ lys_getnext_into_case(const struct lysc_node_case *first_case, const struct lysc
     (*next) = (*next)->next;
 }
 
-/**
- * @brief Generic getnext function for ::lys_getnext() and ::lys_getnext_ext().
- *
- * Gets next schema tree (sibling) node element that can be instantiated in a data tree. Returned node can
- * be from an augment. If the @p ext is provided, the function is locked inside the schema tree defined in the
- * extension instance.
- *
- * ::lys_getnext_() is supposed to be called sequentially. In the first call, the @p last parameter is usually NULL
- * and function starts returning i) the first @p parent's child or ii) the first top level element specified in the
- * given extension (if provided) or iii) the first top level element of the @p module.
- * Consequent calls suppose to provide the previously returned node as the @p last parameter and still the same
- * @p parent and @p module parameters.
- *
- * Without options, the function is used to traverse only the schema nodes that can be paired with corresponding
- * data nodes in a data tree. By setting some @p options the behavior can be modified to the extent that
- * all the schema nodes are iteratively returned.
- *
- * @param[in] last Previously returned schema tree node, or NULL in case of the first call.
- * @param[in] parent Parent of the subtree where the function starts processing.
- * @param[in] module In case of iterating on top level elements, the @p parent is NULL and
- * module must be specified.
- * @param[in] ext The extension instance to provide a separate schema tree. To consider the top level elements in the tree,
- * the @p parent must be NULL. Aat least one of @p parent, @p module and @p ext parameters must be specified.
- * @param[in] options [ORed options](@ref sgetnextflags).
- * @return Next schema tree node that can be instantiated in a data tree, NULL in case there is no such element.
- */
-static const struct lysc_node *
-lys_getnext_(const struct lysc_node *last, const struct lysc_node *parent, const struct lysc_module *module,
-        const struct lysc_ext_instance *ext, uint32_t options)
+LIBYANG_API_DEF const struct lysc_node *
+lys_getnext(const struct lysc_node *last, const struct lysc_node *parent, const struct lysc_module *module, uint32_t options)
 {
     const struct lysc_node *next = NULL;
-    ly_bool action_flag = 0, notif_flag = 0, sm_flag = options & LYS_GETNEXT_WITHSCHEMAMOUNT ? 0 : 1;
-    LY_ARRAY_COUNT_TYPE u;
-    const struct ly_ctx *sm_ctx = NULL;
-    const struct lys_module *mod;
-    struct lyplg_ext *ext_plg;
-    uint32_t idx;
+    ly_bool action_flag = 0, notif_flag = 0;
 
-    LY_CHECK_ARG_RET(NULL, parent || module || ext, NULL);
+    LY_CHECK_ARG_RET(NULL, last || parent || module, NULL);
 
 next:
     if (!last) {
@@ -185,18 +289,7 @@ next:
             next = last = lysc_node_child(parent);
         } else {
             /* top level data */
-            if (ext) {
-                if (ext->def->plugin_ref && (ext_plg = LYSC_GET_EXT_PLG(ext->def->plugin_ref))->snode) {
-                    /* use the extension callback */
-                    ext_plg->snode((struct lysc_ext_instance *)ext, NULL, NULL, NULL, 0, 0, NULL, NULL, 0,
-                            options & LYS_GETNEXT_EXT_XPATH, &last);
-                } else {
-                    last = NULL;
-                }
-                next = last;
-            } else {
-                next = last = module->data;
-            }
+            next = last = module->data;
         }
         if (!next) {
             /* try to get action or notification */
@@ -217,73 +310,23 @@ next:
 
 repeat:
     if (!next) {
-        if (last && !sm_flag && parent && (last->module->ctx != parent->module->ctx)) {
-            sm_flag = 1;
-
-            /* find the module of last */
-            sm_ctx = last->module->ctx;
-            idx = 0;
-            while ((mod = ly_ctx_get_module_iter(sm_ctx, &idx))) {
-                if (mod == last->module) {
-                    break;
-                }
-            }
-            assert(mod);
-
-            /* get node from the next mounted module */
-            while (!next && (mod = ly_ctx_get_module_iter(sm_ctx, &idx))) {
-                if (!mod->implemented) {
-                    continue;
-                }
-
-                next = lys_getnext(NULL, NULL, mod->compiled, options & ~LYS_GETNEXT_WITHSCHEMAMOUNT);
-            }
-        } else if (last && (last->parent != parent)) {
+        if (last && (last->parent != parent)) {
             /* go back to parent */
             last = last->parent;
             goto next;
         } else if (!action_flag) {
             action_flag = 1;
-            if (ext) {
-                lyplg_ext_get_storage(ext, LY_STMT_OP_MASK, sizeof next, (const void **)&next);
-            } else if (parent) {
+            if (parent) {
                 next = (struct lysc_node *)lysc_node_actions(parent);
-            } else {
+            } else if (module) {
                 next = (struct lysc_node *)module->rpcs;
             }
         } else if (!notif_flag) {
             notif_flag = 1;
-            if (ext) {
-                lyplg_ext_get_storage(ext, LY_STMT_NOTIFICATION, sizeof next, (const void **)&next);
-            } else if (parent) {
-                next = (struct lysc_node *)lysc_node_notifs(parent);
-            } else {
-                next = (struct lysc_node *)module->notifs;
-            }
-        } else if (!sm_flag) {
-            sm_flag = 1;
             if (parent) {
-                LY_ARRAY_FOR(parent->exts, u) {
-                    if (!strcmp(parent->exts[u].def->name, "mount-point") &&
-                            !strcmp(parent->exts[u].def->module->name, "ietf-yang-schema-mount")) {
-                        lyplg_ext_schema_mount_get_ctx(&parent->exts[u], NULL, &sm_ctx);
-                        if (sm_ctx) {
-                            /* some usable context created */
-                            break;
-                        }
-                    }
-                }
-                if (sm_ctx) {
-                    /* get the first node from the first usable module */
-                    idx = 0;
-                    while (!next && (mod = ly_ctx_get_module_iter(sm_ctx, &idx))) {
-                        if (!mod->implemented) {
-                            continue;
-                        }
-
-                        next = lys_getnext(NULL, NULL, mod->compiled, options & ~LYS_GETNEXT_WITHSCHEMAMOUNT);
-                    }
-                }
+                next = (struct lysc_node *)lysc_node_notifs(parent);
+            } else if (module) {
+                next = (struct lysc_node *)module->notifs;
             }
         } else {
             return NULL;
@@ -355,90 +398,219 @@ check:
         goto repeat;
     default:
         /* we should not be here */
-        LOGINT(module ? module->mod->ctx : parent ? parent->module->ctx : ext->module->ctx);
+        LOGINT(NULL);
         return NULL;
     }
 
     return next;
 }
 
-LIBYANG_API_DEF const struct lysc_node *
-lys_getnext(const struct lysc_node *last, const struct lysc_node *parent, const struct lysc_module *module, uint32_t options)
+/**
+ * @brief Get schema node in extension instance according to the given parameters.
+ *
+ * @param[in] ext Extension instance which top-level schema node is being searched.
+ * @param[in] parent Parsed parent data node.
+ * @param[in] sparent Schema parent node.
+ * @param[in] module Optional parameter to match the extension instance's (and its data) module.
+ * @param[in] name Name of the schema node to find, if the string is not NULL-terminated, the @p name_len must be set.
+ * @param[in] name_len Length of the @p name string, use in case the @p name is not NULL-terminated string.
+ * @param[in] nodetype Allowed [type of the node](@ref schemanodetypes).
+ * @param[in] is_xpath Set if searching for nodes in an XPath expression.
+ * @param[out] snode Found schema node, NULL if no suitable was found.
+ * @return Found schema node if there is some satisfy the provided requirements.
+ */
+static LY_ERR
+lys_ext_find_node(const struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct lysc_node *sparent,
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, ly_bool is_xpath, const struct lysc_node **snode)
 {
-    return lys_getnext_(last, parent, module, NULL, options);
+    LY_ERR rc = LY_SUCCESS;
+    struct lyplg_ext *plg_ext;
+    const struct lys_module *mod;
+    const struct lysc_node *node;
+
+    plg_ext = LYSC_GET_EXT_PLG(ext->def->plugin_ref);
+    if (!plg_ext) {
+        return LY_ENOT;
+    }
+
+    /* standard nodes */
+    if (is_xpath && plg_ext->snode_xpath) {
+        rc = plg_ext->snode_xpath((struct lysc_ext_instance *)ext, prefix, prefix_len, format, prefix_data, name,
+                name_len, snode);
+    } else if (!is_xpath && plg_ext->snode) {
+        rc = plg_ext->snode((struct lysc_ext_instance *)ext, parent, sparent, prefix, prefix_len, format,
+                prefix_data, name, name_len, snode);
+    } else {
+        lyplg_ext_get_storage(ext, LY_STMT_DATA_NODE_MASK, sizeof node, (const void **)&node);
+        if (node) {
+            /* find the module */
+            mod = lys_find_module((*snode)->module->ctx, parent ? parent->schema : sparent, prefix, prefix_len, format,
+                    prefix_data);
+        }
+        if (node && mod && mod->implemented) {
+            while ((node = lys_getnext(node, node->parent, NULL, 0))) {
+                if (node->module != mod) {
+                    continue;
+                }
+                if (ly_strncmp(node->name, name, name_len)) {
+                    continue;
+                }
+
+                break;
+            }
+            if (node) {
+                /* matching node */
+                *snode = node;
+            }
+        }
+        if (!*snode) {
+            rc = LY_ENOT;
+        }
+    }
+
+    return rc;
 }
 
-LIBYANG_API_DEF const struct lysc_node *
-lys_getnext_ext(const struct lysc_node *last, const struct lysc_node *parent, const struct lysc_ext_instance *ext, uint32_t options)
+LY_ERR
+lys_find_child_node_ext(const struct ly_ctx *ctx, const struct lys_module *mod, const struct lyd_node *parent,
+        const struct lysc_node *sparent, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        void *prefix_data, const char *name, uint32_t name_len, ly_bool is_xpath, const struct lysc_node **snode,
+        struct lysc_ext_instance **ext)
 {
-    return lys_getnext_(last, parent, NULL, ext, options);
+    LY_ERR r;
+    LY_ARRAY_COUNT_TYPE u;
+    struct lysc_ext_instance *exts;
+
+    *snode = NULL;
+    if (ext) {
+        *ext = NULL;
+    }
+
+    /* check if there are any nested parent extension instances */
+    if (parent && parent->schema) {
+        exts = parent->schema->exts;
+    } else if (sparent) {
+        exts = sparent->exts;
+    } else {
+        exts = NULL;
+    }
+    LY_ARRAY_FOR(exts, u) {
+        r = lys_ext_find_node(&exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len,
+                is_xpath, snode);
+        if (!r) {
+            if (ext) {
+                /* schema node found, remember the ext instance */
+                *ext = &exts[u];
+            }
+            return LY_SUCCESS;
+        } else if (r != LY_ENOT) {
+            return r;
+        }
+
+        /* data was not from this ext instance, continue */
+    }
+
+    /* check if there are global module ext instances */
+    if (!mod) {
+        mod = lys_find_module(ctx, parent ? parent->schema : sparent, prefix, prefix_len, format, prefix_data);
+    }
+    if (mod && mod->implemented) {
+        exts = mod->compiled->exts;
+    } else {
+        exts = NULL;
+    }
+    LY_ARRAY_FOR(exts, u) {
+        r = lys_ext_find_node(&exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len,
+                is_xpath, snode);
+        if (!r) {
+            if (ext) {
+                *ext = &exts[u];
+            }
+            return LY_SUCCESS;
+        } else if (r != LY_ENOT) {
+            return r;
+        }
+    }
+
+    /* no extensions or none matched */
+    return LY_ENOT;
 }
 
-const struct lysc_node *
-lysc_ext_find_node(const struct lysc_ext_instance *ext, const struct lys_module *module, const char *name, size_t name_len,
-        uint16_t nodetype, uint32_t options)
+LY_ERR
+lys_find_child_node(const struct ly_ctx *ctx, const struct lysc_node *parent, const struct lys_module *mod,
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, uint32_t options, const struct lysc_node **snode, struct lysc_ext_instance **ext)
 {
     const struct lysc_node *node = NULL;
 
-    LY_CHECK_ARG_RET(NULL, ext, name, NULL);
-    if (!nodetype) {
-        nodetype = LYS_NODETYPE_MASK;
+    assert(name);
+
+    *snode = NULL;
+    if (ext) {
+        *ext = NULL;
     }
 
-    if (module && (module != ext->module)) {
-        return NULL;
+    if (prefix && !prefix_len) {
+        prefix_len = strlen(prefix);
+    }
+    if (!name_len) {
+        name_len = strlen(name);
     }
 
-    while ((node = lys_getnext_ext(node, NULL, ext, options))) {
-        if (!(node->nodetype & nodetype)) {
-            continue;
-        }
+    /* find the module */
+    if (!mod) {
+        mod = lys_find_module(ctx, parent, prefix, prefix_len, format, prefix_data);
+    }
 
-        if (name_len) {
+    /* look for a standard schema node */
+    if (mod && mod->implemented) {
+        while ((node = lys_getnext(node, parent, mod->compiled, options))) {
+            /* check module */
+            if (node->module != mod) {
+                continue;
+            }
+
+            /* check name */
             if (!ly_strncmp(node->name, name, name_len)) {
-                return node;
-            }
-        } else {
-            if (!strcmp(node->name, name)) {
-                return node;
+                *snode = node;
+                return LY_SUCCESS;
             }
         }
     }
-    return NULL;
+
+    /* look for an ext instance node */
+    return lys_find_child_node_ext(ctx, mod, NULL, parent, prefix, prefix_len, format, prefix_data, name, name_len,
+            0, snode, ext);
 }
 
 LIBYANG_API_DEF const struct lysc_node *
-lys_find_child(const struct lysc_node *parent, const struct lys_module *module, const char *name, size_t name_len,
-        uint16_t nodetype, uint32_t options)
+lys_find_child(const struct ly_ctx *ctx, const struct lysc_node *parent, const struct lys_module *mod,
+        const char *mod_name, uint32_t mod_len, const char *name, uint32_t name_len, uint32_t options)
 {
-    const struct lysc_node *node = NULL;
+    const struct lysc_node *snode = NULL;
 
-    LY_CHECK_ARG_RET(NULL, module, name, NULL);
-    LY_CHECK_CTX_EQUAL_RET(__func__, parent ? parent->module->ctx : NULL, module->ctx, NULL);
-    if (!nodetype) {
-        nodetype = LYS_NODETYPE_MASK;
+    LY_CHECK_ARG_RET(NULL, ctx || parent || mod, (mod || mod_name) && (!mod || !mod_name), name, NULL);
+
+    if (parent) {
+        ctx = parent->module->ctx;
+    } else if (mod) {
+        ctx = mod->ctx;
     }
 
-    while ((node = lys_getnext(node, parent, module->compiled, options))) {
-        if (!(node->nodetype & nodetype)) {
-            continue;
-        }
-        if (node->module != module) {
-            continue;
-        }
-
-        if (name_len) {
-            if (!ly_strncmp(node->name, name, name_len)) {
-                return node;
-            }
-        } else {
-            if (!strcmp(node->name, name)) {
-                return node;
-            }
-        }
+    if (mod) {
+        mod_name = mod->name;
     }
 
-    return NULL;
+    if (mod_name && !mod_len) {
+        mod_len = strlen(mod_name);
+    }
+    if (!name_len) {
+        name_len = strlen(name);
+    }
+
+    lys_find_child_node(ctx, parent, mod, mod_name, mod_len, LY_VALUE_JSON, NULL, name, name_len, options, &snode, NULL);
+    return snode;
 }
 
 LIBYANG_API_DEF LY_ERR
@@ -464,11 +636,11 @@ lys_find_xpath_atoms(const struct ly_ctx *ctx, const struct lysc_node *ctx_node,
     LY_CHECK_GOTO(ret, cleanup);
 
     /* compile expression */
-    ret = lyxp_expr_parse(ctx, xpath, 0, 1, &exp);
+    ret = lyxp_expr_parse(ctx, NULL, xpath, 0, 1, &exp);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* atomize expression */
-    ret = lyxp_atomize(ctx, exp, NULL, LY_VALUE_JSON, NULL, ctx_node, ctx_node, NULL, &xp_set, options);
+    ret = lyxp_atomize(ctx, exp, NULL, LY_VALUE_JSON, NULL, ctx_node, ctx_node, &xp_set, options);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* transform into ly_set */
@@ -509,7 +681,7 @@ lys_find_expr_atoms(const struct lysc_node *ctx_node, const struct lys_module *c
 
     /* atomize expression */
     ret = lyxp_atomize(cur_mod->ctx, expr, cur_mod, LY_VALUE_SCHEMA_RESOLVED, (void *)prefixes, ctx_node, ctx_node,
-            NULL, &xp_set, options);
+            &xp_set, options);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* transform into ly_set */
@@ -559,11 +731,11 @@ lys_find_xpath(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const
     LY_CHECK_GOTO(ret, cleanup);
 
     /* compile expression */
-    ret = lyxp_expr_parse(ctx, xpath, 0, 1, &exp);
+    ret = lyxp_expr_parse(ctx, NULL, xpath, 0, 1, &exp);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* atomize expression */
-    ret = lyxp_atomize(ctx, exp, NULL, LY_VALUE_JSON, NULL, ctx_node, ctx_node, NULL, &xp_set, options);
+    ret = lyxp_atomize(ctx, exp, NULL, LY_VALUE_JSON, NULL, ctx_node, ctx_node, &xp_set, options);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* transform into ly_set */
@@ -641,7 +813,7 @@ lys_find_path_atoms(const struct ly_ctx *ctx, const struct lysc_node *ctx_node,
 
     /* compile */
     oper = output ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, expr, oper, LY_PATH_TARGET_MANY, 0, LY_VALUE_JSON, NULL, &p);
+    ret = ly_path_compile(ctx, ctx_node, expr, oper, LY_PATH_TARGET_MANY, 0, LY_VALUE_JSON, NULL, &p);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* resolve */
@@ -676,7 +848,7 @@ lys_find_path(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const
 
     /* compile */
     oper = output ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, expr, oper, LY_PATH_TARGET_MANY, 0, LY_VALUE_JSON, NULL, &p);
+    ret = ly_path_compile(ctx, ctx_node, expr, oper, LY_PATH_TARGET_MANY, 0, LY_VALUE_JSON, NULL, &p);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* get last node */
@@ -1394,12 +1566,12 @@ lysp_resolve_ext_instance_records(struct lysp_ctx *pctx)
             if ((r = lysp_resolve_ext_instance_log_path(pctx, ext, &path))) {
                 return r;
             }
-            ly_log_location(NULL, NULL, path, NULL);
+            ly_log_location(NULL, path, NULL);
 
             /* parse */
             r = ext_plg->parse(pctx, ext);
 
-            ly_log_location_revert(0, 0, 1, 0);
+            ly_log_location_revert(0, 1, 0);
             free(path);
 
             if (r == LY_ENOT) {
@@ -1518,13 +1690,13 @@ lysp_load_module_data_check(const struct ly_ctx *ctx, struct lysp_module *mod, s
 
         /* check that the submodule belongs-to our module */
         if (strcmp(mod_data->submoduleof, submod->mod->name)) {
-            LOGVAL(ctx, LYVE_REFERENCE, "Included \"%s\" submodule from \"%s\" belongs-to a different module \"%s\".",
+            LOGVAL(ctx, NULL, LYVE_REFERENCE, "Included \"%s\" submodule from \"%s\" belongs-to a different module \"%s\".",
                     submod->name, mod_data->submoduleof, submod->mod->name);
             return LY_EVALID;
         }
         /* check circular dependency */
         if (submod->parsing) {
-            LOGVAL(ctx, LYVE_REFERENCE, "A circular dependency (include) for module \"%s\".", submod->name);
+            LOGVAL(ctx, NULL, LYVE_REFERENCE, "A circular dependency (include) for module \"%s\".", submod->name);
             return LY_EVALID;
         }
     }
