@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief YANG XPath evaluation functions header
  *
- * Copyright (c) 2015 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -315,7 +315,6 @@ struct lyxp_set {
     void *prefix_data;                      /**< Format-specific prefix data (see ::ly_resolve_prefix). */
     const struct lyxp_var *vars;            /**< XPath variables. [Sized array](@ref sizedarrays).
                                                  Set of variable bindings. */
-    const struct lysc_ext_instance *ext;    /**< Extension instance with a callback for getting document root children, if any. */
 };
 
 /**
@@ -344,7 +343,6 @@ const char *lyxp_token2str(enum lyxp_token tok);
  * @param[in] tree Data tree on which to perform the evaluation, it must include all the available data (including
  * the tree of @p ctx_node). Can be any node of the tree, it is adjusted.
  * @param[in] vars [Sized array](@ref sizedarrays) of XPath variables.
- * @param[in] top_ext Extension instance whose XPath context we are evaluating in.
  * @param[out] set Result set.
  * @param[in] options Whether to apply some evaluation restrictions.
  * @return LY_EVALID for invalid argument types/count,
@@ -353,8 +351,7 @@ const char *lyxp_token2str(enum lyxp_token tok);
  */
 LY_ERR lyxp_eval(const struct ly_ctx *ctx, const struct lyxp_expr *exp, const struct lys_module *cur_mod,
         LY_VALUE_FORMAT format, void *prefix_data, const struct lyd_node *cur_node, const struct lyd_node *ctx_node,
-        const struct lyd_node *tree, const struct lyxp_var *vars, const struct lysc_ext_instance *top_ext,
-        struct lyxp_set *set, uint32_t options);
+        const struct lyd_node *tree, const struct lyxp_var *vars, struct lyxp_set *set, uint32_t options);
 
 /**
  * @brief Get all the partial XPath nodes (atoms) that are required for @p exp to be evaluated.
@@ -368,14 +365,13 @@ LY_ERR lyxp_eval(const struct ly_ctx *ctx, const struct lyxp_expr *exp, const st
  * subexpression is being atomized.
  * @param[in] ctx_scnode Starting context schema node, NULL in case of the root node. Equal to @p cur_scnode unless a
  * subexpression is being atomized.
- * @param[in] top_ext Extension instance whose XPath context we are evaluating in.
  * @param[out] set Result set.
  * @param[in] options Whether to apply some evaluation restrictions, one flag must always be used.
  * @return LY_ERR (same as ::lyxp_eval()).
  */
 LY_ERR lyxp_atomize(const struct ly_ctx *ctx, const struct lyxp_expr *exp, const struct lys_module *cur_mod,
         LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *cur_scnode,
-        const struct lysc_node *ctx_scnode, const struct lysc_ext_instance *top_ext, struct lyxp_set *set, uint32_t options);
+        const struct lysc_node *ctx_scnode, struct lyxp_set *set, uint32_t options);
 
 /** used only internally, maps with @ref findxpathoptions */
 #define LYXP_IGNORE_WHEN     0x01   /**< Ignore unevaluated when in data nodes and do not return ::LY_EINCOMPLETE. */
@@ -389,14 +385,13 @@ LY_ERR lyxp_atomize(const struct ly_ctx *ctx, const struct lyxp_expr *exp, const
                                                              warning is printed. */
 #define LYXP_ACCESS_TREE_ALL 0x80   /**< Explicit accessible tree of all the nodes. */
 #define LYXP_ACCESS_TREE_CONFIG 0x0100  /**< Explicit accessible tree of only configuration data. */
-#define LYXP_SCNODE_SCHEMAMOUNT LYS_FIND_SCHEMAMOUNT    /**< Nodes from mounted modules are also accessible. */
 
 /**
  * @brief Cast XPath set to another type.
  *        Indirectly context position aware.
  *
  * @param[in] set Set to cast.
- * @param[in] target Target type to cast \p set into.
+ * @param[in] target Target type to cast @p set into.
  * @return LY_ERR
  */
 LY_ERR lyxp_set_cast(struct lyxp_set *set, enum lyxp_set_type target);
@@ -450,6 +445,7 @@ LY_ERR lyxp_set_scnode_insert_node(struct lyxp_set *set, const struct lysc_node
  * https://www.w3.org/TR/1999/REC-xpath-19991116/#exprlex
  *
  * @param[in] ctx Context for errors.
+ * @param[in] lnode Data node for logging.
  * @param[in] expr_str XPath expression to parse. It is duplicated.
  * @param[in] expr_len Length of @p expr, can be 0 if @p expr is 0-terminated.
  * @param[in] reparse Whether to re-parse the expression to finalize full XPath parsing and fill
@@ -459,8 +455,8 @@ LY_ERR lyxp_set_scnode_insert_node(struct lyxp_set *set, const struct lysc_node
  * @return LY_EMEM in case of memory allocation failure.
  * @return LY_EVALID in case of invalid XPath expression in @p expr_str.
  */
-LY_ERR lyxp_expr_parse(const struct ly_ctx *ctx, const char *expr_str, size_t expr_len, ly_bool reparse,
-        struct lyxp_expr **expr_p);
+LY_ERR lyxp_expr_parse(const struct ly_ctx *ctx, const struct lyd_node *lnode, const char *expr_str, size_t expr_len,
+        ly_bool reparse, struct lyxp_expr **expr_p);
 
 /**
  * @brief Duplicate parsed XPath expression.
@@ -477,6 +473,15 @@ LY_ERR lyxp_expr_parse(const struct ly_ctx *ctx, const char *expr_str, size_t ex
 LY_ERR lyxp_expr_dup(const struct ly_ctx *ctx, const struct lyxp_expr *exp, uint32_t start_idx, uint32_t end_idx,
         struct lyxp_expr **dup);
 
+/**
+ * @brief Get the first XPath document root child, use ext instance callbacks if needed.
+ *
+ * @param[in] cur_node Current (original context) node.
+ * @param[in] tree Full data tree
+ * @return First document root child.
+ */
+const struct lyd_node *lyxp_node_first_doc_root_child(const struct lyd_node *cur_node, const struct lyd_node *tree);
+
 /**
  * @brief Look at the next token and check its kind.
  *
