@@ -220,7 +220,7 @@ test_leaf(void **state)
     /* reverse solidus in JSON object member name */
     data = "{\"@a:foo\":{\"a:hi\\nt\":1},\"a:foo\":\"xxx\"}";
     assert_int_equal(LY_EINVAL, lyd_parse_data_mem(UTEST_LYCTX, data, LYD_JSON, 0, LYD_VALIDATE_PRESENT, &tree));
-    CHECK_LOG_CTX("Annotation definition for attribute \"a:hi\nt\" not found.", "/@a:foo/@a:hi\nt", 1);
+    CHECK_LOG_CTX("Annotation definition for attribute \"a:hi\nt\" not found.", "/a:foo/@a:hi\nt", 1);
 
     data = "{\"a:foo\": null}";
     PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID, "Invalid non-string-encoded string value \"\".", "/a:foo", 1);
@@ -689,7 +689,7 @@ test_opaq(void **state)
 
     /* invalid metadata */
     data = "{\"@a:foo\":\"str\",\"@a:foo3\":1,\"a:foo3\":2}";
-    PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID, "Unknown module of node \"@a:foo\".", "/", 0);
+    PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID, "Unknown module of node \"@a:foo\".", NULL, 0);
     CHECK_LOG_CTX("Missing JSON data instance to be coupled with @a:foo metadata.", "/@a:foo", 1);
 
     /* empty name */
@@ -799,7 +799,7 @@ test_rpc(void **state)
     CHECK_LYSC_NODE(node->schema, "Inline config content.", 0, LYS_STATUS_CURR | LYS_IS_INPUT, 1, "config",
             0, LYS_ANYDATA, 1, 0, NULL, 0);
 
-    node = ((struct lyd_node_any *)node)->value.tree;
+    node = ((struct lyd_node_any *)node)->child;
     CHECK_LYSC_NODE(node->schema, NULL, 0, LYS_CONFIG_W | LYS_STATUS_CURR | LYS_PRESENCE, 1, "cp",
             1, LYS_CONTAINER, 0, 0, NULL, 0);
     node = lyd_child(node);
@@ -973,7 +973,7 @@ test_restconf_notification(void **state)
 
     /* notification with the parent node */
     data = "{\"a:c\":{\"n1\":{\"nl\":\"value\"}}}";
-    CHECK_LYD_STRING(lyd_parent(ntf), LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS, data);
+    CHECK_LYD_STRING(ntf->parent, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS, data);
 
     lyd_free_all(tree);
     lyd_free_all(ntf);
