@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief unit tests for Schema Mount extension support
  *
- * Copyright (c) 2021 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2021 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -1405,14 +1405,14 @@ test_dup_shared(void **state)
     assert_int_equal(LY_SUCCESS, lyd_dup_single(node, NULL, diff_opts, &dup));
 
     while (dup->parent) {
-        dup = lyd_parent(dup);
+        dup = dup->parent;
     }
     assert_int_equal(LY_SUCCESS, lyd_find_xpath(data,
             "/sm:root3/ls[name='ls2']/ietf-interfaces:interfaces-state/interface[name='if2']", &set));
     assert_int_equal(1, set->count);
     node = set->dnodes[0];
     ly_set_free(set, NULL);
-    assert_int_equal(LY_SUCCESS, lyd_dup_single_to_ctx(node, LYD_CTX(data), (struct lyd_node_inner *)dup, diff_opts, NULL));
+    assert_int_equal(LY_SUCCESS, lyd_dup_single_to_ctx(node, LYD_CTX(data), dup, diff_opts, NULL));
 
     lyd_free_siblings(dup);
 
@@ -1431,14 +1431,14 @@ test_dup_shared(void **state)
     assert_int_equal(LY_SUCCESS, lyd_dup_single_to_ctx(node, ctx2, NULL, diff_opts, &dup));
 
     while (dup->parent) {
-        dup = lyd_parent(dup);
+        dup = dup->parent;
     }
     assert_int_equal(LY_SUCCESS, lyd_find_xpath(data,
             "/sm:root3/ls[name='ls2']/ietf-interfaces:interfaces-state/interface[name='if2']", &set));
     assert_int_equal(1, set->count);
     node = set->dnodes[0];
     ly_set_free(set, NULL);
-    assert_int_equal(LY_SUCCESS, lyd_dup_single_to_ctx(node, ctx2, (struct lyd_node_inner *)dup, diff_opts, NULL));
+    assert_int_equal(LY_SUCCESS, lyd_dup_single_to_ctx(node, ctx2, dup, diff_opts, NULL));
 
     lyd_free_siblings(dup);
 
@@ -1867,32 +1867,23 @@ test_lys_getnext(void **state)
     parent = lys_find_path(UTEST_LYCTX, NULL, "/sm:root", 0);
     assert_non_null(parent);
 
-    node = lys_getnext(NULL, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "yang", 0, "date-and-time", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "date-and-time");
 
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "ietf-yang-schema-mount", 0, "schema-mounts", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "schema-mounts");
 
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "ietf-yang-library", 0, "yang-library", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "yang-library");
 
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "ietf-yang-library", 0, "modules-state", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "modules-state");
 
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "ietf-interfaces", 0, "interfaces", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "interfaces");
 
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
+    node = lys_find_child(NULL, parent, NULL, "ietf-interfaces", 0, "interfaces-state", 0, 0);
     assert_non_null(node);
-    assert_string_equal(node->name, "interfaces-state");
-
-    node = lys_getnext(node, parent, NULL, LYS_GETNEXT_WITHSCHEMAMOUNT);
-    assert_null(node);
 }
 
 static void
@@ -1900,6 +1891,7 @@ test_xpath(void **state)
 {
     const char *xml;
     struct lyd_node *data;
+    struct ly_set *set;
 
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
             "<root xmlns=\"urn:sm\">"
@@ -1983,6 +1975,11 @@ test_xpath(void **state)
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
     lyd_free_siblings(data);
+
+    /* find nodes */
+    assert_int_equal(LY_SUCCESS, lys_find_xpath(UTEST_LYCTX, NULL, "/sm:root/mount:root/l1", 0, &set));
+    assert_int_equal(set->count, 1);
+    ly_set_free(set, NULL);
 }
 
 int
