@@ -51,7 +51,7 @@
         char *xml_out, *data; \
         data = "<" NODE_NAME " xmlns=\"urn:tests:" MOD_NAME "\">" DATA "</" NODE_NAME ">"; \
         CHECK_PARSE_LYD_PARAM(data, LYD_XML, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, LY_SUCCESS, tree_1); \
-        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_WITHSIBLINGS), 0); \
+        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_SIBLINGS), 0); \
         assert_int_equal(LY_SUCCESS, lyd_parse_data_mem(UTEST_LYCTX, xml_out, LYD_LYB, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, &tree_2)); \
         assert_non_null(tree_2); \
         CHECK_LYD(tree_1, tree_2); \
@@ -77,10 +77,10 @@ test_data_xml(void **state)
 
     /* invalid value */
     TEST_ERROR_XML("defs", "l1", "x");
-    CHECK_LOG_CTX("Invalid empty value length 1.", "/defs:l1", 1);
+    CHECK_LOG_CTX("Invalid empty value size 8 b.", "/defs:l1", 1);
 
     TEST_ERROR_XML("defs", "l1", " ");
-    CHECK_LOG_CTX("Invalid empty value length 1.", "/defs:l1", 1);
+    CHECK_LOG_CTX("Invalid empty value size 8 b.", "/defs:l1", 1);
 }
 
 static void
